package androidx.camera.camera2.internal;

import android.hardware.camera2.CameraDevice;
import androidx.camera.camera2.internal.CaptureSessionRepository;
import androidx.camera.core.impl.DeferrableSurface;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.Executor;

/* access modifiers changed from: package-private */
public class CaptureSessionRepository {
    private final CameraDevice.StateCallback mCameraStateCallback = new CameraDevice.StateCallback() {
        /* class androidx.camera.camera2.internal.CaptureSessionRepository.AnonymousClass1 */

        public void onOpened(CameraDevice cameraDevice) {
        }

        public void onError(CameraDevice cameraDevice, int i) {
            forceOnClosedCaptureSessions();
        }

        public void onDisconnected(CameraDevice cameraDevice) {
            forceOnClosedCaptureSessions();
        }

        private void forceOnClosedCaptureSessions() {
            CaptureSessionRepository.this.mExecutor.execute(new Runnable() {
                /* class androidx.camera.camera2.internal.$$Lambda$CaptureSessionRepository$1$sBss0s2PABHkbD_yQBqnFH8lYQw */

                public final void run() {
                    CaptureSessionRepository.AnonymousClass1.this.lambda$forceOnClosedCaptureSessions$0$CaptureSessionRepository$1();
                }
            });
        }

        public /* synthetic */ void lambda$forceOnClosedCaptureSessions$0$CaptureSessionRepository$1() {
            LinkedHashSet linkedHashSet = new LinkedHashSet();
            synchronized (CaptureSessionRepository.this.mLock) {
                linkedHashSet.addAll(new LinkedHashSet(CaptureSessionRepository.this.mCreatingCaptureSessions));
                linkedHashSet.addAll(new LinkedHashSet(CaptureSessionRepository.this.mCaptureSessions));
            }
            CaptureSessionRepository.forceOnClosed(linkedHashSet);
        }
    };
    final Set<SynchronizedCaptureSession> mCaptureSessions = new LinkedHashSet();
    final Set<SynchronizedCaptureSession> mClosingCaptureSession = new LinkedHashSet();
    final Set<SynchronizedCaptureSession> mCreatingCaptureSessions = new LinkedHashSet();
    final Map<SynchronizedCaptureSession, List<DeferrableSurface>> mDeferrableSurfaceMap = new HashMap();
    final Executor mExecutor;
    final Object mLock = new Object();

    CaptureSessionRepository(Executor executor) {
        this.mExecutor = executor;
    }

    /* access modifiers changed from: package-private */
    public CameraDevice.StateCallback getCameraStateCallback() {
        return this.mCameraStateCallback;
    }

    static void forceOnClosed(Set<SynchronizedCaptureSession> set) {
        for (SynchronizedCaptureSession synchronizedCaptureSession : set) {
            synchronizedCaptureSession.getStateCallback().onClosed(synchronizedCaptureSession);
        }
    }

    /* access modifiers changed from: package-private */
    public List<SynchronizedCaptureSession> getCaptureSessions() {
        ArrayList arrayList;
        synchronized (this.mLock) {
            arrayList = new ArrayList(this.mCaptureSessions);
        }
        return arrayList;
    }

    /* access modifiers changed from: package-private */
    public List<SynchronizedCaptureSession> getClosingCaptureSession() {
        ArrayList arrayList;
        synchronized (this.mLock) {
            arrayList = new ArrayList(this.mClosingCaptureSession);
        }
        return arrayList;
    }

    /* access modifiers changed from: package-private */
    public List<SynchronizedCaptureSession> getCreatingCaptureSessions() {
        ArrayList arrayList;
        synchronized (this.mLock) {
            arrayList = new ArrayList(this.mCreatingCaptureSessions);
        }
        return arrayList;
    }

    /* access modifiers changed from: package-private */
    public Map<SynchronizedCaptureSession, List<DeferrableSurface>> registerDeferrableSurface(SynchronizedCaptureSession synchronizedCaptureSession, List<DeferrableSurface> list) {
        HashMap hashMap;
        synchronized (this.mLock) {
            this.mDeferrableSurfaceMap.put(synchronizedCaptureSession, list);
            hashMap = new HashMap(this.mDeferrableSurfaceMap);
        }
        return hashMap;
    }

    /* access modifiers changed from: package-private */
    public void unregisterDeferrableSurface(SynchronizedCaptureSession synchronizedCaptureSession) {
        synchronized (this.mLock) {
            this.mDeferrableSurfaceMap.remove(synchronizedCaptureSession);
        }
    }

    /* access modifiers changed from: package-private */
    public void onCreateCaptureSession(SynchronizedCaptureSession synchronizedCaptureSession) {
        synchronized (this.mLock) {
            this.mCreatingCaptureSessions.add(synchronizedCaptureSession);
        }
    }

    /* access modifiers changed from: package-private */
    public void onCaptureSessionConfigureFail(SynchronizedCaptureSession synchronizedCaptureSession) {
        synchronized (this.mLock) {
            this.mCreatingCaptureSessions.remove(synchronizedCaptureSession);
        }
    }

    /* access modifiers changed from: package-private */
    public void onCaptureSessionCreated(SynchronizedCaptureSession synchronizedCaptureSession) {
        synchronized (this.mLock) {
            this.mCaptureSessions.add(synchronizedCaptureSession);
            this.mCreatingCaptureSessions.remove(synchronizedCaptureSession);
        }
    }

    /* access modifiers changed from: package-private */
    public void onCaptureSessionClosed(SynchronizedCaptureSession synchronizedCaptureSession) {
        synchronized (this.mLock) {
            this.mCaptureSessions.remove(synchronizedCaptureSession);
            this.mClosingCaptureSession.remove(synchronizedCaptureSession);
        }
    }

    /* access modifiers changed from: package-private */
    public void onCaptureSessionClosing(SynchronizedCaptureSession synchronizedCaptureSession) {
        synchronized (this.mLock) {
            this.mClosingCaptureSession.add(synchronizedCaptureSession);
        }
    }
}
