package androidx.camera.camera2.internal;

import android.hardware.camera2.CameraAccessException;
import android.hardware.camera2.CameraCaptureSession;
import android.hardware.camera2.CameraDevice;
import android.hardware.camera2.CaptureRequest;
import android.os.Handler;
import android.view.Surface;
import androidx.camera.camera2.internal.compat.params.SessionConfigurationCompat;
import androidx.camera.core.Logger;
import androidx.camera.core.impl.DeferrableSurface;
import androidx.camera.core.impl.utils.executor.CameraXExecutors;
import androidx.camera.core.impl.utils.futures.AsyncFunction;
import androidx.camera.core.impl.utils.futures.FutureChain;
import androidx.camera.core.impl.utils.futures.Futures;
import androidx.concurrent.futures.CallbackToFutureAdapter;
import com.google.common.util.concurrent.ListenableFuture;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.Executor;
import java.util.concurrent.ScheduledExecutorService;

/* access modifiers changed from: package-private */
public class SynchronizedCaptureSessionImpl extends SynchronizedCaptureSessionBaseImpl {
    private static final String TAG = "SyncCaptureSessionImpl";
    private final CameraCaptureSession.CaptureCallback mCaptureCallback = new CameraCaptureSession.CaptureCallback() {
        /* class androidx.camera.camera2.internal.SynchronizedCaptureSessionImpl.AnonymousClass1 */

        public void onCaptureStarted(CameraCaptureSession cameraCaptureSession, CaptureRequest captureRequest, long j, long j2) {
            if (SynchronizedCaptureSessionImpl.this.mStartStreamingCompleter != null) {
                SynchronizedCaptureSessionImpl.this.mStartStreamingCompleter.set(null);
                SynchronizedCaptureSessionImpl.this.mStartStreamingCompleter = null;
            }
        }

        public void onCaptureSequenceAborted(CameraCaptureSession cameraCaptureSession, int i) {
            if (SynchronizedCaptureSessionImpl.this.mStartStreamingCompleter != null) {
                SynchronizedCaptureSessionImpl.this.mStartStreamingCompleter.setCancelled();
                SynchronizedCaptureSessionImpl.this.mStartStreamingCompleter = null;
            }
        }
    };
    CallbackToFutureAdapter.Completer<Void> mClosingDeferrableSurfaceCompleter;
    private final ListenableFuture<Void> mClosingDeferrableSurfaceFuture;
    private List<DeferrableSurface> mDeferrableSurfaces;
    private final Set<String> mEnabledFeature;
    private boolean mHasSubmittedRepeating;
    private final Object mObjectLock = new Object();
    ListenableFuture<Void> mOpeningCaptureSession;
    CallbackToFutureAdapter.Completer<Void> mStartStreamingCompleter;
    private final ListenableFuture<Void> mStartStreamingFuture;
    ListenableFuture<List<Surface>> mStartingSurface;

    SynchronizedCaptureSessionImpl(Set<String> set, CaptureSessionRepository captureSessionRepository, Executor executor, ScheduledExecutorService scheduledExecutorService, Handler handler) {
        super(captureSessionRepository, executor, scheduledExecutorService, handler);
        this.mEnabledFeature = set;
        if (set.contains("wait_for_request")) {
            this.mStartStreamingFuture = CallbackToFutureAdapter.getFuture(new CallbackToFutureAdapter.Resolver() {
                /* class androidx.camera.camera2.internal.$$Lambda$SynchronizedCaptureSessionImpl$jyQAveySUCZWY5ISV0AhM2DhYt0 */

                @Override // androidx.concurrent.futures.CallbackToFutureAdapter.Resolver
                public final Object attachCompleter(CallbackToFutureAdapter.Completer completer) {
                    return SynchronizedCaptureSessionImpl.this.lambda$new$0$SynchronizedCaptureSessionImpl(completer);
                }
            });
        } else {
            this.mStartStreamingFuture = Futures.immediateFuture(null);
        }
        if (this.mEnabledFeature.contains("deferrableSurface_close")) {
            this.mClosingDeferrableSurfaceFuture = CallbackToFutureAdapter.getFuture(new CallbackToFutureAdapter.Resolver() {
                /* class androidx.camera.camera2.internal.$$Lambda$SynchronizedCaptureSessionImpl$WP0Dt0CneE2u6JPoDDGhCbiX1Ho */

                @Override // androidx.concurrent.futures.CallbackToFutureAdapter.Resolver
                public final Object attachCompleter(CallbackToFutureAdapter.Completer completer) {
                    return SynchronizedCaptureSessionImpl.this.lambda$new$1$SynchronizedCaptureSessionImpl(completer);
                }
            });
        } else {
            this.mClosingDeferrableSurfaceFuture = Futures.immediateFuture(null);
        }
    }

    public /* synthetic */ Object lambda$new$0$SynchronizedCaptureSessionImpl(CallbackToFutureAdapter.Completer completer) throws Exception {
        this.mStartStreamingCompleter = completer;
        return "StartStreamingFuture[session=" + this + "]";
    }

    public /* synthetic */ Object lambda$new$1$SynchronizedCaptureSessionImpl(CallbackToFutureAdapter.Completer completer) throws Exception {
        this.mClosingDeferrableSurfaceCompleter = completer;
        return "ClosingDeferrableSurfaceFuture[session=" + this + "]";
    }

    @Override // androidx.camera.camera2.internal.SynchronizedCaptureSessionBaseImpl, androidx.camera.camera2.internal.SynchronizedCaptureSessionOpener.OpenerImpl
    public ListenableFuture<Void> openCaptureSession(CameraDevice cameraDevice, SessionConfigurationCompat sessionConfigurationCompat) {
        ListenableFuture<Void> nonCancellationPropagating;
        synchronized (this.mObjectLock) {
            this.mOpeningCaptureSession = FutureChain.from(Futures.successfulAsList(getBlockerFuture("wait_for_request", this.mCaptureSessionRepository.getClosingCaptureSession()))).transformAsync(new AsyncFunction(cameraDevice, sessionConfigurationCompat) {
                /* class androidx.camera.camera2.internal.$$Lambda$SynchronizedCaptureSessionImpl$m2Xqfw_ydv7rK_tiDA4dZKmwX50 */
                private final /* synthetic */ CameraDevice f$1;
                private final /* synthetic */ SessionConfigurationCompat f$2;

                {
                    this.f$1 = r2;
                    this.f$2 = r3;
                }

                @Override // androidx.camera.core.impl.utils.futures.AsyncFunction
                public final ListenableFuture apply(Object obj) {
                    return SynchronizedCaptureSessionImpl.this.lambda$openCaptureSession$2$SynchronizedCaptureSessionImpl(this.f$1, this.f$2, (List) obj);
                }
            }, CameraXExecutors.directExecutor());
            nonCancellationPropagating = Futures.nonCancellationPropagating(this.mOpeningCaptureSession);
        }
        return nonCancellationPropagating;
    }

    public /* synthetic */ ListenableFuture lambda$openCaptureSession$2$SynchronizedCaptureSessionImpl(CameraDevice cameraDevice, SessionConfigurationCompat sessionConfigurationCompat, List list) throws Exception {
        return super.openCaptureSession(cameraDevice, sessionConfigurationCompat);
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x0027  */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x0035  */
    @Override // androidx.camera.camera2.internal.SynchronizedCaptureSession, androidx.camera.camera2.internal.SynchronizedCaptureSessionBaseImpl
    public ListenableFuture<Void> getSynchronizedBlocker(String str) {
        char c;
        int hashCode = str.hashCode();
        if (hashCode != -1937525425) {
            if (hashCode == -529927828 && str.equals("deferrableSurface_close")) {
                c = 1;
                if (c == 0) {
                    return Futures.nonCancellationPropagating(this.mStartStreamingFuture);
                }
                if (c != 1) {
                    return super.getSynchronizedBlocker(str);
                }
                return Futures.nonCancellationPropagating(this.mClosingDeferrableSurfaceFuture);
            }
        } else if (str.equals("wait_for_request")) {
            c = 0;
            if (c == 0) {
            }
        }
        c = 65535;
        if (c == 0) {
        }
    }

    private List<ListenableFuture<Void>> getBlockerFuture(String str, List<SynchronizedCaptureSession> list) {
        ArrayList arrayList = new ArrayList();
        for (SynchronizedCaptureSession synchronizedCaptureSession : list) {
            arrayList.add(synchronizedCaptureSession.getSynchronizedBlocker(str));
        }
        return arrayList;
    }

    @Override // androidx.camera.camera2.internal.SynchronizedCaptureSessionBaseImpl, androidx.camera.camera2.internal.SynchronizedCaptureSessionOpener.OpenerImpl
    public ListenableFuture<List<Surface>> startWithDeferrableSurface(List<DeferrableSurface> list, long j) {
        ListenableFuture<List<Surface>> nonCancellationPropagating;
        synchronized (this.mObjectLock) {
            this.mDeferrableSurfaces = list;
            List<ListenableFuture<Void>> emptyList = Collections.emptyList();
            if (this.mEnabledFeature.contains("force_close")) {
                Map<SynchronizedCaptureSession, List<DeferrableSurface>> registerDeferrableSurface = this.mCaptureSessionRepository.registerDeferrableSurface(this, list);
                ArrayList arrayList = new ArrayList();
                for (Map.Entry<SynchronizedCaptureSession, List<DeferrableSurface>> entry : registerDeferrableSurface.entrySet()) {
                    if (entry.getKey() != this && !Collections.disjoint(entry.getValue(), this.mDeferrableSurfaces)) {
                        arrayList.add(entry.getKey());
                    }
                }
                emptyList = getBlockerFuture("deferrableSurface_close", arrayList);
            }
            this.mStartingSurface = FutureChain.from(Futures.successfulAsList(emptyList)).transformAsync(new AsyncFunction(list, j) {
                /* class androidx.camera.camera2.internal.$$Lambda$SynchronizedCaptureSessionImpl$wl1PsdoNzau59EdJhZcEGOmtTgk */
                private final /* synthetic */ List f$1;
                private final /* synthetic */ long f$2;

                {
                    this.f$1 = r2;
                    this.f$2 = r3;
                }

                @Override // androidx.camera.core.impl.utils.futures.AsyncFunction
                public final ListenableFuture apply(Object obj) {
                    return SynchronizedCaptureSessionImpl.this.lambda$startWithDeferrableSurface$3$SynchronizedCaptureSessionImpl(this.f$1, this.f$2, (List) obj);
                }
            }, getExecutor());
            nonCancellationPropagating = Futures.nonCancellationPropagating(this.mStartingSurface);
        }
        return nonCancellationPropagating;
    }

    public /* synthetic */ ListenableFuture lambda$startWithDeferrableSurface$3$SynchronizedCaptureSessionImpl(List list, long j, List list2) throws Exception {
        return super.startWithDeferrableSurface(list, j);
    }

    @Override // androidx.camera.camera2.internal.SynchronizedCaptureSessionBaseImpl, androidx.camera.camera2.internal.SynchronizedCaptureSessionOpener.OpenerImpl
    public boolean stop() {
        boolean stop;
        synchronized (this.mObjectLock) {
            if (isCameraCaptureSessionOpen()) {
                closeConfiguredDeferrableSurfaces();
            } else {
                if (this.mOpeningCaptureSession != null) {
                    this.mOpeningCaptureSession.cancel(true);
                }
                if (this.mStartingSurface != null) {
                    this.mStartingSurface.cancel(true);
                }
                stopDeferrableSurface();
            }
            stop = super.stop();
        }
        return stop;
    }

    @Override // androidx.camera.camera2.internal.SynchronizedCaptureSession, androidx.camera.camera2.internal.SynchronizedCaptureSessionBaseImpl
    public int setSingleRepeatingRequest(CaptureRequest captureRequest, CameraCaptureSession.CaptureCallback captureCallback) throws CameraAccessException {
        int singleRepeatingRequest;
        if (!this.mEnabledFeature.contains("wait_for_request")) {
            return super.setSingleRepeatingRequest(captureRequest, captureCallback);
        }
        synchronized (this.mObjectLock) {
            this.mHasSubmittedRepeating = true;
            singleRepeatingRequest = super.setSingleRepeatingRequest(captureRequest, Camera2CaptureCallbacks.createComboCallback(this.mCaptureCallback, captureCallback));
        }
        return singleRepeatingRequest;
    }

    @Override // androidx.camera.camera2.internal.SynchronizedCaptureSession.StateCallback, androidx.camera.camera2.internal.SynchronizedCaptureSessionBaseImpl
    public void onConfigured(SynchronizedCaptureSession synchronizedCaptureSession) {
        SynchronizedCaptureSession next;
        SynchronizedCaptureSession next2;
        debugLog("Session onConfigured()");
        if (this.mEnabledFeature.contains("force_close")) {
            LinkedHashSet linkedHashSet = new LinkedHashSet();
            Iterator<SynchronizedCaptureSession> it = this.mCaptureSessionRepository.getCreatingCaptureSessions().iterator();
            while (it.hasNext() && (next2 = it.next()) != synchronizedCaptureSession) {
                linkedHashSet.add(next2);
            }
            forceOnConfigureFailed(linkedHashSet);
        }
        super.onConfigured(synchronizedCaptureSession);
        if (this.mEnabledFeature.contains("force_close")) {
            LinkedHashSet linkedHashSet2 = new LinkedHashSet();
            Iterator<SynchronizedCaptureSession> it2 = this.mCaptureSessionRepository.getCaptureSessions().iterator();
            while (it2.hasNext() && (next = it2.next()) != synchronizedCaptureSession) {
                linkedHashSet2.add(next);
            }
            forceOnClosed(linkedHashSet2);
        }
    }

    @Override // androidx.camera.camera2.internal.SynchronizedCaptureSession, androidx.camera.camera2.internal.SynchronizedCaptureSessionBaseImpl
    public void close() {
        debugLog("Session call close()");
        if (this.mEnabledFeature.contains("wait_for_request")) {
            synchronized (this.mObjectLock) {
                if (!this.mHasSubmittedRepeating) {
                    this.mStartStreamingFuture.cancel(true);
                }
            }
        }
        this.mStartStreamingFuture.addListener(new Runnable() {
            /* class androidx.camera.camera2.internal.$$Lambda$SynchronizedCaptureSessionImpl$ej6SnusDBaFvWFR_5VwoLwriBIE */

            public final void run() {
                SynchronizedCaptureSessionImpl.this.lambda$close$4$SynchronizedCaptureSessionImpl();
            }
        }, getExecutor());
    }

    public /* synthetic */ void lambda$close$4$SynchronizedCaptureSessionImpl() {
        debugLog("Session call super.close()");
        super.close();
    }

    /* access modifiers changed from: package-private */
    public void closeConfiguredDeferrableSurfaces() {
        synchronized (this.mObjectLock) {
            if (this.mDeferrableSurfaces == null) {
                debugLog("deferrableSurface == null, maybe forceClose, skip close");
                return;
            }
            if (this.mEnabledFeature.contains("deferrableSurface_close")) {
                for (DeferrableSurface deferrableSurface : this.mDeferrableSurfaces) {
                    deferrableSurface.close();
                }
                debugLog("deferrableSurface closed");
                stopDeferrableSurface();
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void stopDeferrableSurface() {
        if (this.mEnabledFeature.contains("deferrableSurface_close")) {
            this.mCaptureSessionRepository.unregisterDeferrableSurface(this);
            CallbackToFutureAdapter.Completer<Void> completer = this.mClosingDeferrableSurfaceCompleter;
            if (completer != null) {
                completer.set(null);
            }
        }
    }

    @Override // androidx.camera.camera2.internal.SynchronizedCaptureSession.StateCallback, androidx.camera.camera2.internal.SynchronizedCaptureSessionBaseImpl
    public void onClosed(SynchronizedCaptureSession synchronizedCaptureSession) {
        closeConfiguredDeferrableSurfaces();
        debugLog("onClosed()");
        super.onClosed(synchronizedCaptureSession);
    }

    static void forceOnClosed(Set<SynchronizedCaptureSession> set) {
        for (SynchronizedCaptureSession synchronizedCaptureSession : set) {
            synchronizedCaptureSession.getStateCallback().onClosed(synchronizedCaptureSession);
        }
    }

    private void forceOnConfigureFailed(Set<SynchronizedCaptureSession> set) {
        for (SynchronizedCaptureSession synchronizedCaptureSession : set) {
            synchronizedCaptureSession.getStateCallback().onConfigureFailed(synchronizedCaptureSession);
        }
    }

    /* access modifiers changed from: package-private */
    public void debugLog(String str) {
        Logger.d(TAG, "[" + this + "] " + str);
    }
}
