package androidx.camera.core;

import android.content.ContentResolver;
import android.content.ContentValues;
import android.net.Uri;
import androidx.camera.core.ImageCapture;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;

/* access modifiers changed from: package-private */
public class ImageSaveLocationValidator {
    private static final String TAG = "SaveLocationValidator";

    private ImageSaveLocationValidator() {
    }

    static boolean isValid(ImageCapture.OutputFileOptions outputFileOptions) {
        if (isSaveToFile(outputFileOptions)) {
            return canSaveToFile(outputFileOptions.getFile());
        }
        if (isSaveToMediaStore(outputFileOptions)) {
            return canSaveToMediaStore(outputFileOptions.getContentResolver(), outputFileOptions.getSaveCollection(), outputFileOptions.getContentValues());
        }
        return true;
    }

    private static boolean isSaveToFile(ImageCapture.OutputFileOptions outputFileOptions) {
        return outputFileOptions.getFile() != null;
    }

    private static boolean isSaveToMediaStore(ImageCapture.OutputFileOptions outputFileOptions) {
        return (outputFileOptions.getSaveCollection() == null || outputFileOptions.getContentResolver() == null || outputFileOptions.getContentValues() == null) ? false : true;
    }

    private static boolean canSaveToFile(File file) {
        try {
            new FileOutputStream(file).close();
            return true;
        } catch (IOException e) {
            Logger.e(TAG, "Failed to open a write stream to " + file.toString(), e);
            return false;
        }
    }

    private static boolean canSaveToMediaStore(ContentResolver contentResolver, Uri uri, ContentValues contentValues) {
        try {
            Uri insert = contentResolver.insert(uri, contentValues);
            if (insert == null) {
                return false;
            }
            try {
                OutputStream openOutputStream = contentResolver.openOutputStream(insert);
                boolean z = openOutputStream != null;
                if (openOutputStream != null) {
                    openOutputStream.close();
                }
                try {
                    contentResolver.delete(insert, null, null);
                } catch (IllegalArgumentException e) {
                    Logger.e(TAG, "Failed to delete inserted row at " + insert.toString(), e);
                }
                return z;
            } catch (IOException e2) {
                Logger.e(TAG, "Failed to open a write stream to" + insert.toString(), e2);
                try {
                    contentResolver.delete(insert, null, null);
                } catch (IllegalArgumentException e3) {
                    Logger.e(TAG, "Failed to delete inserted row at " + insert.toString(), e3);
                }
                return false;
            } catch (Throwable th) {
                try {
                    contentResolver.delete(insert, null, null);
                } catch (IllegalArgumentException e4) {
                    Logger.e(TAG, "Failed to delete inserted row at " + insert.toString(), e4);
                }
                throw th;
            }
        } catch (IllegalArgumentException e5) {
            Logger.e(TAG, "Failed to insert into " + uri.toString(), e5);
            return false;
        }
    }
}
