package androidx.camera.extensions;

import androidx.camera.core.CameraSelector;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.Logger;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.AutoImageCaptureExtenderImpl;

public class AutoImageCaptureExtender extends ImageCaptureExtender {
    private static final String TAG = "AutoICExtender";

    public static AutoImageCaptureExtender create(ImageCapture.Builder builder) {
        if (ExtensionVersion.isExtensionVersionSupported()) {
            try {
                return new VendorAutoImageCaptureExtender(builder);
            } catch (NoClassDefFoundError unused) {
                Logger.d(TAG, "No auto image capture extender found. Falling back to default.");
            }
        }
        return new DefaultAutoImageCaptureExtender();
    }

    /* access modifiers changed from: package-private */
    public static class DefaultAutoImageCaptureExtender extends AutoImageCaptureExtender {
        @Override // androidx.camera.extensions.ImageCaptureExtender
        public void enableExtension(CameraSelector cameraSelector) {
        }

        @Override // androidx.camera.extensions.ImageCaptureExtender
        public boolean isExtensionAvailable(CameraSelector cameraSelector) {
            return false;
        }

        DefaultAutoImageCaptureExtender() {
            super();
        }
    }

    /* access modifiers changed from: package-private */
    public static class VendorAutoImageCaptureExtender extends AutoImageCaptureExtender {
        private final AutoImageCaptureExtenderImpl mImpl = new AutoImageCaptureExtenderImpl();

        VendorAutoImageCaptureExtender(ImageCapture.Builder builder) {
            super();
            init(builder, this.mImpl, ExtensionsManager.EffectMode.AUTO);
        }
    }

    private AutoImageCaptureExtender() {
    }
}
