package androidx.camera.extensions;

import androidx.camera.core.CameraSelector;
import androidx.camera.core.Logger;
import androidx.camera.core.Preview;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.AutoPreviewExtenderImpl;

public class AutoPreviewExtender extends PreviewExtender {
    private static final String TAG = "AutoPreviewExtender";

    public static AutoPreviewExtender create(Preview.Builder builder) {
        if (ExtensionVersion.isExtensionVersionSupported()) {
            try {
                return new VendorAutoPreviewExtender(builder);
            } catch (NoClassDefFoundError unused) {
                Logger.d(TAG, "No auto preview extender found. Falling back to default.");
            }
        }
        return new DefaultAutoPreviewExtender();
    }

    /* access modifiers changed from: package-private */
    public static class DefaultAutoPreviewExtender extends AutoPreviewExtender {
        @Override // androidx.camera.extensions.PreviewExtender
        public void enableExtension(CameraSelector cameraSelector) {
        }

        @Override // androidx.camera.extensions.PreviewExtender
        public boolean isExtensionAvailable(CameraSelector cameraSelector) {
            return false;
        }

        DefaultAutoPreviewExtender() {
            super();
        }
    }

    /* access modifiers changed from: package-private */
    public static class VendorAutoPreviewExtender extends AutoPreviewExtender {
        private final AutoPreviewExtenderImpl mImpl = new AutoPreviewExtenderImpl();

        VendorAutoPreviewExtender(Preview.Builder builder) {
            super();
            init(builder, this.mImpl, ExtensionsManager.EffectMode.AUTO);
        }
    }

    private AutoPreviewExtender() {
    }
}
