package androidx.camera.extensions;

import androidx.camera.core.CameraSelector;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.Logger;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.BeautyImageCaptureExtenderImpl;

public class BeautyImageCaptureExtender extends ImageCaptureExtender {
    private static final String TAG = "BeautyICExtender";

    public static BeautyImageCaptureExtender create(ImageCapture.Builder builder) {
        if (ExtensionVersion.isExtensionVersionSupported()) {
            try {
                return new VendorBeautyImageCaptureExtender(builder);
            } catch (NoClassDefFoundError unused) {
                Logger.d(TAG, "No beauty image capture extender found. Falling back to default.");
            }
        }
        return new DefaultBeautyImageCaptureExtender();
    }

    /* access modifiers changed from: package-private */
    public static class DefaultBeautyImageCaptureExtender extends BeautyImageCaptureExtender {
        @Override // androidx.camera.extensions.ImageCaptureExtender
        public void enableExtension(CameraSelector cameraSelector) {
        }

        @Override // androidx.camera.extensions.ImageCaptureExtender
        public boolean isExtensionAvailable(CameraSelector cameraSelector) {
            return false;
        }

        DefaultBeautyImageCaptureExtender() {
            super();
        }
    }

    /* access modifiers changed from: package-private */
    public static class VendorBeautyImageCaptureExtender extends BeautyImageCaptureExtender {
        private final BeautyImageCaptureExtenderImpl mImpl = new BeautyImageCaptureExtenderImpl();

        VendorBeautyImageCaptureExtender(ImageCapture.Builder builder) {
            super();
            init(builder, this.mImpl, ExtensionsManager.EffectMode.BEAUTY);
        }
    }

    private BeautyImageCaptureExtender() {
    }
}
