package androidx.camera.extensions;

import androidx.camera.core.CameraSelector;
import androidx.camera.core.Logger;
import androidx.camera.core.Preview;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.BeautyPreviewExtenderImpl;

public class BeautyPreviewExtender extends PreviewExtender {
    private static final String TAG = "BeautyPreviewExtender";

    public static BeautyPreviewExtender create(Preview.Builder builder) {
        if (ExtensionVersion.isExtensionVersionSupported()) {
            try {
                return new VendorBeautyPreviewExtender(builder);
            } catch (NoClassDefFoundError unused) {
                Logger.d(TAG, "No beauty preview extender found. Falling back to default.");
            }
        }
        return new DefaultBeautyPreviewExtender();
    }

    /* access modifiers changed from: package-private */
    public static class DefaultBeautyPreviewExtender extends BeautyPreviewExtender {
        @Override // androidx.camera.extensions.PreviewExtender
        public void enableExtension(CameraSelector cameraSelector) {
        }

        @Override // androidx.camera.extensions.PreviewExtender
        public boolean isExtensionAvailable(CameraSelector cameraSelector) {
            return false;
        }

        DefaultBeautyPreviewExtender() {
            super();
        }
    }

    /* access modifiers changed from: package-private */
    public static class VendorBeautyPreviewExtender extends BeautyPreviewExtender {
        private final BeautyPreviewExtenderImpl mImpl = new BeautyPreviewExtenderImpl();

        VendorBeautyPreviewExtender(Preview.Builder builder) {
            super();
            init(builder, this.mImpl, ExtensionsManager.EffectMode.BEAUTY);
        }
    }

    private BeautyPreviewExtender() {
    }
}
