package androidx.camera.extensions;

import androidx.camera.core.CameraSelector;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.Logger;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.BokehImageCaptureExtenderImpl;

public class BokehImageCaptureExtender extends ImageCaptureExtender {
    private static final String TAG = "BokehImgCaptureExtender";

    public static BokehImageCaptureExtender create(ImageCapture.Builder builder) {
        if (ExtensionVersion.isExtensionVersionSupported()) {
            try {
                return new VendorBokehImageCaptureExtender(builder);
            } catch (NoClassDefFoundError unused) {
                Logger.d(TAG, "No bokeh image capture extender found. Falling back to default.");
            }
        }
        return new DefaultBokehImageCaptureExtender();
    }

    /* access modifiers changed from: private */
    public static class DefaultBokehImageCaptureExtender extends BokehImageCaptureExtender {
        @Override // androidx.camera.extensions.ImageCaptureExtender
        public void enableExtension(CameraSelector cameraSelector) {
        }

        @Override // androidx.camera.extensions.ImageCaptureExtender
        public boolean isExtensionAvailable(CameraSelector cameraSelector) {
            return false;
        }

        DefaultBokehImageCaptureExtender() {
            super();
        }
    }

    /* access modifiers changed from: private */
    public static class VendorBokehImageCaptureExtender extends BokehImageCaptureExtender {
        private final BokehImageCaptureExtenderImpl mImpl = new BokehImageCaptureExtenderImpl();

        VendorBokehImageCaptureExtender(ImageCapture.Builder builder) {
            super();
            init(builder, this.mImpl, ExtensionsManager.EffectMode.BOKEH);
        }
    }

    private BokehImageCaptureExtender() {
    }
}
