package androidx.camera.extensions;

import androidx.camera.core.CameraSelector;
import androidx.camera.core.Logger;
import androidx.camera.core.Preview;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.BokehPreviewExtenderImpl;

public class BokehPreviewExtender extends PreviewExtender {
    private static final String TAG = "BokehPreviewExtender";

    public static BokehPreviewExtender create(Preview.Builder builder) {
        if (ExtensionVersion.isExtensionVersionSupported()) {
            try {
                return new VendorBokehPreviewExtender(builder);
            } catch (NoClassDefFoundError unused) {
                Logger.d(TAG, "No bokeh preview extender found. Falling back to default.");
            }
        }
        return new DefaultBokehPreviewExtender();
    }

    /* access modifiers changed from: private */
    public static class DefaultBokehPreviewExtender extends BokehPreviewExtender {
        @Override // androidx.camera.extensions.PreviewExtender
        public void enableExtension(CameraSelector cameraSelector) {
        }

        @Override // androidx.camera.extensions.PreviewExtender
        public boolean isExtensionAvailable(CameraSelector cameraSelector) {
            return false;
        }

        DefaultBokehPreviewExtender() {
            super();
        }
    }

    /* access modifiers changed from: private */
    public static class VendorBokehPreviewExtender extends BokehPreviewExtender {
        private final BokehPreviewExtenderImpl mImpl = new BokehPreviewExtenderImpl();

        VendorBokehPreviewExtender(Preview.Builder builder) {
            super();
            init(builder, this.mImpl, ExtensionsManager.EffectMode.BOKEH);
        }
    }

    private BokehPreviewExtender() {
    }
}
