package androidx.camera.extensions;

import android.hardware.camera2.CameraCharacteristics;
import androidx.camera.camera2.interop.Camera2CameraInfo;
import androidx.camera.core.Camera;
import androidx.camera.core.CameraFilter;
import androidx.camera.core.CameraInfo;
import androidx.camera.core.impl.CameraInternal;
import androidx.camera.extensions.impl.ImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.PreviewExtenderImpl;
import androidx.core.util.Preconditions;
import java.util.Iterator;
import java.util.LinkedHashSet;

public final class ExtensionCameraFilter implements CameraFilter {
    private final ImageCaptureExtenderImpl mImageCaptureExtenderImpl;
    private final PreviewExtenderImpl mPreviewExtenderImpl;

    ExtensionCameraFilter(PreviewExtenderImpl previewExtenderImpl) {
        this.mPreviewExtenderImpl = previewExtenderImpl;
        this.mImageCaptureExtenderImpl = null;
    }

    ExtensionCameraFilter(ImageCaptureExtenderImpl imageCaptureExtenderImpl) {
        this.mPreviewExtenderImpl = null;
        this.mImageCaptureExtenderImpl = imageCaptureExtenderImpl;
    }

    ExtensionCameraFilter(PreviewExtenderImpl previewExtenderImpl, ImageCaptureExtenderImpl imageCaptureExtenderImpl) {
        this.mPreviewExtenderImpl = previewExtenderImpl;
        this.mImageCaptureExtenderImpl = imageCaptureExtenderImpl;
    }

    @Override // androidx.camera.core.CameraFilter
    public LinkedHashSet<Camera> filter(LinkedHashSet<Camera> linkedHashSet) {
        LinkedHashSet<Camera> linkedHashSet2 = new LinkedHashSet<>();
        Iterator<Camera> it = linkedHashSet.iterator();
        while (it.hasNext()) {
            Camera next = it.next();
            Preconditions.checkState(next instanceof CameraInternal, "The camera doesn't contain internal implementation.");
            CameraInfo cameraInfo = next.getCameraInfo();
            String cameraId = Camera2CameraInfo.fromCameraInfo(cameraInfo).getCameraId();
            CameraCharacteristics extractCameraCharacteristics = Camera2CameraInfo.extractCameraCharacteristics(cameraInfo);
            boolean z = true;
            PreviewExtenderImpl previewExtenderImpl = this.mPreviewExtenderImpl;
            if (previewExtenderImpl != null) {
                z = previewExtenderImpl.isExtensionAvailable(cameraId, extractCameraCharacteristics);
            }
            ImageCaptureExtenderImpl imageCaptureExtenderImpl = this.mImageCaptureExtenderImpl;
            if (imageCaptureExtenderImpl != null) {
                z = imageCaptureExtenderImpl.isExtensionAvailable(cameraId, extractCameraCharacteristics);
            }
            if (z) {
                linkedHashSet2.add(next);
            }
        }
        return linkedHashSet2;
    }
}
