package androidx.camera.extensions;

import androidx.camera.core.Logger;
import androidx.camera.extensions.impl.ExtensionVersionImpl;

abstract class ExtensionVersion {
    private static final String TAG = "ExtenderVersion";
    private static volatile ExtensionVersion sExtensionVersion;

    /* access modifiers changed from: package-private */
    public abstract Version getVersionObject();

    ExtensionVersion() {
    }

    private static ExtensionVersion getInstance() {
        if (sExtensionVersion != null) {
            return sExtensionVersion;
        }
        synchronized (ExtensionVersion.class) {
            if (sExtensionVersion == null) {
                try {
                    sExtensionVersion = new VendorExtenderVersioning();
                } catch (NoClassDefFoundError unused) {
                    Logger.d(TAG, "No versioning extender found. Falling back to default.");
                    sExtensionVersion = new DefaultExtenderVersioning();
                }
            }
        }
        return sExtensionVersion;
    }

    static boolean isExtensionVersionSupported() {
        return getInstance().getVersionObject() != null;
    }

    static Version getRuntimeVersion() {
        return getInstance().getVersionObject();
    }

    /* access modifiers changed from: private */
    public static class VendorExtenderVersioning extends ExtensionVersion {
        private static ExtensionVersionImpl sImpl;
        private Version mRuntimeVersion;

        VendorExtenderVersioning() {
            if (sImpl == null) {
                sImpl = new ExtensionVersionImpl();
            }
            Version parse = Version.parse(sImpl.checkApiVersion(VersionName.getCurrentVersion().toVersionString()));
            if (parse != null && VersionName.getCurrentVersion().getVersion().getMajor() == parse.getMajor()) {
                this.mRuntimeVersion = parse;
            }
            Logger.d(ExtensionVersion.TAG, "Selected vendor runtime: " + this.mRuntimeVersion);
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.camera.extensions.ExtensionVersion
        public Version getVersionObject() {
            return this.mRuntimeVersion;
        }
    }

    /* access modifiers changed from: private */
    public static class DefaultExtenderVersioning extends ExtensionVersion {
        /* access modifiers changed from: package-private */
        @Override // androidx.camera.extensions.ExtensionVersion
        public Version getVersionObject() {
            return null;
        }

        DefaultExtenderVersioning() {
        }
    }
}
