package androidx.camera.extensions;

import android.content.Context;
import androidx.camera.core.Camera;
import androidx.camera.core.CameraFilter;
import androidx.camera.core.CameraInfo;
import androidx.camera.core.UseCase;
import androidx.camera.core.impl.CameraConfig;
import androidx.camera.core.impl.CameraFilters;
import androidx.camera.core.impl.ExtendableUseCaseConfigFactory;
import androidx.camera.core.impl.ImageCaptureConfig;
import androidx.camera.core.impl.PreviewConfig;
import androidx.camera.core.impl.UseCaseConfigFactory;
import androidx.camera.core.internal.CameraUseCaseAdapter;
import androidx.camera.extensions.ExtensionsConfig;
import androidx.camera.extensions.impl.AutoImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.AutoPreviewExtenderImpl;
import androidx.camera.extensions.impl.BeautyImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.BeautyPreviewExtenderImpl;
import androidx.camera.extensions.impl.BokehImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.BokehPreviewExtenderImpl;
import androidx.camera.extensions.impl.HdrImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.HdrPreviewExtenderImpl;
import androidx.camera.extensions.impl.NightImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.NightPreviewExtenderImpl;
import androidx.camera.extensions.internal.ImageCaptureConfigProvider;
import androidx.camera.extensions.internal.PreviewConfigProvider;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.LinkedHashSet;
import java.util.List;

public class Extensions {
    public static final int EXTENSION_MODE_AUTO = 5;
    public static final int EXTENSION_MODE_BEAUTY = 4;
    public static final int EXTENSION_MODE_BOKEH = 1;
    public static final int EXTENSION_MODE_HDR = 2;
    public static final int EXTENSION_MODE_NIGHT = 3;
    public static final int EXTENSION_MODE_NONE = 0;
    private static final String TAG = "Extensions";
    private final Context mContext;

    @Retention(RetentionPolicy.SOURCE)
    public @interface ExtensionMode {
    }

    Extensions(Context context) {
        this.mContext = context;
    }

    public void setExtension(Camera camera, int i) {
        if (isExtensionAvailable(camera, i)) {
            CameraInfo cameraInfo = getFilter(i).filter(new LinkedHashSet<>(camera.getCameraInternals())).iterator().next().getCameraInfo();
            ExtendableUseCaseConfigFactory extendableUseCaseConfigFactory = new ExtendableUseCaseConfigFactory();
            extendableUseCaseConfigFactory.installDefaultProvider(ImageCaptureConfig.class, new ImageCaptureConfigProvider(i, cameraInfo, this.mContext));
            extendableUseCaseConfigFactory.installDefaultProvider(PreviewConfig.class, new PreviewConfigProvider(i, cameraInfo, this.mContext));
            try {
                camera.setExtendedConfig(new ExtensionsConfig.Builder().setExtensionMode(i).setCameraFilter(getFilter(i)).setUseCaseConfigFactory((UseCaseConfigFactory) extendableUseCaseConfigFactory).build());
            } catch (CameraUseCaseAdapter.CameraException e) {
                throw new IllegalArgumentException("Camera unable to support the extension with the attached UseCases. " + e);
            }
        } else {
            throw new IllegalArgumentException("Extension mode not supported on camera: " + i);
        }
    }

    public int getExtension(Camera camera) {
        CameraConfig extendedConfig = camera.getExtendedConfig();
        if (extendedConfig instanceof ExtensionsConfig) {
            return ((ExtensionsConfig) extendedConfig).getExtensionMode();
        }
        return 0;
    }

    public boolean isExtensionAvailable(Camera camera, int i) {
        return !getFilter(i).filter(new LinkedHashSet<>(camera.getCameraInternals())).isEmpty();
    }

    private CameraFilter getFilter(int i) {
        if (i == 1) {
            return new ExtensionCameraFilter(new BokehPreviewExtenderImpl(), new BokehImageCaptureExtenderImpl());
        }
        if (i == 2) {
            return new ExtensionCameraFilter(new HdrPreviewExtenderImpl(), new HdrImageCaptureExtenderImpl());
        }
        if (i == 3) {
            return new ExtensionCameraFilter(new NightPreviewExtenderImpl(), new NightImageCaptureExtenderImpl());
        }
        if (i == 4) {
            return new ExtensionCameraFilter(new BeautyPreviewExtenderImpl(), new BeautyImageCaptureExtenderImpl());
        }
        if (i == 5) {
            return new ExtensionCameraFilter(new AutoPreviewExtenderImpl(), new AutoImageCaptureExtenderImpl());
        }
        try {
            return CameraFilters.ANY;
        } catch (NoClassDefFoundError unused) {
            return CameraFilters.NONE;
        }
    }

    public List<List<UseCase>> checkUseCases(Camera camera, List<UseCase> list, int i) {
        throw new UnsupportedOperationException("not yet implemented");
    }
}
