package androidx.camera.extensions;

import androidx.camera.core.CameraSelector;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.Logger;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.HdrImageCaptureExtenderImpl;

public class HdrImageCaptureExtender extends ImageCaptureExtender {
    private static final String TAG = "HdrImageCaptureExtender";

    public static HdrImageCaptureExtender create(ImageCapture.Builder builder) {
        if (ExtensionVersion.isExtensionVersionSupported()) {
            try {
                return new VendorHdrImageCaptureExtender(builder);
            } catch (NoClassDefFoundError unused) {
                Logger.d(TAG, "No HDR image capture extender found. Falling back to default.");
            }
        }
        return new DefaultHdrImageCaptureExtender();
    }

    /* access modifiers changed from: package-private */
    public static class DefaultHdrImageCaptureExtender extends HdrImageCaptureExtender {
        @Override // androidx.camera.extensions.ImageCaptureExtender
        public void enableExtension(CameraSelector cameraSelector) {
        }

        @Override // androidx.camera.extensions.ImageCaptureExtender
        public boolean isExtensionAvailable(CameraSelector cameraSelector) {
            return false;
        }

        DefaultHdrImageCaptureExtender() {
            super();
        }
    }

    /* access modifiers changed from: package-private */
    public static class VendorHdrImageCaptureExtender extends HdrImageCaptureExtender {
        private final HdrImageCaptureExtenderImpl mImpl = new HdrImageCaptureExtenderImpl();

        VendorHdrImageCaptureExtender(ImageCapture.Builder builder) {
            super();
            init(builder, this.mImpl, ExtensionsManager.EffectMode.HDR);
        }
    }

    private HdrImageCaptureExtender() {
    }
}
