package androidx.camera.extensions;

import androidx.camera.core.CameraSelector;
import androidx.camera.core.Logger;
import androidx.camera.core.Preview;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.HdrPreviewExtenderImpl;

public class HdrPreviewExtender extends PreviewExtender {
    private static final String TAG = "HdrPreviewExtender";

    public static HdrPreviewExtender create(Preview.Builder builder) {
        if (ExtensionVersion.isExtensionVersionSupported()) {
            try {
                return new VendorHdrPreviewExtender(builder);
            } catch (NoClassDefFoundError unused) {
                Logger.d(TAG, "No HDR preview extender found. Falling back to default.");
            }
        }
        return new DefaultHdrPreviewExtender();
    }

    /* access modifiers changed from: package-private */
    public static class DefaultHdrPreviewExtender extends HdrPreviewExtender {
        @Override // androidx.camera.extensions.PreviewExtender
        public void enableExtension(CameraSelector cameraSelector) {
        }

        @Override // androidx.camera.extensions.PreviewExtender
        public boolean isExtensionAvailable(CameraSelector cameraSelector) {
            return false;
        }

        DefaultHdrPreviewExtender() {
            super();
        }
    }

    /* access modifiers changed from: package-private */
    public static class VendorHdrPreviewExtender extends HdrPreviewExtender {
        private final HdrPreviewExtenderImpl mImpl = new HdrPreviewExtenderImpl();

        VendorHdrPreviewExtender(Preview.Builder builder) {
            super();
            init(builder, this.mImpl, ExtensionsManager.EffectMode.HDR);
        }
    }

    private HdrPreviewExtender() {
    }
}
