package androidx.camera.extensions;

import androidx.camera.core.CameraSelector;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.Logger;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.NightImageCaptureExtenderImpl;

public class NightImageCaptureExtender extends ImageCaptureExtender {
    private static final String TAG = "NightICExtender";

    public static NightImageCaptureExtender create(ImageCapture.Builder builder) {
        if (ExtensionVersion.isExtensionVersionSupported()) {
            try {
                return new VendorNightImageCaptureExtender(builder);
            } catch (NoClassDefFoundError unused) {
                Logger.d(TAG, "No night image capture extender found. Falling back to default.");
            }
        }
        return new DefaultNightImageCaptureExtender();
    }

    /* access modifiers changed from: package-private */
    public static class DefaultNightImageCaptureExtender extends NightImageCaptureExtender {
        @Override // androidx.camera.extensions.ImageCaptureExtender
        public void enableExtension(CameraSelector cameraSelector) {
        }

        @Override // androidx.camera.extensions.ImageCaptureExtender
        public boolean isExtensionAvailable(CameraSelector cameraSelector) {
            return false;
        }

        DefaultNightImageCaptureExtender() {
            super();
        }
    }

    /* access modifiers changed from: package-private */
    public static class VendorNightImageCaptureExtender extends NightImageCaptureExtender {
        private final NightImageCaptureExtenderImpl mImpl = new NightImageCaptureExtenderImpl();

        VendorNightImageCaptureExtender(ImageCapture.Builder builder) {
            super();
            init(builder, this.mImpl, ExtensionsManager.EffectMode.NIGHT);
        }
    }

    private NightImageCaptureExtender() {
    }
}
