package androidx.camera.extensions;

import androidx.camera.core.CameraSelector;
import androidx.camera.core.Logger;
import androidx.camera.core.Preview;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.NightPreviewExtenderImpl;

public class NightPreviewExtender extends PreviewExtender {
    private static final String TAG = "NightPreviewExtender";

    public static NightPreviewExtender create(Preview.Builder builder) {
        if (ExtensionVersion.isExtensionVersionSupported()) {
            try {
                return new VendorNightPreviewExtender(builder);
            } catch (NoClassDefFoundError unused) {
                Logger.d(TAG, "No night preview extender found. Falling back to default.");
            }
        }
        return new DefaultNightPreviewExtender();
    }

    /* access modifiers changed from: package-private */
    public static class DefaultNightPreviewExtender extends NightPreviewExtender {
        @Override // androidx.camera.extensions.PreviewExtender
        public void enableExtension(CameraSelector cameraSelector) {
        }

        @Override // androidx.camera.extensions.PreviewExtender
        public boolean isExtensionAvailable(CameraSelector cameraSelector) {
            return false;
        }

        DefaultNightPreviewExtender() {
            super();
        }
    }

    /* access modifiers changed from: package-private */
    public static class VendorNightPreviewExtender extends NightPreviewExtender {
        private final NightPreviewExtenderImpl mImpl = new NightPreviewExtenderImpl();

        VendorNightPreviewExtender(Preview.Builder builder) {
            super();
            init(builder, this.mImpl, ExtensionsManager.EffectMode.NIGHT);
        }
    }

    private NightPreviewExtender() {
    }
}
