package androidx.camera.extensions.internal;

import android.content.Context;
import android.util.Pair;
import android.util.Size;
import androidx.camera.camera2.impl.Camera2ImplConfig;
import androidx.camera.camera2.impl.CameraEventCallbacks;
import androidx.camera.camera2.interop.Camera2CameraInfo;
import androidx.camera.core.CameraInfo;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.UseCase;
import androidx.camera.core.impl.ConfigProvider;
import androidx.camera.core.impl.ImageCaptureConfig;
import androidx.camera.core.impl.OptionsBundle;
import androidx.camera.extensions.ImageCaptureExtender;
import androidx.camera.extensions.impl.AutoImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.BeautyImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.BokehImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.CaptureProcessorImpl;
import androidx.camera.extensions.impl.HdrImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.ImageCaptureExtenderImpl;
import androidx.camera.extensions.impl.NightImageCaptureExtenderImpl;
import java.util.List;

public class ImageCaptureConfigProvider implements ConfigProvider<ImageCaptureConfig> {
    private Context mContext;
    private ImageCaptureExtenderImpl mImpl;

    public ImageCaptureConfigProvider(int i, CameraInfo cameraInfo, Context context) {
        if (i == 1) {
            this.mImpl = new BokehImageCaptureExtenderImpl();
        } else if (i == 2) {
            this.mImpl = new HdrImageCaptureExtenderImpl();
        } else if (i == 3) {
            this.mImpl = new NightImageCaptureExtenderImpl();
        } else if (i == 4) {
            this.mImpl = new BeautyImageCaptureExtenderImpl();
        } else if (i == 5) {
            try {
                this.mImpl = new AutoImageCaptureExtenderImpl();
            } catch (NoClassDefFoundError unused) {
                throw new IllegalArgumentException("Extension mode does not exist: " + i);
            }
        } else {
            return;
        }
        this.mContext = context;
        this.mImpl.init(Camera2CameraInfo.fromCameraInfo(cameraInfo).getCameraId(), Camera2CameraInfo.extractCameraCharacteristics(cameraInfo));
    }

    @Override // androidx.camera.core.impl.ConfigProvider
    public ImageCaptureConfig getConfig() {
        if (this.mImpl == null) {
            return new ImageCaptureConfig(OptionsBundle.emptyBundle());
        }
        ImageCapture.Builder builder = new ImageCapture.Builder();
        CaptureProcessorImpl captureProcessor = this.mImpl.getCaptureProcessor();
        if (captureProcessor != null) {
            builder.setCaptureProcessor(new AdaptingCaptureProcessor(captureProcessor));
        }
        if (this.mImpl.getMaxCaptureStage() > 0) {
            builder.setMaxCaptureStages(this.mImpl.getMaxCaptureStage());
        }
        ImageCaptureExtender.ImageCaptureAdapter imageCaptureAdapter = new ImageCaptureExtender.ImageCaptureAdapter(this.mImpl, this.mContext);
        new Camera2ImplConfig.Extender(builder).setCameraEventCallback(new CameraEventCallbacks(imageCaptureAdapter));
        builder.setUseCaseEventCallback((UseCase.EventCallback) imageCaptureAdapter);
        builder.setCaptureBundle(imageCaptureAdapter);
        List<Pair<Integer, Size[]>> supportedResolutions = ImageCaptureExtender.getSupportedResolutions(this.mImpl);
        if (supportedResolutions != null) {
            builder.setSupportedResolutions(supportedResolutions);
        }
        return builder.getUseCaseConfig();
    }
}
