package androidx.camera.view.preview.transform;

import android.util.Pair;
import android.view.View;
import androidx.camera.view.PreviewView;
import androidx.camera.view.preview.transform.transformation.ScaleTransformation;
import androidx.camera.view.preview.transform.transformation.Transformation;
import androidx.camera.view.preview.transform.transformation.TranslationTransformation;

final class ScaleTypeTransform {
    private ScaleTypeTransform() {
    }

    static Transformation getTransformation(View view, View view2, PreviewView.ScaleType scaleType, int i) {
        ScaleTransformation scale = getScale(view, view2, scaleType, i);
        return scale.add(getScaledTranslation(view, view2, scaleType, new Pair(Float.valueOf(view2.getScaleX() * scale.getScaleX()), Float.valueOf(view2.getScaleY() * scale.getScaleY())), i));
    }

    private static ScaleTransformation getScale(View view, View view2, PreviewView.ScaleType scaleType, int i) {
        switch (scaleType) {
            case FILL_START:
            case FILL_CENTER:
            case FILL_END:
                return ScaleTransform.fill(view, view2, i);
            case FIT_START:
            case FIT_CENTER:
            case FIT_END:
                return ScaleTransform.fit(view, view2, i);
            default:
                throw new IllegalArgumentException("Unknown scale type " + scaleType);
        }
    }

    private static TranslationTransformation getScaledTranslation(View view, View view2, PreviewView.ScaleType scaleType, Pair<Float, Float> pair, int i) {
        switch (scaleType) {
            case FILL_START:
            case FIT_START:
                return TranslationTransform.start(view2, pair, i);
            case FILL_CENTER:
            case FIT_CENTER:
                return TranslationTransform.center(view, view2);
            case FILL_END:
            case FIT_END:
                return TranslationTransform.end(view, view2, pair, i);
            default:
                throw new IllegalArgumentException("Unknown scale type " + scaleType);
        }
    }
}
