package com.befovy.fijkplayer;

import android.content.Context;
import android.content.res.AssetManager;
import android.graphics.Bitmap;
import android.graphics.SurfaceTexture;
import android.net.Uri;
import android.text.TextUtils;
import android.util.Log;
import android.view.Surface;
import androidx.core.app.NotificationCompat;
import com.bigbug.mmkvflutter.MmkvFlutterPlugin;
import com.google.android.exoplayer2.text.ttml.TtmlNode;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.view.TextureRegistry;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.atomic.AtomicInteger;
import tv.danmaku.ijk.media.player.IMediaPlayer;
import tv.danmaku.ijk.media.player.IjkEventListener;
import tv.danmaku.ijk.media.player.IjkMediaMeta;
import tv.danmaku.ijk.media.player.IjkMediaPlayer;

public class FijkPlayer implements MethodChannel.MethodCallHandler, IjkEventListener, IMediaPlayer.OnSnapShotListener {
    private static final int asyncPreparing = 2;
    private static final AtomicInteger atomicId = new AtomicInteger(0);
    private static final int completed = 6;
    private static final int end = 9;
    private static final int error = 8;
    private static final int idle = 0;
    private static final int initialized = 1;
    private static final int paused = 5;
    private static final int prepared = 3;
    private static final int started = 4;
    private static final int stopped = 7;
    private final FijkEngine mEngine;
    private final EventChannel mEventChannel;
    private final QueuingEventSink mEventSink = new QueuingEventSink();
    private int mHeight = 0;
    private final HostOption mHostOptions = new HostOption();
    private final IjkMediaPlayer mIjkMediaPlayer;
    private final boolean mJustSurface;
    private final MethodChannel mMethodChannel;
    private final int mPlayerId;
    private int mRotate = -1;
    private int mState;
    private Surface mSurface;
    private SurfaceTexture mSurfaceTexture;
    private TextureRegistry.SurfaceTextureEntry mSurfaceTextureEntry;
    private int mWidth = 0;

    private boolean isPlayable(int i) {
        return i == 4 || i == 5 || i == 6 || i == 3;
    }

    FijkPlayer(FijkEngine fijkEngine, boolean z) {
        this.mEngine = fijkEngine;
        this.mPlayerId = atomicId.incrementAndGet();
        this.mState = 0;
        this.mJustSurface = z;
        if (z) {
            this.mIjkMediaPlayer = null;
            this.mEventChannel = null;
            this.mMethodChannel = null;
            return;
        }
        this.mIjkMediaPlayer = new IjkMediaPlayer();
        this.mIjkMediaPlayer.addIjkEventListener(this);
        this.mIjkMediaPlayer.setOption(4, "enable-position-notify", 1);
        this.mIjkMediaPlayer.setOption(4, "start-on-prepared", 0);
        BinaryMessenger messenger = this.mEngine.messenger();
        this.mMethodChannel = new MethodChannel(messenger, "befovy.com/fijkplayer/" + this.mPlayerId);
        this.mMethodChannel.setMethodCallHandler(this);
        this.mIjkMediaPlayer.setOnSnapShotListener(this);
        BinaryMessenger messenger2 = this.mEngine.messenger();
        this.mEventChannel = new EventChannel(messenger2, "befovy.com/fijkplayer/event/" + this.mPlayerId);
        this.mEventChannel.setStreamHandler(new EventChannel.StreamHandler() {
            /* class com.befovy.fijkplayer.FijkPlayer.AnonymousClass1 */

            @Override // io.flutter.plugin.common.EventChannel.StreamHandler
            public void onListen(Object obj, EventChannel.EventSink eventSink) {
                FijkPlayer.this.mEventSink.setDelegate(eventSink);
            }

            @Override // io.flutter.plugin.common.EventChannel.StreamHandler
            public void onCancel(Object obj) {
                FijkPlayer.this.mEventSink.setDelegate(null);
            }
        });
    }

    /* access modifiers changed from: package-private */
    public int getPlayerId() {
        return this.mPlayerId;
    }

    /* access modifiers changed from: package-private */
    public void setup() {
        if (!this.mJustSurface && this.mHostOptions.getIntOption("enable-snapshot", 0) > 0) {
            this.mIjkMediaPlayer.setAmcGlesRender();
            this.mIjkMediaPlayer.setOption(4, "overlay-format", "fcc-_es2");
        }
    }

    /* access modifiers changed from: package-private */
    public long setupSurface() {
        setup();
        if (this.mSurfaceTextureEntry == null) {
            TextureRegistry.SurfaceTextureEntry createSurfaceEntry = this.mEngine.createSurfaceEntry();
            this.mSurfaceTextureEntry = createSurfaceEntry;
            if (createSurfaceEntry != null) {
                this.mSurfaceTexture = createSurfaceEntry.surfaceTexture();
                this.mSurface = new Surface(this.mSurfaceTexture);
            }
            if (!this.mJustSurface) {
                this.mIjkMediaPlayer.setSurface(this.mSurface);
            }
        }
        TextureRegistry.SurfaceTextureEntry surfaceTextureEntry = this.mSurfaceTextureEntry;
        if (surfaceTextureEntry != null) {
            return surfaceTextureEntry.id();
        }
        Log.e("FIJKPLAYER", "setup surface, null SurfaceTextureEntry");
        return 0;
    }

    /* access modifiers changed from: package-private */
    public void release() {
        if (!this.mJustSurface) {
            handleEvent(700, 9, this.mState, null);
            this.mIjkMediaPlayer.release();
        }
        TextureRegistry.SurfaceTextureEntry surfaceTextureEntry = this.mSurfaceTextureEntry;
        if (surfaceTextureEntry != null) {
            surfaceTextureEntry.release();
            this.mSurfaceTextureEntry = null;
        }
        SurfaceTexture surfaceTexture = this.mSurfaceTexture;
        if (surfaceTexture != null) {
            surfaceTexture.release();
            this.mSurfaceTexture = null;
        }
        Surface surface = this.mSurface;
        if (surface != null) {
            surface.release();
            this.mSurface = null;
        }
        if (!this.mJustSurface) {
            this.mMethodChannel.setMethodCallHandler(null);
            this.mEventChannel.setStreamHandler(null);
        }
    }

    private void onStateChanged(int i, int i2) {
        if (i == 4 && i2 != 4) {
            this.mEngine.onPlayingChange(1);
            if (this.mHostOptions.getIntOption("request-audio-focus", 0) == 1) {
                this.mEngine.audioFocus(true);
            }
            if (this.mHostOptions.getIntOption("request-screen-on", 0) == 1) {
                this.mEngine.setScreenOn(true);
            }
        } else if (i != 4 && i2 == 4) {
            this.mEngine.onPlayingChange(-1);
            if (this.mHostOptions.getIntOption("release-audio-focus", 0) == 1) {
                this.mEngine.audioFocus(false);
            }
            if (this.mHostOptions.getIntOption("request-screen-on", 0) == 1) {
                this.mEngine.setScreenOn(false);
            }
        }
        if (isPlayable(i) && !isPlayable(i2)) {
            this.mEngine.onPlayableChange(1);
        } else if (!isPlayable(i) && isPlayable(i2)) {
            this.mEngine.onPlayableChange(-1);
        }
    }

    private void handleEvent(int i, int i2, int i3, Object obj) {
        int i4;
        HashMap hashMap = new HashMap();
        if (i == 100) {
            this.mEventSink.error(String.valueOf(i2), obj.toString(), Integer.valueOf(i3));
        } else if (i == 200) {
            hashMap.put(NotificationCompat.CATEGORY_EVENT, "prepared");
            hashMap.put("duration", Long.valueOf(this.mIjkMediaPlayer.getDuration()));
            this.mEventSink.success(hashMap);
        } else if (i == 400) {
            hashMap.put(NotificationCompat.CATEGORY_EVENT, "size_changed");
            int i5 = this.mRotate;
            if (i5 == 0 || i5 == 180) {
                hashMap.put("width", Integer.valueOf(i2));
                hashMap.put("height", Integer.valueOf(i3));
                this.mEventSink.success(hashMap);
            } else if (i5 == 90 || i5 == 270) {
                hashMap.put("width", Integer.valueOf(i3));
                hashMap.put("height", Integer.valueOf(i2));
                this.mEventSink.success(hashMap);
            }
            this.mWidth = i2;
            this.mHeight = i3;
        } else if (i == 510) {
            hashMap.put(NotificationCompat.CATEGORY_EVENT, "pos");
            hashMap.put("pos", Integer.valueOf(i2));
            this.mEventSink.success(hashMap);
        } else if (i == 600) {
            hashMap.put(NotificationCompat.CATEGORY_EVENT, "seek_complete");
            hashMap.put("pos", Integer.valueOf(i2));
            hashMap.put(NotificationCompat.CATEGORY_ERROR, Integer.valueOf(i3));
            this.mEventSink.success(hashMap);
        } else if (i != 700) {
            switch (i) {
                case 402:
                case 403:
                    hashMap.put(NotificationCompat.CATEGORY_EVENT, "rendering_start");
                    hashMap.put(IjkMediaMeta.IJKM_KEY_TYPE, i == 402 ? "video" : "audio");
                    this.mEventSink.success(hashMap);
                    return;
                case 404:
                    hashMap.put(NotificationCompat.CATEGORY_EVENT, "rotate");
                    hashMap.put("degree", Integer.valueOf(i2));
                    this.mRotate = i2;
                    this.mEventSink.success(hashMap);
                    int i6 = this.mWidth;
                    if (i6 > 0 && (i4 = this.mHeight) > 0) {
                        handleEvent(400, i6, i4, null);
                        return;
                    }
                    return;
                default:
                    switch (i) {
                        case 500:
                        case 501:
                            hashMap.put(NotificationCompat.CATEGORY_EVENT, "freeze");
                            hashMap.put(MmkvFlutterPlugin.VALUE, Boolean.valueOf(i == 500));
                            this.mEventSink.success(hashMap);
                            return;
                        case 502:
                            hashMap.put(NotificationCompat.CATEGORY_EVENT, "buffering");
                            hashMap.put(TtmlNode.TAG_HEAD, Integer.valueOf(i2));
                            hashMap.put("percent", Integer.valueOf(i3));
                            this.mEventSink.success(hashMap);
                            return;
                        default:
                            return;
                    }
            }
        } else {
            this.mState = i2;
            hashMap.put(NotificationCompat.CATEGORY_EVENT, "state_change");
            hashMap.put("new", Integer.valueOf(i2));
            hashMap.put("old", Integer.valueOf(i3));
            onStateChanged(i2, i3);
            this.mEventSink.success(hashMap);
        }
    }

    @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnSnapShotListener
    public void onSnapShot(IMediaPlayer iMediaPlayer, Bitmap bitmap, int i, int i2) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        bitmap.compress(Bitmap.CompressFormat.JPEG, 100, byteArrayOutputStream);
        bitmap.recycle();
        HashMap hashMap = new HashMap();
        hashMap.put("data", byteArrayOutputStream.toByteArray());
        hashMap.put("w", Integer.valueOf(i));
        hashMap.put("h", Integer.valueOf(i2));
        this.mMethodChannel.invokeMethod("_onSnapshot", hashMap);
    }

    @Override // tv.danmaku.ijk.media.player.IjkEventListener
    public void onEvent(IjkMediaPlayer ijkMediaPlayer, int i, int i2, int i3, Object obj) {
        if (!(i == 100 || i == 200 || i == 400 || i == 510 || i == 600 || i == 700)) {
            switch (i) {
                case 402:
                case 403:
                case 404:
                    break;
                default:
                    switch (i) {
                        case 500:
                        case 501:
                        case 502:
                            break;
                        default:
                            return;
                    }
            }
        }
        handleEvent(i, i2, i3, obj);
    }

    private void applyOptions(Object obj) {
        if (obj instanceof Map) {
            Map map = (Map) obj;
            for (Object obj2 : map.keySet()) {
                Object obj3 = map.get(obj2);
                if ((obj2 instanceof Integer) && (obj3 instanceof Map)) {
                    int intValue = ((Integer) obj2).intValue();
                    Map map2 = (Map) obj3;
                    for (Object obj4 : map2.keySet()) {
                        Object obj5 = map2.get(obj4);
                        boolean z = obj4 instanceof String;
                        if (z && intValue != 0) {
                            String str = (String) obj4;
                            if (obj5 instanceof Integer) {
                                this.mIjkMediaPlayer.setOption(intValue, str, (long) ((Integer) obj5).intValue());
                            } else if (obj5 instanceof String) {
                                this.mIjkMediaPlayer.setOption(intValue, str, (String) obj5);
                            }
                        } else if (z) {
                            String str2 = (String) obj4;
                            if (obj5 instanceof Integer) {
                                this.mHostOptions.addIntOption(str2, (Integer) obj5);
                            } else if (obj5 instanceof String) {
                                this.mHostOptions.addStrOption(str2, (String) obj5);
                            }
                        }
                    }
                }
            }
        }
    }

    @Override // io.flutter.plugin.common.MethodChannel.MethodCallHandler
    public void onMethodCall(MethodCall methodCall, MethodChannel.Result result) {
        if (methodCall.method.equals("setupSurface")) {
            result.success(Long.valueOf(setupSurface()));
            return;
        }
        long j = 0;
        if (methodCall.method.equals("setOption")) {
            Integer num = (Integer) methodCall.argument("cat");
            String str = (String) methodCall.argument(MmkvFlutterPlugin.KEY);
            if (methodCall.hasArgument("long")) {
                Integer num2 = (Integer) methodCall.argument("long");
                if (num != null && num.intValue() != 0) {
                    IjkMediaPlayer ijkMediaPlayer = this.mIjkMediaPlayer;
                    int intValue = num.intValue();
                    if (num2 != null) {
                        j = num2.longValue();
                    }
                    ijkMediaPlayer.setOption(intValue, str, j);
                } else if (num != null) {
                    this.mHostOptions.addIntOption(str, num2);
                }
            } else if (methodCall.hasArgument("str")) {
                String str2 = (String) methodCall.argument("str");
                if (num != null && num.intValue() != 0) {
                    this.mIjkMediaPlayer.setOption(num.intValue(), str, str2);
                } else if (num != null) {
                    this.mHostOptions.addStrOption(str, str2);
                }
            } else {
                Log.w("FIJKPLAYER", "error arguments for setOptions");
            }
            result.success(null);
        } else if (methodCall.method.equals("applyOptions")) {
            applyOptions(methodCall.arguments);
            result.success(null);
        } else {
            boolean z = false;
            int i = 1;
            if (methodCall.method.equals("setDataSource")) {
                Uri parse = Uri.parse((String) methodCall.argument(IjkMediaPlayer.OnNativeInvokeListener.ARG_URL));
                String str3 = "";
                if ("asset".equals(parse.getScheme())) {
                    String lookupKeyForAsset = this.mEngine.lookupKeyForAsset(parse.getPath() != null ? parse.getPath().substring(1) : str3, parse.getHost());
                    if (!TextUtils.isEmpty(lookupKeyForAsset)) {
                        parse = Uri.parse(lookupKeyForAsset);
                    }
                    z = true;
                }
                try {
                    Context context = this.mEngine.context();
                    if (z && context != null) {
                        AssetManager assets = context.getAssets();
                        if (parse.getPath() != null) {
                            str3 = parse.getPath();
                        }
                        this.mIjkMediaPlayer.setDataSource(new RawMediaDataSource(assets.open(str3, 1)));
                    } else if (context != null) {
                        if (!TextUtils.isEmpty(parse.getScheme())) {
                            if (!"file".equals(parse.getScheme())) {
                                this.mIjkMediaPlayer.setDataSource(this.mEngine.context(), parse);
                            }
                        }
                        if (parse.getPath() != null) {
                            str3 = parse.getPath();
                        }
                        this.mIjkMediaPlayer.setDataSource(new FileMediaDataSource(new File(str3)));
                    } else {
                        Log.e("FIJKPLAYER", "context null, can't setDataSource");
                    }
                    handleEvent(700, 1, -1, null);
                    if (context == null) {
                        handleEvent(700, 8, -1, null);
                    }
                    result.success(null);
                } catch (FileNotFoundException e) {
                    result.error("-875574348", "Local File not found:" + e.getMessage(), null);
                } catch (IOException e2) {
                    result.error("-1162824012", "Local IOException:" + e2.getMessage(), null);
                }
            } else if (methodCall.method.equals("prepareAsync")) {
                setup();
                this.mIjkMediaPlayer.prepareAsync();
                handleEvent(700, 2, -1, null);
                result.success(null);
            } else if (methodCall.method.equals(TtmlNode.START)) {
                this.mIjkMediaPlayer.start();
                result.success(null);
            } else if (methodCall.method.equals("pause")) {
                this.mIjkMediaPlayer.pause();
                result.success(null);
            } else if (methodCall.method.equals("stop")) {
                this.mIjkMediaPlayer.stop();
                handleEvent(700, 7, -1, null);
                result.success(null);
            } else if (methodCall.method.equals("reset")) {
                this.mIjkMediaPlayer.reset();
                handleEvent(700, 0, -1, null);
                result.success(null);
            } else if (methodCall.method.equals("getCurrentPosition")) {
                result.success(Long.valueOf(this.mIjkMediaPlayer.getCurrentPosition()));
            } else {
                float f = 1.0f;
                if (methodCall.method.equals("setVolume")) {
                    Double d = (Double) methodCall.argument("volume");
                    if (d != null) {
                        f = d.floatValue();
                    }
                    this.mIjkMediaPlayer.setVolume(f, f);
                    result.success(null);
                } else if (methodCall.method.equals("seekTo")) {
                    Integer num3 = (Integer) methodCall.argument("msec");
                    if (this.mState == 6) {
                        handleEvent(700, 5, -1, null);
                    }
                    IjkMediaPlayer ijkMediaPlayer2 = this.mIjkMediaPlayer;
                    if (num3 != null) {
                        j = num3.longValue();
                    }
                    ijkMediaPlayer2.seekTo(j);
                    result.success(null);
                } else if (methodCall.method.equals("setLoop")) {
                    Integer num4 = (Integer) methodCall.argument("loop");
                    IjkMediaPlayer ijkMediaPlayer3 = this.mIjkMediaPlayer;
                    if (num4 != null) {
                        i = num4.intValue();
                    }
                    ijkMediaPlayer3.setLoopCount(i);
                    result.success(null);
                } else if (methodCall.method.equals("setSpeed")) {
                    Double d2 = (Double) methodCall.argument("speed");
                    IjkMediaPlayer ijkMediaPlayer4 = this.mIjkMediaPlayer;
                    if (d2 != null) {
                        f = d2.floatValue();
                    }
                    ijkMediaPlayer4.setSpeed(f);
                    result.success(null);
                } else if (methodCall.method.equals("snapshot")) {
                    if (this.mHostOptions.getIntOption("enable-snapshot", 0) > 0) {
                        this.mIjkMediaPlayer.snapShot();
                    } else {
                        this.mMethodChannel.invokeMethod("_onSnapshot", "not support");
                    }
                    result.success(null);
                } else {
                    result.notImplemented();
                }
            }
        }
    }
}
