package com.befovy.fijkplayer;

import android.util.Log;
import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
import tv.danmaku.ijk.media.player.misc.IMediaDataSource;

class FileMediaDataSource implements IMediaDataSource {
    private RandomAccessFile mFile;
    private long mFileSize;

    public FileMediaDataSource(File file) {
        try {
            this.mFile = new RandomAccessFile(file, "r");
            this.mFileSize = this.mFile.length();
        } catch (IOException e) {
            this.mFile = null;
            this.mFileSize = -1;
            Log.e("DataSource", "failed to open RandomAccess" + e.getMessage());
        }
    }

    @Override // tv.danmaku.ijk.media.player.misc.IMediaDataSource
    public int readAt(long j, byte[] bArr, int i, int i2) {
        if (i2 == 0) {
            return 0;
        }
        RandomAccessFile randomAccessFile = this.mFile;
        if (randomAccessFile == null) {
            return -1;
        }
        try {
            if (randomAccessFile.getFilePointer() != j) {
                this.mFile.seek(j);
            }
            return this.mFile.read(bArr, 0, i2);
        } catch (IOException e) {
            Log.e("DataSource", "failed to read" + e.getMessage());
            return -1;
        }
    }

    @Override // tv.danmaku.ijk.media.player.misc.IMediaDataSource
    public long getSize() {
        return this.mFileSize;
    }

    @Override // tv.danmaku.ijk.media.player.misc.IMediaDataSource
    public void close() {
        RandomAccessFile randomAccessFile = this.mFile;
        if (randomAccessFile != null) {
            try {
                randomAccessFile.close();
                this.mFileSize = 0;
                this.mFile = null;
            } catch (IOException e) {
                Log.e("DataSource", "failed to close" + e.getMessage());
            }
        }
    }
}
