package com.flutter_webview_plugin;

import android.graphics.Bitmap;
import android.webkit.WebResourceRequest;
import android.webkit.WebResourceResponse;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import com.tekartik.sqflite.Constant;
import java.util.HashMap;
import java.util.regex.Pattern;
import tv.danmaku.ijk.media.player.IjkMediaMeta;
import tv.danmaku.ijk.media.player.IjkMediaPlayer;

public class BrowserClient extends WebViewClient {
    private Pattern invalidUrlPattern;

    public BrowserClient() {
        this(null);
    }

    public BrowserClient(String str) {
        this.invalidUrlPattern = null;
        if (str != null) {
            this.invalidUrlPattern = Pattern.compile(str);
        }
    }

    public void updateInvalidUrlRegex(String str) {
        if (str != null) {
            this.invalidUrlPattern = Pattern.compile(str);
        } else {
            this.invalidUrlPattern = null;
        }
    }

    public void onPageStarted(WebView webView, String str, Bitmap bitmap) {
        super.onPageStarted(webView, str, bitmap);
        HashMap hashMap = new HashMap();
        hashMap.put(IjkMediaPlayer.OnNativeInvokeListener.ARG_URL, str);
        hashMap.put(IjkMediaMeta.IJKM_KEY_TYPE, "startLoad");
        FlutterWebviewPlugin.channel.invokeMethod("onState", hashMap);
    }

    public void onPageFinished(WebView webView, String str) {
        super.onPageFinished(webView, str);
        HashMap hashMap = new HashMap();
        hashMap.put(IjkMediaPlayer.OnNativeInvokeListener.ARG_URL, str);
        FlutterWebviewPlugin.channel.invokeMethod("onUrlChanged", hashMap);
        hashMap.put(IjkMediaMeta.IJKM_KEY_TYPE, "finishLoad");
        FlutterWebviewPlugin.channel.invokeMethod("onState", hashMap);
    }

    @Override // android.webkit.WebViewClient
    public boolean shouldOverrideUrlLoading(WebView webView, WebResourceRequest webResourceRequest) {
        String uri = webResourceRequest.getUrl().toString();
        boolean checkInvalidUrl = checkInvalidUrl(uri);
        HashMap hashMap = new HashMap();
        hashMap.put(IjkMediaPlayer.OnNativeInvokeListener.ARG_URL, uri);
        hashMap.put(IjkMediaMeta.IJKM_KEY_TYPE, checkInvalidUrl ? "abortLoad" : "shouldStart");
        FlutterWebviewPlugin.channel.invokeMethod("onState", hashMap);
        return checkInvalidUrl;
    }

    @Override // android.webkit.WebViewClient
    public boolean shouldOverrideUrlLoading(WebView webView, String str) {
        boolean checkInvalidUrl = checkInvalidUrl(str);
        HashMap hashMap = new HashMap();
        hashMap.put(IjkMediaPlayer.OnNativeInvokeListener.ARG_URL, str);
        hashMap.put(IjkMediaMeta.IJKM_KEY_TYPE, checkInvalidUrl ? "abortLoad" : "shouldStart");
        FlutterWebviewPlugin.channel.invokeMethod("onState", hashMap);
        return checkInvalidUrl;
    }

    public void onReceivedHttpError(WebView webView, WebResourceRequest webResourceRequest, WebResourceResponse webResourceResponse) {
        super.onReceivedHttpError(webView, webResourceRequest, webResourceResponse);
        HashMap hashMap = new HashMap();
        hashMap.put(IjkMediaPlayer.OnNativeInvokeListener.ARG_URL, webResourceRequest.getUrl().toString());
        hashMap.put(Constant.PARAM_ERROR_CODE, Integer.toString(webResourceResponse.getStatusCode()));
        FlutterWebviewPlugin.channel.invokeMethod("onHttpError", hashMap);
    }

    public void onReceivedError(WebView webView, int i, String str, String str2) {
        super.onReceivedError(webView, i, str, str2);
        HashMap hashMap = new HashMap();
        hashMap.put(IjkMediaPlayer.OnNativeInvokeListener.ARG_URL, str2);
        hashMap.put(Constant.PARAM_ERROR_CODE, Integer.toString(i));
        FlutterWebviewPlugin.channel.invokeMethod("onHttpError", hashMap);
    }

    private boolean checkInvalidUrl(String str) {
        Pattern pattern = this.invalidUrlPattern;
        if (pattern == null) {
            return false;
        }
        return pattern.matcher(str).lookingAt();
    }
}
