package com.leeson.image_pickers;

import android.content.Intent;
import android.util.Log;
import com.leeson.image_pickers.activitys.PermissionActivity;
import com.leeson.image_pickers.activitys.PhotosActivity;
import com.leeson.image_pickers.activitys.SelectPicsActivity;
import com.leeson.image_pickers.activitys.VideoActivity;
import com.leeson.image_pickers.utils.Saver;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class MethodCallImpl implements MethodChannel.MethodCallHandler, PluginRegistry.ActivityResultListener {
    private static final int SAVE_IMAGE = 103;
    private static final int SAVE_IMAGE_DATA = 105;
    private static final int SELECT = 102;
    private static final int WRITE_SDCARD = 104;
    private ActivityPluginBinding activityPluginBinding;
    private byte[] data;
    private MethodChannel.Result result;

    public void setActivityPluginBinding(ActivityPluginBinding activityPluginBinding2) {
        this.activityPluginBinding = activityPluginBinding2;
        activityPluginBinding2.addActivityResultListener(this);
    }

    public ActivityPluginBinding getActivityPluginBinding() {
        return this.activityPluginBinding;
    }

    @Override // io.flutter.plugin.common.MethodChannel.MethodCallHandler
    public void onMethodCall(MethodCall methodCall, MethodChannel.Result result2) {
        this.result = result2;
        if ("getPickerPaths".equals(methodCall.method)) {
            Intent intent = new Intent(this.activityPluginBinding.getActivity(), SelectPicsActivity.class);
            intent.putExtra(SelectPicsActivity.GALLERY_MODE, (String) methodCall.argument("galleryMode"));
            intent.putExtra(SelectPicsActivity.UI_COLOR, (Serializable) ((Map) methodCall.argument("uiColor")));
            intent.putExtra(SelectPicsActivity.SELECT_COUNT, (Number) methodCall.argument("selectCount"));
            intent.putExtra(SelectPicsActivity.SHOW_CAMERA, (Boolean) methodCall.argument("showCamera"));
            intent.putExtra(SelectPicsActivity.ENABLE_CROP, (Boolean) methodCall.argument("enableCrop"));
            intent.putExtra(SelectPicsActivity.WIDTH, (Number) methodCall.argument("width"));
            intent.putExtra(SelectPicsActivity.HEIGHT, (Number) methodCall.argument("height"));
            intent.putExtra(SelectPicsActivity.COMPRESS_SIZE, (Number) methodCall.argument("compressSize"));
            intent.putExtra(SelectPicsActivity.CAMERA_MIME_TYPE, (String) methodCall.argument("cameraMimeType"));
            this.activityPluginBinding.getActivity().startActivityForResult(intent, 102);
        } else if ("previewImage".equals(methodCall.method)) {
            Intent intent2 = new Intent(this.activityPluginBinding.getActivity(), PhotosActivity.class);
            ArrayList arrayList = new ArrayList();
            arrayList.add(methodCall.argument("path").toString());
            intent2.putExtra(PhotosActivity.IMAGES, arrayList);
            this.activityPluginBinding.getActivity().startActivity(intent2);
        } else if ("previewImages".equals(methodCall.method)) {
            Intent intent3 = new Intent(this.activityPluginBinding.getActivity(), PhotosActivity.class);
            intent3.putExtra(PhotosActivity.IMAGES, (Serializable) ((List) methodCall.argument("paths")));
            intent3.putExtra(PhotosActivity.CURRENT_POSITION, (Number) methodCall.argument("initIndex"));
            this.activityPluginBinding.getActivity().startActivity(intent3);
        } else if ("previewVideo".equals(methodCall.method)) {
            Intent intent4 = new Intent(this.activityPluginBinding.getActivity(), VideoActivity.class);
            intent4.putExtra(VideoActivity.VIDEO_PATH, methodCall.argument("path").toString());
            intent4.putExtra(VideoActivity.THUMB_PATH, methodCall.argument("thumbPath").toString());
            this.activityPluginBinding.getActivity().startActivity(intent4);
        } else if ("saveImageToGallery".equals(methodCall.method)) {
            Intent intent5 = new Intent(this.activityPluginBinding.getActivity(), PermissionActivity.class);
            intent5.putExtra(PermissionActivity.PERMISSIONS, new String[]{"android.permission.WRITE_EXTERNAL_STORAGE", "android.permission.READ_EXTERNAL_STORAGE"});
            intent5.putExtra("imageUrl", methodCall.argument("path").toString());
            this.activityPluginBinding.getActivity().startActivityForResult(intent5, 103);
        } else if ("saveVideoToGallery".equals(methodCall.method)) {
            Intent intent6 = new Intent(this.activityPluginBinding.getActivity(), PermissionActivity.class);
            intent6.putExtra(PermissionActivity.PERMISSIONS, new String[]{"android.permission.WRITE_EXTERNAL_STORAGE", "android.permission.READ_EXTERNAL_STORAGE"});
            intent6.putExtra("videoUrl", methodCall.argument("path").toString());
            this.activityPluginBinding.getActivity().startActivityForResult(intent6, 104);
        } else if ("saveByteDataImageToGallery".equals(methodCall.method)) {
            Intent intent7 = new Intent(this.activityPluginBinding.getActivity(), PermissionActivity.class);
            intent7.putExtra(PermissionActivity.PERMISSIONS, new String[]{"android.permission.WRITE_EXTERNAL_STORAGE", "android.permission.READ_EXTERNAL_STORAGE"});
            this.data = (byte[]) methodCall.argument("uint8List");
            this.activityPluginBinding.getActivity().startActivityForResult(intent7, 105);
        } else {
            result2.notImplemented();
        }
    }

    @Override // io.flutter.plugin.common.PluginRegistry.ActivityResultListener
    public boolean onActivityResult(int i, int i2, Intent intent) {
        if (i == 102) {
            if (i2 != -1) {
                return true;
            }
            List list = (List) intent.getSerializableExtra(SelectPicsActivity.COMPRESS_PATHS);
            Log.e("onActivityResult", "onActivityResult: " + list.size() + " == " + this.result);
            MethodChannel.Result result2 = this.result;
            if (result2 == null) {
                return true;
            }
            result2.success(list);
            return true;
        } else if (i == 103) {
            if (i2 != -1) {
                return false;
            }
            new Saver(this.activityPluginBinding.getActivity()).saveImgToGallery(intent.getStringExtra("imageUrl"), new Saver.IFinishListener() {
                /* class com.leeson.image_pickers.MethodCallImpl.AnonymousClass1 */

                @Override // com.leeson.image_pickers.utils.Saver.IFinishListener
                public void onSuccess(Saver.FileInfo fileInfo) {
                    if (MethodCallImpl.this.result != null) {
                        MethodCallImpl.this.result.success(fileInfo.getPath());
                    }
                }

                @Override // com.leeson.image_pickers.utils.Saver.IFinishListener
                public void onFailed(String str) {
                    if (MethodCallImpl.this.result != null) {
                        MethodCallImpl.this.result.error("-1", str, str);
                    }
                }
            });
            return false;
        } else if (i == 104) {
            if (i2 != -1) {
                return false;
            }
            new Saver(this.activityPluginBinding.getActivity()).saveVideoToGallery(intent.getStringExtra("videoUrl"), new Saver.IFinishListener() {
                /* class com.leeson.image_pickers.MethodCallImpl.AnonymousClass2 */

                @Override // com.leeson.image_pickers.utils.Saver.IFinishListener
                public void onSuccess(Saver.FileInfo fileInfo) {
                    if (MethodCallImpl.this.result != null) {
                        MethodCallImpl.this.result.success(fileInfo.getPath());
                    }
                }

                @Override // com.leeson.image_pickers.utils.Saver.IFinishListener
                public void onFailed(String str) {
                    if (MethodCallImpl.this.result != null) {
                        MethodCallImpl.this.result.error("-1", str, str);
                    }
                }
            });
            return false;
        } else if (i != 105 || i2 != -1 || this.data == null) {
            return false;
        } else {
            new Saver(this.activityPluginBinding.getActivity()).saveByteDataToGallery(this.data, new Saver.IFinishListener() {
                /* class com.leeson.image_pickers.MethodCallImpl.AnonymousClass3 */

                @Override // com.leeson.image_pickers.utils.Saver.IFinishListener
                public void onSuccess(Saver.FileInfo fileInfo) {
                    if (MethodCallImpl.this.result != null) {
                        MethodCallImpl.this.result.success(fileInfo.getPath());
                    }
                    MethodCallImpl.this.data = null;
                }

                @Override // com.leeson.image_pickers.utils.Saver.IFinishListener
                public void onFailed(String str) {
                    if (MethodCallImpl.this.result != null) {
                        MethodCallImpl.this.result.error("-1", str, str);
                    }
                    MethodCallImpl.this.data = null;
                }
            });
            return false;
        }
    }
}
