package com.leeson.image_pickers.utils;

import android.content.ContentResolver;
import android.content.ContentUris;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.media.MediaScannerConnection;
import android.net.Uri;
import android.os.Build;
import android.os.Handler;
import android.os.ParcelFileDescriptor;
import android.provider.DocumentsContract;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.util.Base64;
import android.util.Log;
import android.view.View;
import com.google.android.exoplayer2.util.MimeTypes;
import com.leeson.image_pickers.AppPath;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.tools.PictureFileUtils;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.URLDecoder;
import java.net.URLEncoder;
import java.util.Locale;

public class Saver {
    private final String[][] MIME_MapTable = {new String[]{".3gp", MimeTypes.VIDEO_H263}, new String[]{".apk", "application/vnd.android.package-archive"}, new String[]{".asf", "video/x-ms-asf"}, new String[]{".avi", "video/x-msvideo"}, new String[]{".bin", "application/octet-stream"}, new String[]{".bmp", "image/bmp"}, new String[]{".c", "text/plain"}, new String[]{".class", "application/octet-stream"}, new String[]{".conf", "text/plain"}, new String[]{".cpp", "text/plain"}, new String[]{".doc", "application/msword"}, new String[]{".exe", "application/octet-stream"}, new String[]{".gif", "image/gif"}, new String[]{".gtar", "application/x-gtar"}, new String[]{".gz", "application/x-gzip"}, new String[]{".h", "text/plain"}, new String[]{".htm", "text/html"}, new String[]{".html", "text/html"}, new String[]{".jar", "application/java-archive"}, new String[]{".java", "text/plain"}, new String[]{".jpeg", PictureMimeType.MIME_TYPE_IMAGE}, new String[]{".jpg", PictureMimeType.MIME_TYPE_IMAGE}, new String[]{".js", "application/x-javascript"}, new String[]{".log", "text/plain"}, new String[]{".m3u", "audio/x-mpegurl"}, new String[]{".m4a", MimeTypes.AUDIO_AAC}, new String[]{".m4b", MimeTypes.AUDIO_AAC}, new String[]{".m4p", MimeTypes.AUDIO_AAC}, new String[]{".m4u", "video/vnd.mpegurl"}, new String[]{".m4v", "video/x-m4v"}, new String[]{".mov", "video/quicktime"}, new String[]{".mp2", "audio/x-mpeg"}, new String[]{PictureFileUtils.POST_AUDIO, "audio/x-mpeg"}, new String[]{PictureFileUtils.POST_VIDEO, "video/mp4"}, new String[]{".mpc", "application/vnd.mpohun.certificate"}, new String[]{".mpe", MimeTypes.VIDEO_MPEG}, new String[]{".mpeg", MimeTypes.VIDEO_MPEG}, new String[]{".mpg", MimeTypes.VIDEO_MPEG}, new String[]{".mpg4", "video/mp4"}, new String[]{".mpga", "audio/mpeg"}, new String[]{".msg", "application/vnd.ms-outlook"}, new String[]{".ogg", MimeTypes.AUDIO_OGG}, new String[]{".pdf", "application/pdf"}, new String[]{PictureMimeType.PNG, "image/png"}, new String[]{".pps", "application/vnd.ms-powerpoint"}, new String[]{".ppt", "application/vnd.ms-powerpoint"}, new String[]{".prop", "text/plain"}, new String[]{".rar", "application/x-rar-compressed"}, new String[]{".rc", "text/plain"}, new String[]{".rmvb", "audio/x-pn-realaudio"}, new String[]{".rtf", "application/rtf"}, new String[]{".sh", "text/plain"}, new String[]{".tar", "application/x-tar"}, new String[]{".tgz", "application/x-compressed"}, new String[]{".txt", "text/plain"}, new String[]{".wav", "audio/x-wav"}, new String[]{".wma", "audio/x-ms-wma"}, new String[]{".wmv", "audio/x-ms-wmv"}, new String[]{".wps", "application/vnd.ms-works"}, new String[]{".xml", "text/plain"}, new String[]{".z", "application/x-compress"}, new String[]{".zip", "application/zip"}, new String[]{".xlm", "application/vnd.ms-excel"}, new String[]{".xls", "application/vnd.ms-excel"}, new String[]{".xlsx", "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"}, new String[]{".xlt", "application/vnd.ms-excel"}, new String[]{".xlw", "application/vnd.ms-excel"}, new String[]{".xm", "audio/x-mod"}, new String[]{".xml", "text/plain"}, new String[]{".xml", "application/xml"}, new String[]{".xmz", "audio/x-mod"}, new String[]{".xof", "x-world/x-vrml"}, new String[]{".xpi", "application/x-xpinstall"}, new String[]{".xpm", "image/x-xpixmap"}, new String[]{".xsit", "text/xml"}, new String[]{".xsl", "text/xml"}, new String[]{".xul", "text/xul"}, new String[]{".xwd", "image/x-xwindowdump"}, new String[]{".xyz", "chemical/x-pdb"}, new String[]{".yz1", "application/x-yz1"}, new String[]{".z", "application/x-compress"}, new String[]{".zac", "application/x-zaurus-zac"}, new String[]{".docx", "application/msword"}, new String[]{".1", "application/vnd.android.package-archive"}};
    private AppPath appPath;
    private Context context;
    private MediaScannerConnection mediaScannerConnection;

    public interface IDownload {
        void onDownloadFailed(String str);

        void onDownloadSuccess(String str, String str2);
    }

    public interface IFinishListener {
        void onFailed(String str);

        void onSuccess(FileInfo fileInfo);
    }

    public Saver(Context context2) {
        this.context = context2;
        this.appPath = new AppPath(context2);
    }

    public void saveImg(String str, IFinishListener iFinishListener) {
        saveToAppPrivate(str, this.appPath.getAppImgDirPath(false), iFinishListener);
    }

    public void saveVideo(String str, IFinishListener iFinishListener) {
        saveToAppPrivate(str, this.appPath.getAppVideoDirPath(false), iFinishListener);
    }

    public void saveAudio(String str, IFinishListener iFinishListener) {
        saveToAppPrivate(str, this.appPath.getAppAudioDirPath(), iFinishListener);
    }

    public void saveMusicFile(String str, IFinishListener iFinishListener) {
        saveToAppPrivate(str, this.appPath.getAppMusicDirPath(), iFinishListener);
    }

    private void saveToAppPrivate(String str, String str2, final IFinishListener iFinishListener) {
        final File file = new File(str2, str.substring(str.lastIndexOf("/") + 1));
        if (!file.exists()) {
            download(str, str2, new IDownload() {
                /* class com.leeson.image_pickers.utils.Saver.AnonymousClass1 */

                @Override // com.leeson.image_pickers.utils.Saver.IDownload
                public void onDownloadSuccess(String str, String str2) {
                    if (iFinishListener != null) {
                        FileInfo fileInfo = new FileInfo();
                        fileInfo.setBeforeDownload(false);
                        fileInfo.setSize(file.length());
                        fileInfo.setPath(file.getAbsolutePath());
                        fileInfo.setUri(null);
                        iFinishListener.onSuccess(fileInfo);
                    }
                }

                @Override // com.leeson.image_pickers.utils.Saver.IDownload
                public void onDownloadFailed(String str) {
                    IFinishListener iFinishListener = iFinishListener;
                    if (iFinishListener != null) {
                        iFinishListener.onFailed(str);
                    }
                }
            });
        } else if (iFinishListener != null) {
            FileInfo fileInfo = new FileInfo();
            fileInfo.setBeforeDownload(true);
            fileInfo.setSize(file.length());
            fileInfo.setPath(file.getAbsolutePath());
            fileInfo.setUri(null);
            iFinishListener.onSuccess(fileInfo);
        }
    }

    public void saveImgToGallery(String str, final IFinishListener iFinishListener) {
        String substring = str.substring(str.lastIndexOf("/") + 1);
        String appImgDirPath = this.appPath.getAppImgDirPath(true);
        if (Build.VERSION.SDK_INT >= 29) {
            FileInfo fileInfo = getFileInfo(MediaStore.Images.Media.EXTERNAL_CONTENT_URI, "_display_name='" + substring + "'", "_id", "_size", "_data", "_size DESC");
            if (fileInfo == null || fileInfo.size <= 0) {
                download(str, appImgDirPath, new IDownload() {
                    /* class com.leeson.image_pickers.utils.Saver.AnonymousClass2 */

                    @Override // com.leeson.image_pickers.utils.Saver.IDownload
                    public void onDownloadSuccess(String str, String str2) {
                        FileInfo copyImgToPicture = Saver.this.copyImgToPicture(str, str2);
                        Saver.this.notifyGallery(copyImgToPicture.getPath());
                        new File(str).delete();
                        IFinishListener iFinishListener = iFinishListener;
                        if (iFinishListener != null) {
                            iFinishListener.onSuccess(copyImgToPicture);
                        }
                    }

                    @Override // com.leeson.image_pickers.utils.Saver.IDownload
                    public void onDownloadFailed(String str) {
                        IFinishListener iFinishListener = iFinishListener;
                        if (iFinishListener != null) {
                            iFinishListener.onFailed(str);
                        }
                    }
                });
                return;
            }
            if (iFinishListener != null) {
                iFinishListener.onSuccess(fileInfo);
            }
            notifyGallery(fileInfo.getPath());
            return;
        }
        checkOrDownload(str, appImgDirPath, substring, iFinishListener);
    }

    public void saveVideoToGallery(String str, final IFinishListener iFinishListener) {
        String substring = str.substring(str.lastIndexOf("/") + 1);
        String appVideoDirPath = this.appPath.getAppVideoDirPath(true);
        if (Build.VERSION.SDK_INT >= 29) {
            FileInfo fileInfo = getFileInfo(MediaStore.Video.Media.EXTERNAL_CONTENT_URI, "_display_name='" + substring + "'", "_id", "_size", "_data", "_size DESC");
            if (fileInfo == null || fileInfo.size <= 0) {
                download(str, appVideoDirPath, new IDownload() {
                    /* class com.leeson.image_pickers.utils.Saver.AnonymousClass3 */

                    @Override // com.leeson.image_pickers.utils.Saver.IDownload
                    public void onDownloadSuccess(String str, String str2) {
                        FileInfo copyToMovies = Saver.this.copyToMovies(str, str2);
                        Saver.this.notifyGallery(copyToMovies.getPath());
                        new File(str).delete();
                        IFinishListener iFinishListener = iFinishListener;
                        if (iFinishListener != null) {
                            iFinishListener.onSuccess(copyToMovies);
                        }
                    }

                    @Override // com.leeson.image_pickers.utils.Saver.IDownload
                    public void onDownloadFailed(String str) {
                        IFinishListener iFinishListener = iFinishListener;
                        if (iFinishListener != null) {
                            iFinishListener.onFailed(str);
                        }
                    }
                });
            } else if (iFinishListener != null) {
                iFinishListener.onSuccess(fileInfo);
            }
        } else {
            checkOrDownload(str, appVideoDirPath, substring, iFinishListener);
        }
    }

    public void saveFileToDownload(String str, final IFinishListener iFinishListener) {
        String substring = str.substring(str.lastIndexOf("/") + 1);
        String appDownloadDirPath = this.appPath.getAppDownloadDirPath();
        if (Build.VERSION.SDK_INT >= 29) {
            FileInfo fileInfo = getFileInfo(MediaStore.Downloads.EXTERNAL_CONTENT_URI, "_display_name='" + substring + "'", "_id", "_size", "_data", "_size DESC");
            if (fileInfo == null || fileInfo.size <= 0) {
                download(str, appDownloadDirPath, new IDownload() {
                    /* class com.leeson.image_pickers.utils.Saver.AnonymousClass4 */

                    @Override // com.leeson.image_pickers.utils.Saver.IDownload
                    public void onDownloadSuccess(String str, String str2) {
                        FileInfo copyToDownload = Saver.this.copyToDownload(str, str2);
                        Saver.this.notifyGallery(copyToDownload.getPath());
                        new File(str).delete();
                        IFinishListener iFinishListener = iFinishListener;
                        if (iFinishListener != null) {
                            iFinishListener.onSuccess(copyToDownload);
                        }
                    }

                    @Override // com.leeson.image_pickers.utils.Saver.IDownload
                    public void onDownloadFailed(String str) {
                        IFinishListener iFinishListener = iFinishListener;
                        if (iFinishListener != null) {
                            iFinishListener.onFailed(str);
                        }
                    }
                });
            } else if (iFinishListener != null) {
                iFinishListener.onSuccess(fileInfo);
            }
        } else {
            checkOrDownload(str, appDownloadDirPath, substring, iFinishListener);
        }
    }

    public void saveMusicFileToMusic(String str, final IFinishListener iFinishListener) {
        String substring = str.substring(str.lastIndexOf("/") + 1);
        String appMusicDirPath = this.appPath.getAppMusicDirPath();
        if (Build.VERSION.SDK_INT >= 29) {
            FileInfo fileInfo = getFileInfo(MediaStore.Audio.Media.EXTERNAL_CONTENT_URI, "_display_name='" + substring + "'", "_id", "_size", "_data", "_size DESC");
            if (fileInfo == null || fileInfo.size <= 0) {
                download(str, appMusicDirPath, new IDownload() {
                    /* class com.leeson.image_pickers.utils.Saver.AnonymousClass5 */

                    @Override // com.leeson.image_pickers.utils.Saver.IDownload
                    public void onDownloadSuccess(String str, String str2) {
                        FileInfo copyToMusic = Saver.this.copyToMusic(str, str2);
                        Saver.this.notifyGallery(copyToMusic.getPath());
                        new File(str).delete();
                        IFinishListener iFinishListener = iFinishListener;
                        if (iFinishListener != null) {
                            iFinishListener.onSuccess(copyToMusic);
                        }
                    }

                    @Override // com.leeson.image_pickers.utils.Saver.IDownload
                    public void onDownloadFailed(String str) {
                        IFinishListener iFinishListener = iFinishListener;
                        if (iFinishListener != null) {
                            iFinishListener.onFailed(str);
                        }
                    }
                });
            } else if (iFinishListener != null) {
                iFinishListener.onSuccess(fileInfo);
            }
        } else {
            checkOrDownload(str, appMusicDirPath, substring, iFinishListener);
        }
    }

    private void checkOrDownload(String str, String str2, String str3, final IFinishListener iFinishListener) {
        final FileInfo fileInfo = new FileInfo();
        final File file = new File(str2, str3);
        if (file.exists()) {
            fileInfo.setBeforeDownload(true);
            fileInfo.setUri(null);
            fileInfo.setPath(file.getAbsolutePath());
            fileInfo.setSize(file.length());
            if (iFinishListener != null) {
                iFinishListener.onSuccess(fileInfo);
            }
            notifyGallery(fileInfo.getPath());
            return;
        }
        download(str, str2, new IDownload() {
            /* class com.leeson.image_pickers.utils.Saver.AnonymousClass6 */

            @Override // com.leeson.image_pickers.utils.Saver.IDownload
            public void onDownloadSuccess(String str, String str2) {
                fileInfo.setBeforeDownload(false);
                fileInfo.setUri(null);
                fileInfo.setPath(file.getAbsolutePath());
                fileInfo.setSize(file.length());
                Saver.this.notifyGallery(fileInfo.getPath());
                IFinishListener iFinishListener = iFinishListener;
                if (iFinishListener != null) {
                    iFinishListener.onSuccess(fileInfo);
                }
            }

            @Override // com.leeson.image_pickers.utils.Saver.IDownload
            public void onDownloadFailed(String str) {
                IFinishListener iFinishListener = iFinishListener;
                if (iFinishListener != null) {
                    iFinishListener.onFailed(str);
                }
            }
        });
    }

    public void saveByteDataToGallery(final byte[] bArr, final IFinishListener iFinishListener) {
        new Thread(new Runnable() {
            /* class com.leeson.image_pickers.utils.Saver.AnonymousClass7 */

            public void run() {
                try {
                    File file = new File(Saver.this.appPath.getAppImgDirPath(true));
                    if (!file.exists()) {
                        file.mkdirs();
                    }
                    final String str = System.currentTimeMillis() + PictureMimeType.PNG;
                    final File file2 = new File(file, str);
                    FileOutputStream fileOutputStream = new FileOutputStream(file2, false);
                    fileOutputStream.write(bArr, 0, bArr.length);
                    fileOutputStream.flush();
                    fileOutputStream.close();
                    new Handler(Saver.this.context.getMainLooper()).post(new Runnable() {
                        /* class com.leeson.image_pickers.utils.Saver.AnonymousClass7.AnonymousClass1 */

                        public void run() {
                            FileInfo fileInfo = new FileInfo();
                            if (Build.VERSION.SDK_INT >= 29) {
                                fileInfo = Saver.this.copyImgToPicture(file2.getAbsolutePath(), str);
                            } else {
                                fileInfo.setBeforeDownload(false);
                                fileInfo.setUri(null);
                                fileInfo.setPath(file2.getAbsolutePath());
                                fileInfo.setSize(file2.length());
                            }
                            Saver.this.notifyGallery(fileInfo.getPath());
                            fileInfo.setPath(file2.getAbsolutePath());
                            if (iFinishListener != null) {
                                iFinishListener.onSuccess(fileInfo);
                            }
                        }
                    });
                } catch (Exception e) {
                    e.printStackTrace();
                    new Handler(Saver.this.context.getMainLooper()).post(new Runnable() {
                        /* class com.leeson.image_pickers.utils.Saver.AnonymousClass7.AnonymousClass2 */

                        public void run() {
                            if (iFinishListener != null) {
                                iFinishListener.onFailed(e.getMessage());
                            }
                        }
                    });
                }
            }
        }).start();
    }

    public void saveBase64ToToGallery(String str, IFinishListener iFinishListener) {
        saveByteDataToGallery(Base64.decode(str.split(",")[1], 0), iFinishListener);
    }

    public void saveViewToToGallery(View view, IFinishListener iFinishListener) {
        saveBitmapToToGallery(createViewBitmap(view), iFinishListener);
    }

    public Bitmap createViewBitmap(View view) {
        Bitmap createBitmap = Bitmap.createBitmap(view.getWidth(), view.getHeight(), Bitmap.Config.ARGB_8888);
        view.draw(new Canvas(createBitmap));
        return createBitmap;
    }

    public void saveBitmapToToGallery(Bitmap bitmap, final IFinishListener iFinishListener) {
        File file = new File(this.appPath.getAppImgDirPath(true));
        if (!file.exists()) {
            file.mkdirs();
        }
        final String str = System.currentTimeMillis() + (bitmap.hasAlpha() ? PictureMimeType.PNG : ".jpg");
        final File file2 = new File(file, str);
        try {
            FileOutputStream fileOutputStream = new FileOutputStream(file2, false);
            bitmap.compress(bitmap.hasAlpha() ? Bitmap.CompressFormat.PNG : Bitmap.CompressFormat.JPEG, 100, fileOutputStream);
            fileOutputStream.flush();
            fileOutputStream.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
        new Handler(this.context.getMainLooper()).post(new Runnable() {
            /* class com.leeson.image_pickers.utils.Saver.AnonymousClass8 */

            public void run() {
                FileInfo fileInfo = new FileInfo();
                if (Build.VERSION.SDK_INT >= 29) {
                    fileInfo = Saver.this.copyImgToPicture(file2.getAbsolutePath(), str);
                } else {
                    fileInfo.setBeforeDownload(false);
                    fileInfo.setUri(null);
                    fileInfo.setPath(file2.getAbsolutePath());
                    fileInfo.setSize(file2.length());
                }
                Saver.this.notifyGallery(fileInfo.getPath());
                IFinishListener iFinishListener = iFinishListener;
                if (iFinishListener != null) {
                    iFinishListener.onSuccess(fileInfo);
                }
            }
        });
    }

    public void download(final String str, String str2, final IDownload iDownload) {
        if (!TextUtils.isEmpty(str)) {
            File file = new File(str2);
            if (!file.exists()) {
                file.mkdirs();
            }
            final String substring = str.substring(str.lastIndexOf("/") + 1);
            final File file2 = new File(str2, substring);
            if (!file2.exists()) {
                try {
                    file2.createNewFile();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            new Thread(new Runnable() {
                /* class com.leeson.image_pickers.utils.Saver.AnonymousClass9 */
                FileOutputStream fileOutputStream = null;
                InputStream inputStream = null;

                public void run() {
                    try {
                        HttpURLConnection httpURLConnection = (HttpURLConnection) new URL(URLDecoder.decode(str.substring(0, str.lastIndexOf("/") + 1) + URLEncoder.encode(substring, "utf-8"), "utf-8")).openConnection();
                        httpURLConnection.setRequestMethod("GET");
                        httpURLConnection.setDoInput(true);
                        httpURLConnection.connect();
                        if (httpURLConnection.getResponseCode() == 200) {
                            this.inputStream = httpURLConnection.getInputStream();
                            this.fileOutputStream = new FileOutputStream(file2);
                            byte[] bArr = new byte[5120];
                            while (true) {
                                int read = this.inputStream.read(bArr);
                                if (read != -1) {
                                    this.fileOutputStream.write(bArr, 0, read);
                                } else {
                                    this.fileOutputStream.close();
                                    this.inputStream.close();
                                    new Handler(Saver.this.context.getMainLooper()).post(new Runnable() {
                                        /* class com.leeson.image_pickers.utils.Saver.AnonymousClass9.AnonymousClass1 */

                                        public void run() {
                                            if (iDownload != null) {
                                                iDownload.onDownloadSuccess(file2.getAbsolutePath(), substring);
                                            }
                                        }
                                    });
                                    return;
                                }
                            }
                        } else {
                            new Handler(Saver.this.context.getMainLooper()).post(new Runnable() {
                                /* class com.leeson.image_pickers.utils.Saver.AnonymousClass9.AnonymousClass2 */

                                public void run() {
                                    if (iDownload != null) {
                                        iDownload.onDownloadFailed("下载失败");
                                    }
                                }
                            });
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                        new Handler(Saver.this.context.getMainLooper()).post(new Runnable() {
                            /* class com.leeson.image_pickers.utils.Saver.AnonymousClass9.AnonymousClass3 */

                            public void run() {
                                if (iDownload != null) {
                                    iDownload.onDownloadFailed(e.getMessage());
                                }
                            }
                        });
                        try {
                            if (this.fileOutputStream != null) {
                                this.fileOutputStream.close();
                            }
                            if (this.inputStream != null) {
                                this.inputStream.close();
                            }
                        } catch (IOException e2) {
                            e2.printStackTrace();
                        }
                    }
                }
            }).start();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private FileInfo copyImgToPicture(String str, String str2) {
        ContentValues contentValues = new ContentValues();
        contentValues.put("_display_name", str2);
        contentValues.put("title", str2);
        contentValues.put("description", str2);
        contentValues.put("mime_type", "image/*");
        return copy(str, contentValues, MediaStore.Images.Media.EXTERNAL_CONTENT_URI);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private FileInfo copyToMovies(String str, String str2) {
        ContentValues contentValues = new ContentValues();
        contentValues.put("_display_name", str2);
        contentValues.put("title", str2);
        contentValues.put("description", str2);
        contentValues.put("mime_type", "video/*");
        return copy(str, contentValues, MediaStore.Video.Media.EXTERNAL_CONTENT_URI);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private FileInfo copyToDownload(String str, String str2) {
        ContentValues contentValues = new ContentValues();
        contentValues.put("_display_name", str2);
        contentValues.put("title", str2);
        contentValues.put("mime_type", getMIMEType(str2));
        return copy(str, contentValues, MediaStore.Downloads.EXTERNAL_CONTENT_URI);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private FileInfo copyToMusic(String str, String str2) {
        ContentValues contentValues = new ContentValues();
        contentValues.put("_display_name", str2);
        contentValues.put("title", str2);
        contentValues.put("mime_type", getMIMEType(str2));
        return copy(str, contentValues, MediaStore.Audio.Media.EXTERNAL_CONTENT_URI);
    }

    /* JADX WARNING: Removed duplicated region for block: B:27:0x0062  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x006a  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x0077 A[SYNTHETIC, Splitter:B:36:0x0077] */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x007f A[Catch:{ IOException -> 0x007b }] */
    private FileInfo copy(String str, ContentValues contentValues, Uri uri) {
        Throwable th;
        FileInputStream fileInputStream;
        OutputStream outputStream;
        Exception e;
        FileInfo fileInfo = new FileInfo();
        fileInfo.setBeforeDownload(false);
        ContentResolver contentResolver = this.context.getContentResolver();
        Uri insert = contentResolver.insert(uri, contentValues);
        FileInputStream fileInputStream2 = null;
        r11 = null;
        OutputStream outputStream2 = null;
        OutputStream outputStream3 = null;
        try {
            fileInputStream = new FileInputStream(new File(str));
            if (insert != null) {
                try {
                    fileInfo.setUri(insert);
                    outputStream2 = contentResolver.openOutputStream(insert);
                    fileInfo.setPath(getPath(this.context, insert));
                } catch (Exception e2) {
                    e = e2;
                    outputStream = null;
                    fileInputStream2 = fileInputStream;
                    try {
                        e.printStackTrace();
                        if (fileInputStream2 != null) {
                        }
                        if (outputStream != null) {
                        }
                        return fileInfo;
                    } catch (Throwable th2) {
                        th = th2;
                        fileInputStream = fileInputStream2;
                        outputStream3 = outputStream;
                        if (fileInputStream != null) {
                            try {
                                fileInputStream.close();
                            } catch (IOException e3) {
                                e3.printStackTrace();
                                throw th;
                            }
                        }
                        if (outputStream3 != null) {
                            outputStream3.close();
                        }
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    if (fileInputStream != null) {
                    }
                    if (outputStream3 != null) {
                    }
                    throw th;
                }
            }
            if (outputStream2 != null) {
                byte[] bArr = new byte[5120];
                long j = 0;
                while (true) {
                    int read = fileInputStream.read(bArr);
                    if (read == -1) {
                        break;
                    }
                    j += (long) read;
                    outputStream2.write(bArr, 0, read);
                }
                fileInfo.setSize(j);
            }
            try {
                fileInputStream.close();
                if (outputStream2 != null) {
                    outputStream2.close();
                }
            } catch (IOException e4) {
                e4.printStackTrace();
            }
        } catch (Exception e5) {
            e = e5;
            outputStream = null;
            e.printStackTrace();
            if (fileInputStream2 != null) {
                fileInputStream2.close();
            }
            if (outputStream != null) {
                outputStream.close();
            }
            return fileInfo;
        } catch (Throwable th4) {
            th = th4;
            fileInputStream = null;
            if (fileInputStream != null) {
            }
            if (outputStream3 != null) {
            }
            throw th;
        }
        return fileInfo;
    }

    private void test(Uri uri) {
        Cursor query = this.context.getContentResolver().query(uri, null, null, null, null);
        if (query != null && query.moveToFirst()) {
            while (query.moveToNext()) {
                Log.e("cursor", "getFileInfo: cursor= > " + query.getString(query.getColumnIndex("_data")) + "==: " + query.getString(query.getColumnIndex("_display_name")));
            }
            query.close();
        }
    }

    private FileInfo getFileInfo(Uri uri, String str, String str2, String str3, String str4, String str5) {
        Cursor query;
        ContentResolver contentResolver = this.context.getContentResolver();
        if (contentResolver == null || (query = contentResolver.query(uri, new String[]{str2, str3, str4}, str, null, str5)) == null || !query.moveToFirst()) {
            return null;
        }
        FileInfo fileInfo = new FileInfo();
        fileInfo.setBeforeDownload(true);
        int i = query.getInt(query.getColumnIndex(str2));
        fileInfo.setUri(Uri.withAppendedPath(uri, "" + i));
        fileInfo.setSize(query.getLong(query.getColumnIndex(str3)));
        fileInfo.setPath(query.getString(query.getColumnIndex(str4)));
        query.close();
        return fileInfo;
    }

    public boolean isFileExists(Uri uri) {
        if (uri == null) {
            return false;
        }
        try {
            ParcelFileDescriptor openFileDescriptor = this.context.getContentResolver().openFileDescriptor(uri, "r");
            if (openFileDescriptor == null) {
                return false;
            }
            try {
                openFileDescriptor.close();
                return true;
            } catch (IOException e) {
                e.printStackTrace();
                return true;
            }
        } catch (Exception e2) {
            e2.printStackTrace();
            return false;
        }
    }

    public static class FileInfo {
        private boolean isBeforeDownload;
        private String path;
        private long size;
        private Uri uri;

        public boolean isBeforeDownload() {
            return this.isBeforeDownload;
        }

        public void setBeforeDownload(boolean z) {
            this.isBeforeDownload = z;
        }

        public String getPath() {
            return this.path;
        }

        public void setPath(String str) {
            this.path = str;
        }

        public long getSize() {
            return this.size;
        }

        public void setSize(long j) {
            this.size = j;
        }

        public Uri getUri() {
            return this.uri;
        }

        public void setUri(Uri uri2) {
            this.uri = uri2;
        }

        public String toString() {
            return "FileInfo{size=" + this.size + ", uri=" + this.uri + ", path='" + this.path + '\'' + ", isBeforeDownload=" + this.isBeforeDownload + '}';
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyGallery(final String str) {
        this.mediaScannerConnection = new MediaScannerConnection(this.context, new MediaScannerConnection.MediaScannerConnectionClient() {
            /* class com.leeson.image_pickers.utils.Saver.AnonymousClass10 */

            public void onMediaScannerConnected() {
                Saver.this.mediaScannerConnection.scanFile(str, null);
            }

            public void onScanCompleted(String str, Uri uri) {
                Saver.this.mediaScannerConnection.disconnect();
            }
        });
        this.mediaScannerConnection.connect();
    }

    public static boolean isExternalStorageDocument(Uri uri) {
        return "com.android.externalstorage.documents".equals(uri.getAuthority());
    }

    public static boolean isDownloadsDocument(Uri uri) {
        return "com.android.providers.downloads.documents".equals(uri.getAuthority());
    }

    public static boolean isMediaDocument(Uri uri) {
        return "com.android.providers.media.documents".equals(uri.getAuthority());
    }

    public static boolean isGooglePhotosUri(Uri uri) {
        return "com.google.android.apps.photos.content".equals(uri.getAuthority());
    }

    /* JADX WARNING: Code restructure failed: missing block: B:12:0x002b, code lost:
        if (r8 != null) goto L_0x002d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x002d, code lost:
        r8.close();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x004f, code lost:
        if (r8 != null) goto L_0x002d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0052, code lost:
        return null;
     */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x0056  */
    public static String getDataColumn(Context context2, Uri uri, String str, String[] strArr) {
        Throwable th;
        Cursor cursor;
        IllegalArgumentException e;
        try {
            cursor = context2.getContentResolver().query(uri, new String[]{"_data"}, str, strArr, null);
            if (cursor != null) {
                try {
                    if (cursor.moveToFirst()) {
                        String string = cursor.getString(cursor.getColumnIndexOrThrow("_data"));
                        if (cursor != null) {
                            cursor.close();
                        }
                        return string;
                    }
                } catch (IllegalArgumentException e2) {
                    e = e2;
                    try {
                        Log.i("==>", String.format(Locale.getDefault(), "getDataColumn: _data - [%s]", e.getMessage()));
                    } catch (Throwable th2) {
                        th = th2;
                        if (cursor != null) {
                            cursor.close();
                        }
                        throw th;
                    }
                }
            }
        } catch (IllegalArgumentException e3) {
            e = e3;
            cursor = null;
            Log.i("==>", String.format(Locale.getDefault(), "getDataColumn: _data - [%s]", e.getMessage()));
        } catch (Throwable th3) {
            th = th3;
            cursor = null;
            if (cursor != null) {
            }
            throw th;
        }
    }

    public String getPath(Context context2, Uri uri) {
        Uri uri2 = null;
        if (!(Build.VERSION.SDK_INT >= 19) || !DocumentsContract.isDocumentUri(context2, uri)) {
            if ("content".equalsIgnoreCase(uri.getScheme())) {
                if (isGooglePhotosUri(uri)) {
                    return uri.getLastPathSegment();
                }
                return getDataColumn(context2, uri, null, null);
            } else if ("file".equalsIgnoreCase(uri.getScheme())) {
                return uri.getPath();
            }
        } else if (isDownloadsDocument(uri)) {
            return getDataColumn(context2, ContentUris.withAppendedId(Uri.parse("content://downloads/public_downloads"), Long.valueOf(DocumentsContract.getDocumentId(uri)).longValue()), null, null);
        } else if (isMediaDocument(uri)) {
            String[] split = DocumentsContract.getDocumentId(uri).split(":");
            String str = split[0];
            if ("image".equals(str)) {
                uri2 = MediaStore.Images.Media.EXTERNAL_CONTENT_URI;
            } else if ("video".equals(str)) {
                uri2 = MediaStore.Video.Media.EXTERNAL_CONTENT_URI;
            } else if ("audio".equals(str)) {
                uri2 = MediaStore.Audio.Media.EXTERNAL_CONTENT_URI;
            }
            return getDataColumn(context2, uri2, "_id=?", new String[]{split[1]});
        }
        return null;
    }

    public String getMIMEType(String str) {
        int lastIndexOf = str.lastIndexOf(".");
        if (lastIndexOf < 0) {
            return "*/*";
        }
        String lowerCase = str.substring(lastIndexOf).toLowerCase();
        if (TextUtils.isEmpty(lowerCase)) {
            return "*/*";
        }
        int i = 0;
        while (true) {
            String[][] strArr = this.MIME_MapTable;
            if (i >= strArr.length) {
                return "*/*";
            }
            if (lowerCase.equals(strArr[i][0])) {
                return this.MIME_MapTable[i][1];
            }
            i++;
        }
    }
}
