package com.luck.picture.lib;

import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.view.View;
import androidx.appcompat.app.AppCompatActivity;
import com.luck.picture.lib.broadcast.BroadcastAction;
import com.luck.picture.lib.broadcast.BroadcastManager;
import com.luck.picture.lib.compress.Luban;
import com.luck.picture.lib.compress.OnCompressListener;
import com.luck.picture.lib.compress.OnRenameListener;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.dialog.PictureLoadingDialog;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.immersive.ImmersiveManage;
import com.luck.picture.lib.immersive.NavBarUtils;
import com.luck.picture.lib.permissions.PermissionChecker;
import com.luck.picture.lib.tools.AndroidQTransformUtils;
import com.luck.picture.lib.tools.AttrsUtils;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.yalantis.ucrop.UCrop;
import com.yalantis.ucrop.UCropMulti;
import com.yalantis.ucrop.model.CutInfo;
import java.io.File;
import java.util.ArrayList;
import java.util.List;

public abstract class PictureBaseActivity extends AppCompatActivity implements Handler.Callback {
    private static final int MSG_ASY_COMPRESSION_RESULT_SUCCESS = 300;
    private static final int MSG_CHOOSE_RESULT_SUCCESS = 200;
    protected String cameraPath;
    protected int colorPrimary;
    protected int colorPrimaryDark;
    protected PictureSelectionConfig config;
    protected View container;
    protected boolean isPreviewLoading;
    protected Handler mHandler;
    protected PictureLoadingDialog mLoadingDialog;
    protected boolean numComplete;
    protected boolean openWhiteStatusBar;
    protected String originalPath;
    protected List<LocalMedia> selectionMedias;

    /* access modifiers changed from: protected */
    public Context getContext() {
        return this;
    }

    public abstract int getResourceId();

    /* access modifiers changed from: protected */
    public void initPictureSelectorStyle() {
    }

    /* access modifiers changed from: protected */
    public void initWidgets() {
    }

    public boolean isImmersive() {
        return true;
    }

    public boolean isRequestedOrientation() {
        return true;
    }

    public void immersive() {
        ImmersiveManage.immersiveAboveAPI23(this, this.colorPrimaryDark, this.colorPrimary, this.openWhiteStatusBar);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onCreate(Bundle bundle) {
        if (bundle != null) {
            this.config = (PictureSelectionConfig) bundle.getParcelable(PictureConfig.EXTRA_CONFIG);
            this.cameraPath = bundle.getString(PictureConfig.EXTRA_BUNDLE_CAMERA_PATH);
            this.originalPath = bundle.getString(PictureConfig.EXTRA_BUNDLE_ORIGINAL_PATH);
        } else if (this.config == null) {
            this.config = PictureSelectionConfig.getInstance();
        }
        if (!this.config.camera) {
            setTheme(this.config.themeStyleId);
        }
        super.onCreate(bundle);
        if (isRequestedOrientation()) {
            setNewRequestedOrientation();
        }
        this.mHandler = new Handler(Looper.getMainLooper(), this);
        initConfig();
        if (isImmersive()) {
            immersive();
        }
        if (!(this.config.style == null || this.config.style.pictureNavBarColor == 0)) {
            NavBarUtils.setNavBarColor(this, this.config.style.pictureNavBarColor);
        }
        int resourceId = getResourceId();
        if (resourceId != 0) {
            setContentView(resourceId);
        }
        initWidgets();
        initPictureSelectorStyle();
    }

    /* access modifiers changed from: protected */
    public void setNewRequestedOrientation() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig != null) {
            setRequestedOrientation(pictureSelectionConfig.requestedOrientation);
        }
    }

    private void initConfig() {
        this.selectionMedias = this.config.selectionMedias == null ? new ArrayList<>() : this.config.selectionMedias;
        if (this.config.style != null) {
            this.openWhiteStatusBar = this.config.style.isChangeStatusBarFontColor;
            if (this.config.style.pictureTitleBarBackgroundColor != 0) {
                this.colorPrimary = this.config.style.pictureTitleBarBackgroundColor;
            }
            if (this.config.style.pictureStatusBarColor != 0) {
                this.colorPrimaryDark = this.config.style.pictureStatusBarColor;
            }
            this.numComplete = this.config.style.isOpenCompletedNumStyle;
            PictureSelectionConfig pictureSelectionConfig = this.config;
            pictureSelectionConfig.checkNumMode = pictureSelectionConfig.style.isOpenCheckNumStyle;
            return;
        }
        this.openWhiteStatusBar = this.config.isChangeStatusBarFontColor;
        if (!this.openWhiteStatusBar) {
            this.openWhiteStatusBar = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_statusFontColor);
        }
        this.numComplete = this.config.isOpenStyleNumComplete;
        if (!this.numComplete) {
            this.numComplete = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_style_numComplete);
        }
        PictureSelectionConfig pictureSelectionConfig2 = this.config;
        pictureSelectionConfig2.checkNumMode = pictureSelectionConfig2.isOpenStyleCheckNumMode;
        if (!this.config.checkNumMode) {
            this.config.checkNumMode = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_style_checkNumMode);
        }
        if (this.config.titleBarBackgroundColor != 0) {
            this.colorPrimary = this.config.titleBarBackgroundColor;
        } else {
            this.colorPrimary = AttrsUtils.getTypeValueColor(this, R.attr.colorPrimary);
        }
        if (this.config.pictureStatusBarColor != 0) {
            this.colorPrimaryDark = this.config.pictureStatusBarColor;
        } else {
            this.colorPrimaryDark = AttrsUtils.getTypeValueColor(this, R.attr.colorPrimaryDark);
        }
    }

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        bundle.putString(PictureConfig.EXTRA_BUNDLE_CAMERA_PATH, this.cameraPath);
        bundle.putString(PictureConfig.EXTRA_BUNDLE_ORIGINAL_PATH, this.originalPath);
        bundle.putParcelable(PictureConfig.EXTRA_CONFIG, this.config);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.appcompat.app.AppCompatActivity
    public void attachBaseContext(Context context) {
        this.config = PictureSelectionConfig.getInstance();
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig != null) {
            super.attachBaseContext(PictureContextWrapper.wrap(context, pictureSelectionConfig.language));
        }
    }

    /* access modifiers changed from: protected */
    /* renamed from: showPleaseDialog */
    public void lambda$onResult$3$PictureBaseActivity() {
        if (!isFinishing()) {
            if (this.mLoadingDialog == null) {
                this.mLoadingDialog = new PictureLoadingDialog(getContext());
            }
            if (this.mLoadingDialog.isShowing()) {
                this.mLoadingDialog.dismiss();
            }
            this.mLoadingDialog.show();
        }
    }

    /* access modifiers changed from: protected */
    public void dismissDialog() {
        if (!isFinishing()) {
            try {
                if (this.mLoadingDialog != null && this.mLoadingDialog.isShowing()) {
                    this.mLoadingDialog.dismiss();
                }
            } catch (Exception e) {
                this.mLoadingDialog = null;
                e.printStackTrace();
            }
        }
        this.isPreviewLoading = false;
    }

    /* access modifiers changed from: protected */
    public void compressImage(final List<LocalMedia> list) {
        lambda$onResult$3$PictureBaseActivity();
        if (this.config.synOrAsy) {
            AsyncTask.SERIAL_EXECUTOR.execute(new Runnable(list) {
                /* class com.luck.picture.lib.$$Lambda$PictureBaseActivity$iHpezmS1_z9almpYP_GwvSGj6Z0 */
                private final /* synthetic */ List f$1;

                {
                    this.f$1 = r2;
                }

                public final void run() {
                    PictureBaseActivity.this.lambda$compressImage$1$PictureBaseActivity(this.f$1);
                }
            });
        } else {
            Luban.with(this).loadMediaData(list).ignoreBy(this.config.minimumCompressSize).setCompressQuality(this.config.compressQuality).setTargetDir(this.config.compressSavePath).setFocusAlpha(this.config.focusAlpha).setRenameListener(new OnRenameListener() {
                /* class com.luck.picture.lib.$$Lambda$PictureBaseActivity$9XujIyBEH1uDLW3n8WmSoAbpIA */

                @Override // com.luck.picture.lib.compress.OnRenameListener
                public final String rename(String str) {
                    return PictureBaseActivity.this.lambda$compressImage$2$PictureBaseActivity(str);
                }
            }).setCompressListener(new OnCompressListener() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass1 */

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onStart() {
                }

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onSuccess(List<LocalMedia> list) {
                    BroadcastManager.getInstance(PictureBaseActivity.this.getApplicationContext()).action(BroadcastAction.ACTION_CLOSE_PREVIEW).broadcast();
                    PictureBaseActivity.this.onResult(list);
                }

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onError(Throwable th) {
                    BroadcastManager.getInstance(PictureBaseActivity.this.getApplicationContext()).action(BroadcastAction.ACTION_CLOSE_PREVIEW).broadcast();
                    PictureBaseActivity.this.onResult(list);
                }
            }).launch();
        }
    }

    public /* synthetic */ void lambda$compressImage$1$PictureBaseActivity(List list) {
        try {
            List<File> list2 = Luban.with(getContext()).loadMediaData(list).setTargetDir(this.config.compressSavePath).setCompressQuality(this.config.compressQuality).setFocusAlpha(this.config.focusAlpha).setRenameListener(new OnRenameListener() {
                /* class com.luck.picture.lib.$$Lambda$PictureBaseActivity$5FzoElrNMObrtTdMpY846QHzA0 */

                @Override // com.luck.picture.lib.compress.OnRenameListener
                public final String rename(String str) {
                    return PictureBaseActivity.this.lambda$null$0$PictureBaseActivity(str);
                }
            }).ignoreBy(this.config.minimumCompressSize).get();
            this.mHandler.sendMessage(this.mHandler.obtainMessage(300, new Object[]{list, list2}));
        } catch (Exception e) {
            BroadcastManager.getInstance(getApplicationContext()).action(BroadcastAction.ACTION_CLOSE_PREVIEW).broadcast();
            onResult(list);
            e.printStackTrace();
        }
    }

    public /* synthetic */ String lambda$null$0$PictureBaseActivity(String str) {
        return this.config.renameCompressFileName;
    }

    public /* synthetic */ String lambda$compressImage$2$PictureBaseActivity(String str) {
        return this.config.renameCompressFileName;
    }

    private void handleCompressCallBack(List<LocalMedia> list, List<File> list2) {
        if (list == null || list2 == null) {
            closeActivity();
            return;
        }
        boolean checkedAndroid_Q = SdkVersionUtils.checkedAndroid_Q();
        int size = list.size();
        if (list2.size() == size) {
            for (int i = 0; i < size; i++) {
                String path = list2.get(i).getPath();
                LocalMedia localMedia = list.get(i);
                boolean z = !TextUtils.isEmpty(path) && PictureMimeType.isHttp(path);
                localMedia.setCompressed(!z);
                localMedia.setCompressPath(z ? "" : path);
                if (checkedAndroid_Q) {
                    localMedia.setAndroidQToPath(path);
                }
            }
        }
        BroadcastManager.getInstance(getApplicationContext()).action(BroadcastAction.ACTION_CLOSE_PREVIEW).broadcast();
        onResult(list);
    }

    /* access modifiers changed from: protected */
    public void startCrop(String str) {
        boolean z;
        int i;
        int i2;
        int i3;
        String str2;
        String str3;
        UCrop.Options options = new UCrop.Options();
        int i4 = 0;
        if (this.config.cropStyle != null) {
            i3 = this.config.cropStyle.cropTitleBarBackgroundColor != 0 ? this.config.cropStyle.cropTitleBarBackgroundColor : 0;
            i2 = this.config.cropStyle.cropStatusBarColorPrimaryDark != 0 ? this.config.cropStyle.cropStatusBarColorPrimaryDark : 0;
            i = this.config.cropStyle.cropTitleColor != 0 ? this.config.cropStyle.cropTitleColor : 0;
            z = this.config.cropStyle.isChangeStatusBarFontColor;
        } else {
            if (this.config.cropTitleBarBackgroundColor != 0) {
                i3 = this.config.cropTitleBarBackgroundColor;
            } else {
                i3 = AttrsUtils.getTypeValueColor(this, R.attr.picture_crop_toolbar_bg);
            }
            if (this.config.cropStatusBarColorPrimaryDark != 0) {
                i2 = this.config.cropStatusBarColorPrimaryDark;
            } else {
                i2 = AttrsUtils.getTypeValueColor(this, R.attr.picture_crop_status_color);
            }
            if (this.config.cropTitleColor != 0) {
                i = this.config.cropTitleColor;
            } else {
                i = AttrsUtils.getTypeValueColor(this, R.attr.picture_crop_title_color);
            }
            z = this.config.isChangeStatusBarFontColor;
            if (!z) {
                z = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_statusFontColor);
            }
        }
        options.isOpenWhiteStatusBar(z);
        options.setToolbarColor(i3);
        options.setStatusBarColor(i2);
        options.setToolbarWidgetColor(i);
        options.setDimmedLayerColor(this.config.circleDimmedColor);
        options.setDimmedLayerBorderColor(this.config.circleDimmedBorderColor);
        options.setCircleStrokeWidth(this.config.circleStrokeWidth);
        options.setCircleDimmedLayer(this.config.circleDimmedLayer);
        options.setShowCropFrame(this.config.showCropFrame);
        options.setShowCropGrid(this.config.showCropGrid);
        options.setDragFrameEnabled(this.config.isDragFrame);
        options.setScaleEnabled(this.config.scaleEnabled);
        options.setRotateEnabled(this.config.rotateEnabled);
        options.setCompressionQuality(this.config.cropCompressQuality);
        options.setHideBottomControls(this.config.hideBottomControls);
        options.setFreeStyleCropEnabled(this.config.freeStyleCropEnabled);
        options.setCropExitAnimation(this.config.windowAnimationStyle != null ? this.config.windowAnimationStyle.activityCropExitAnimation : 0);
        options.setNavBarColor(this.config.cropStyle != null ? this.config.cropStyle.cropNavBarColor : 0);
        boolean isHttp = PictureMimeType.isHttp(str);
        boolean checkedAndroid_Q = SdkVersionUtils.checkedAndroid_Q();
        if (checkedAndroid_Q) {
            str2 = PictureMimeType.getLastImgSuffix(PictureMimeType.getMimeType(getContext(), Uri.parse(str)));
        } else {
            str2 = PictureMimeType.getLastImgType(str);
        }
        Uri parse = (isHttp || checkedAndroid_Q) ? Uri.parse(str) : Uri.fromFile(new File(str));
        String diskCacheDir = PictureFileUtils.getDiskCacheDir(this);
        if (TextUtils.isEmpty(this.config.renameCropFileName)) {
            str3 = DateUtils.getCreateFileName("IMG_") + str2;
        } else {
            str3 = this.config.renameCropFileName;
        }
        UCrop withOptions = UCrop.of(parse, Uri.fromFile(new File(diskCacheDir, str3))).withAspectRatio((float) this.config.aspect_ratio_x, (float) this.config.aspect_ratio_y).withMaxResultSize(this.config.cropWidth, this.config.cropHeight).withOptions(options);
        if (this.config.windowAnimationStyle != null) {
            i4 = this.config.windowAnimationStyle.activityCropEnterAnimation;
        }
        withOptions.startAnimation(this, i4);
    }

    /* access modifiers changed from: protected */
    public void startCrop(ArrayList<CutInfo> arrayList) {
        boolean z;
        int i;
        int i2;
        int i3;
        String str;
        String str2;
        if (arrayList == null || arrayList.size() == 0) {
            ToastUtils.s(this, getString(R.string.picture_not_crop_data));
            return;
        }
        UCropMulti.Options options = new UCropMulti.Options();
        int i4 = 0;
        if (this.config.cropStyle != null) {
            i3 = this.config.cropStyle.cropTitleBarBackgroundColor != 0 ? this.config.cropStyle.cropTitleBarBackgroundColor : 0;
            i2 = this.config.cropStyle.cropStatusBarColorPrimaryDark != 0 ? this.config.cropStyle.cropStatusBarColorPrimaryDark : 0;
            i = this.config.cropStyle.cropTitleColor != 0 ? this.config.cropStyle.cropTitleColor : 0;
            z = this.config.cropStyle.isChangeStatusBarFontColor;
        } else {
            if (this.config.cropTitleBarBackgroundColor != 0) {
                i3 = this.config.cropTitleBarBackgroundColor;
            } else {
                i3 = AttrsUtils.getTypeValueColor(this, R.attr.picture_crop_toolbar_bg);
            }
            if (this.config.cropStatusBarColorPrimaryDark != 0) {
                i2 = this.config.cropStatusBarColorPrimaryDark;
            } else {
                i2 = AttrsUtils.getTypeValueColor(this, R.attr.picture_crop_status_color);
            }
            if (this.config.cropTitleColor != 0) {
                i = this.config.cropTitleColor;
            } else {
                i = AttrsUtils.getTypeValueColor(this, R.attr.picture_crop_title_color);
            }
            z = this.config.isChangeStatusBarFontColor;
            if (!z) {
                z = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_statusFontColor);
            }
        }
        options.isOpenWhiteStatusBar(z);
        options.setToolbarColor(i3);
        options.setStatusBarColor(i2);
        options.setToolbarWidgetColor(i);
        options.setCircleDimmedLayer(this.config.circleDimmedLayer);
        options.setDimmedLayerColor(this.config.circleDimmedColor);
        options.setDimmedLayerBorderColor(this.config.circleDimmedBorderColor);
        options.setCircleStrokeWidth(this.config.circleStrokeWidth);
        options.setShowCropFrame(this.config.showCropFrame);
        options.setDragFrameEnabled(this.config.isDragFrame);
        options.setShowCropGrid(this.config.showCropGrid);
        options.setScaleEnabled(this.config.scaleEnabled);
        options.setRotateEnabled(this.config.rotateEnabled);
        options.setHideBottomControls(this.config.hideBottomControls);
        options.setCompressionQuality(this.config.cropCompressQuality);
        options.setCutListData(arrayList);
        options.setFreeStyleCropEnabled(this.config.freeStyleCropEnabled);
        options.setCropExitAnimation(this.config.windowAnimationStyle != null ? this.config.windowAnimationStyle.activityCropExitAnimation : 0);
        options.setNavBarColor(this.config.cropStyle != null ? this.config.cropStyle.cropNavBarColor : 0);
        String path = arrayList.size() > 0 ? arrayList.get(0).getPath() : "";
        boolean checkedAndroid_Q = SdkVersionUtils.checkedAndroid_Q();
        boolean isHttp = PictureMimeType.isHttp(path);
        if (checkedAndroid_Q) {
            str = PictureMimeType.getLastImgSuffix(PictureMimeType.getMimeType(getContext(), Uri.parse(path)));
        } else {
            str = PictureMimeType.getLastImgType(path);
        }
        Uri parse = (isHttp || checkedAndroid_Q) ? Uri.parse(path) : Uri.fromFile(new File(path));
        String diskCacheDir = PictureFileUtils.getDiskCacheDir(this);
        if (TextUtils.isEmpty(this.config.renameCropFileName)) {
            str2 = DateUtils.getCreateFileName("IMG_") + str;
        } else {
            str2 = this.config.renameCropFileName;
        }
        UCropMulti withOptions = UCropMulti.of(parse, Uri.fromFile(new File(diskCacheDir, str2))).withAspectRatio((float) this.config.aspect_ratio_x, (float) this.config.aspect_ratio_y).withMaxResultSize(this.config.cropWidth, this.config.cropHeight).withOptions(options);
        if (this.config.windowAnimationStyle != null) {
            i4 = this.config.windowAnimationStyle.activityCropEnterAnimation;
        }
        withOptions.startAnimation(this, i4);
    }

    /* access modifiers changed from: protected */
    public void handlerResult(List<LocalMedia> list) {
        if (!this.config.isCompress || this.config.isCheckOriginalImage) {
            onResult(list);
        } else {
            compressImage(list);
        }
    }

    /* access modifiers changed from: protected */
    public void createNewFolder(List<LocalMediaFolder> list) {
        int i;
        if (list.size() == 0) {
            LocalMediaFolder localMediaFolder = new LocalMediaFolder();
            if (this.config.chooseMode == PictureMimeType.ofAudio()) {
                i = R.string.picture_all_audio;
            } else {
                i = R.string.picture_camera_roll;
            }
            localMediaFolder.setName(getString(i));
            localMediaFolder.setFirstImagePath("");
            list.add(localMediaFolder);
        }
    }

    /* access modifiers changed from: protected */
    public LocalMediaFolder getImageFolder(String str, List<LocalMediaFolder> list) {
        File parentFile = new File(str).getParentFile();
        for (LocalMediaFolder localMediaFolder : list) {
            if (localMediaFolder.getName().equals(parentFile.getName())) {
                return localMediaFolder;
            }
        }
        LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
        localMediaFolder2.setName(parentFile.getName());
        localMediaFolder2.setFirstImagePath(str);
        list.add(localMediaFolder2);
        return localMediaFolder2;
    }

    /* access modifiers changed from: protected */
    public void onResult(List<LocalMedia> list) {
        if (!SdkVersionUtils.checkedAndroid_Q() || !this.config.isAndroidQTransform) {
            dismissDialog();
            if (this.config.camera && this.config.selectionMode == 2 && this.selectionMedias != null) {
                list.addAll(list.size() > 0 ? list.size() - 1 : 0, this.selectionMedias);
            }
            if (this.config.isCheckOriginalImage) {
                int size = list.size();
                for (int i = 0; i < size; i++) {
                    LocalMedia localMedia = list.get(i);
                    localMedia.setOriginal(true);
                    localMedia.setOriginalPath(localMedia.getPath());
                }
            }
            setResult(-1, PictureSelector.putIntentResult(list));
            closeActivity();
            return;
        }
        if (!this.config.isCompress) {
            this.mHandler.postDelayed(new Runnable() {
                /* class com.luck.picture.lib.$$Lambda$PictureBaseActivity$uL1q3zcLtWzZFdQQlIhEmn0V9k */

                public final void run() {
                    PictureBaseActivity.this.lambda$onResult$3$PictureBaseActivity();
                }
            }, this.isPreviewLoading ? 30 : 0);
        }
        onResultToAndroidAsy(list);
    }

    private void onResultToAndroidAsy(List<LocalMedia> list) {
        AsyncTask.SERIAL_EXECUTOR.execute(new Runnable(list) {
            /* class com.luck.picture.lib.$$Lambda$PictureBaseActivity$tTeQ7UtoPG2DFFjsus7fvIfLwM */
            private final /* synthetic */ List f$1;

            {
                this.f$1 = r2;
            }

            public final void run() {
                PictureBaseActivity.this.lambda$onResultToAndroidAsy$4$PictureBaseActivity(this.f$1);
            }
        });
    }

    public /* synthetic */ void lambda$onResultToAndroidAsy$4$PictureBaseActivity(List list) {
        int size = list.size();
        for (int i = 0; i < size; i++) {
            LocalMedia localMedia = (LocalMedia) list.get(i);
            if (localMedia != null && !TextUtils.isEmpty(localMedia.getPath())) {
                if (!localMedia.isCut() && !localMedia.isCompressed() && TextUtils.isEmpty(localMedia.getAndroidQToPath())) {
                    localMedia.setAndroidQToPath(getPathToAndroidQ(localMedia));
                    if (this.config.isCheckOriginalImage) {
                        localMedia.setOriginal(true);
                        localMedia.setOriginalPath(localMedia.getAndroidQToPath());
                    }
                } else if (localMedia.isCut() && localMedia.isCompressed()) {
                    localMedia.setAndroidQToPath(localMedia.getCompressPath());
                } else if (this.config.isCheckOriginalImage) {
                    localMedia.setOriginal(true);
                    localMedia.setOriginalPath(localMedia.getAndroidQToPath());
                }
            }
        }
        Handler handler = this.mHandler;
        handler.sendMessage(handler.obtainMessage(200, list));
    }

    private String getPathToAndroidQ(LocalMedia localMedia) {
        if (PictureMimeType.eqVideo(localMedia.getMimeType())) {
            return AndroidQTransformUtils.parseVideoPathToAndroidQ(getApplicationContext(), localMedia.getPath(), this.config.cameraFileName, localMedia.getMimeType());
        }
        if (PictureMimeType.eqAudio(localMedia.getMimeType())) {
            return AndroidQTransformUtils.parseAudioPathToAndroidQ(getApplicationContext(), localMedia.getPath(), this.config.cameraFileName, localMedia.getMimeType());
        }
        return AndroidQTransformUtils.parseImagePathToAndroidQ(getApplicationContext(), localMedia.getPath(), this.config.cameraFileName, localMedia.getMimeType());
    }

    /* access modifiers changed from: protected */
    public void closeActivity() {
        finish();
        if (this.config.camera) {
            overridePendingTransition(0, R.anim.picture_anim_fade_out);
        } else {
            overridePendingTransition(0, (this.config.windowAnimationStyle == null || this.config.windowAnimationStyle.activityExitAnimation == 0) ? R.anim.picture_anim_exit : this.config.windowAnimationStyle.activityExitAnimation);
        }
    }

    /* access modifiers changed from: protected */
    @Override // androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onDestroy() {
        super.onDestroy();
        dismissDialog();
        this.mLoadingDialog = null;
    }

    /* access modifiers changed from: protected */
    @Deprecated
    public void removeImage(int i, boolean z) {
        try {
            getContentResolver().delete(z ? MediaStore.Video.Media.EXTERNAL_CONTENT_URI : MediaStore.Images.Media.EXTERNAL_CONTENT_URI, "_id=?", new String[]{Long.toString((long) i)});
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* access modifiers changed from: protected */
    public String getAudioPath(Intent intent) {
        boolean z = Build.VERSION.SDK_INT <= 19;
        if (intent == null || this.config.chooseMode != PictureMimeType.ofAudio()) {
            return "";
        }
        try {
            Uri data = intent.getData();
            if (z) {
                return data.getPath();
            }
            return getAudioFilePathFromUri(data);
        } catch (Exception e) {
            e.printStackTrace();
            return "";
        }
    }

    /* access modifiers changed from: protected */
    public String getAudioFilePathFromUri(Uri uri) {
        String str = "";
        try {
            Cursor query = getContentResolver().query(uri, null, null, null, null);
            query.moveToFirst();
            str = query.getString(query.getColumnIndex("_data"));
            query.close();
            return str;
        } catch (Exception e) {
            e.printStackTrace();
            return str;
        }
    }

    /* access modifiers changed from: protected */
    public void startOpenCamera() {
        Uri uri;
        Intent intent = new Intent("android.media.action.IMAGE_CAPTURE");
        if (intent.resolveActivity(getPackageManager()) != null) {
            if (SdkVersionUtils.checkedAndroid_Q()) {
                uri = MediaUtils.createImageUri(getApplicationContext());
                if (uri != null) {
                    this.cameraPath = uri.toString();
                } else {
                    ToastUtils.s(getContext(), "open is camera error，the uri is empty ");
                    if (this.config.camera) {
                        closeActivity();
                        return;
                    }
                    return;
                }
            } else {
                File createCameraFile = PictureFileUtils.createCameraFile(getApplicationContext(), this.config.chooseMode == 0 ? 1 : this.config.chooseMode, this.config.cameraFileName, this.config.suffixType);
                this.cameraPath = createCameraFile.getAbsolutePath();
                uri = PictureFileUtils.parUri(this, createCameraFile);
            }
            if (this.config.isCameraAroundState) {
                intent.putExtra(PictureConfig.CAMERA_FACING, 1);
            }
            intent.putExtra("output", uri);
            startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
        }
    }

    /* access modifiers changed from: protected */
    public void startOpenCameraVideo() {
        Uri uri;
        Intent intent = new Intent("android.media.action.VIDEO_CAPTURE");
        if (intent.resolveActivity(getPackageManager()) != null) {
            if (SdkVersionUtils.checkedAndroid_Q()) {
                uri = MediaUtils.createVideoUri(getApplicationContext());
                if (uri != null) {
                    this.cameraPath = uri.toString();
                } else {
                    ToastUtils.s(getContext(), "open is camera error，the uri is empty ");
                    if (this.config.camera) {
                        closeActivity();
                        return;
                    }
                    return;
                }
            } else {
                File createCameraFile = PictureFileUtils.createCameraFile(getApplicationContext(), this.config.chooseMode == 0 ? 2 : this.config.chooseMode, this.config.cameraFileName, this.config.suffixType);
                this.cameraPath = createCameraFile.getAbsolutePath();
                uri = PictureFileUtils.parUri(this, createCameraFile);
            }
            intent.putExtra("output", uri);
            if (this.config.isCameraAroundState) {
                intent.putExtra(PictureConfig.CAMERA_FACING, 1);
            }
            intent.putExtra("android.intent.extra.durationLimit", this.config.recordVideoSecond);
            intent.putExtra("android.intent.extra.videoQuality", this.config.videoQuality);
            startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
        }
    }

    public void startOpenCameraAudio() {
        if (PermissionChecker.checkSelfPermission(this, "android.permission.RECORD_AUDIO")) {
            Intent intent = new Intent("android.provider.MediaStore.RECORD_SOUND");
            if (intent.resolveActivity(getPackageManager()) != null) {
                startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
                return;
            }
            return;
        }
        PermissionChecker.requestPermissions(this, new String[]{"android.permission.RECORD_AUDIO"}, 3);
    }

    /* access modifiers changed from: protected */
    public void multiCropHandleResult(Intent intent) {
        ArrayList arrayList = new ArrayList();
        List<CutInfo> output = UCropMulti.getOutput(intent);
        int size = output.size();
        boolean checkedAndroid_Q = SdkVersionUtils.checkedAndroid_Q();
        for (int i = 0; i < size; i++) {
            CutInfo cutInfo = output.get(i);
            LocalMedia localMedia = new LocalMedia();
            localMedia.setId(cutInfo.getId());
            localMedia.setCut(!TextUtils.isEmpty(cutInfo.getCutPath()));
            localMedia.setPath(cutInfo.getPath());
            localMedia.setCutPath(cutInfo.getCutPath());
            localMedia.setMimeType(cutInfo.getMimeType());
            localMedia.setWidth(cutInfo.getImageWidth());
            localMedia.setHeight(cutInfo.getImageHeight());
            localMedia.setSize(new File(TextUtils.isEmpty(cutInfo.getCutPath()) ? cutInfo.getPath() : cutInfo.getCutPath()).length());
            localMedia.setChooseModel(this.config.chooseMode);
            if (checkedAndroid_Q) {
                localMedia.setAndroidQToPath(cutInfo.getCutPath());
            }
            arrayList.add(localMedia);
        }
        handlerResult(arrayList);
    }

    public boolean handleMessage(Message message) {
        int i = message.what;
        if (i == 200) {
            List list = (List) message.obj;
            dismissDialog();
            if (list != null) {
                if (this.config.camera && this.config.selectionMode == 2 && this.selectionMedias != null) {
                    list.addAll(list.size() > 0 ? list.size() - 1 : 0, this.selectionMedias);
                }
                setResult(-1, PictureSelector.putIntentResult(list));
                closeActivity();
            }
        } else if (i == 300 && message.obj != null && (message.obj instanceof Object[])) {
            Object[] objArr = (Object[]) message.obj;
            if (objArr.length > 0) {
                handleCompressCallBack((List) objArr[0], (List) objArr[1]);
            }
        }
        return false;
    }

    @Override // androidx.core.app.ActivityCompat.OnRequestPermissionsResultCallback, androidx.fragment.app.FragmentActivity
    public void onRequestPermissionsResult(int i, String[] strArr, int[] iArr) {
        super.onRequestPermissionsResult(i, strArr, iArr);
        if (i == 3) {
            if (iArr[0] == 0) {
                Intent intent = new Intent("android.provider.MediaStore.RECORD_SOUND");
                if (intent.resolveActivity(getPackageManager()) != null) {
                    startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
                    return;
                }
                return;
            }
            ToastUtils.s(getContext(), getString(R.string.picture_audio));
        }
    }
}
