package com.luck.picture.lib;

import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.text.TextUtils;
import androidx.core.content.ContextCompat;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.immersive.ImmersiveManage;
import com.luck.picture.lib.permissions.PermissionChecker;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.luck.picture.lib.tools.ValueOf;
import com.yalantis.ucrop.UCrop;
import java.io.File;
import java.util.ArrayList;

public class PictureSelectorCameraEmptyActivity extends PictureBaseActivity {
    static /* synthetic */ void lambda$requestCamera$0() {
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public void immersive() {
        ImmersiveManage.immersiveAboveAPI23(this, ContextCompat.getColor(this, R.color.picture_color_transparent), ContextCompat.getColor(this, R.color.picture_color_transparent), this.openWhiteStatusBar);
    }

    /* access modifiers changed from: protected */
    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, androidx.appcompat.app.AppCompatActivity, com.luck.picture.lib.PictureBaseActivity, androidx.fragment.app.FragmentActivity
    public void onCreate(Bundle bundle) {
        if (!PermissionChecker.checkSelfPermission(this, "android.permission.READ_EXTERNAL_STORAGE") || !PermissionChecker.checkSelfPermission(this, "android.permission.WRITE_EXTERNAL_STORAGE")) {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.READ_EXTERNAL_STORAGE", "android.permission.WRITE_EXTERNAL_STORAGE"}, 1);
        } else {
            onTakePhoto();
        }
        setTheme(R.style.Picture_Theme_Translucent);
        super.onCreate(bundle);
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public int getResourceId() {
        return R.layout.picture_empty;
    }

    private void onTakePhoto() {
        if (PermissionChecker.checkSelfPermission(this, "android.permission.CAMERA")) {
            startCamera();
        } else {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.CAMERA"}, 2);
        }
    }

    private void startCamera() {
        int i = this.config.chooseMode;
        if (i == 0 || i == 1) {
            startOpenCamera();
        } else if (i == 2) {
            startOpenCameraVideo();
        } else if (i == 3) {
            startOpenCameraAudio();
        }
    }

    /* access modifiers changed from: protected */
    @Override // androidx.fragment.app.FragmentActivity
    public void onActivityResult(int i, int i2, Intent intent) {
        super.onActivityResult(i, i2, intent);
        if (i2 == -1) {
            if (i == 69) {
                singleCropHandleResult(intent);
            } else if (i == 609) {
                multiCropHandleResult(intent);
            } else if (i == 909) {
                requestCamera(intent);
            }
        } else if (i2 == 0) {
            closeActivity();
        } else if (i2 == 96) {
            ToastUtils.s(getContext(), ((Throwable) intent.getSerializableExtra("com.yalantis.ucrop.Error")).getMessage());
        }
    }

    private void singleCropHandleResult(Intent intent) {
        ArrayList arrayList = new ArrayList();
        String path = UCrop.getOutput(intent).getPath();
        LocalMedia localMedia = new LocalMedia(this.cameraPath, 0, false, this.config.isCamera ? 1 : 0, 0, this.config.chooseMode);
        if (SdkVersionUtils.checkedAndroid_Q()) {
            int lastIndexOf = this.cameraPath.lastIndexOf("/") + 1;
            localMedia.setId(lastIndexOf > 0 ? ValueOf.toLong(this.cameraPath.substring(lastIndexOf)) : -1);
            localMedia.setAndroidQToPath(path);
        } else {
            localMedia.setId(System.currentTimeMillis());
        }
        localMedia.setCut(true);
        localMedia.setCutPath(path);
        localMedia.setMimeType(PictureMimeType.getImageMimeType(path));
        arrayList.add(localMedia);
        handlerResult(arrayList);
    }

    private void requestCamera(Intent intent) {
        String str;
        long j;
        int[] iArr;
        int[] iArr2;
        boolean checkedAndroid_Q = SdkVersionUtils.checkedAndroid_Q();
        long j2 = 0;
        if (this.config.chooseMode == PictureMimeType.ofAudio()) {
            this.cameraPath = getAudioPath(intent);
            if (!TextUtils.isEmpty(this.cameraPath)) {
                j = MediaUtils.extractDuration(getContext(), checkedAndroid_Q, this.cameraPath);
                str = "audio/mpeg";
            } else {
                return;
            }
        } else {
            str = null;
            j = 0;
        }
        if (!TextUtils.isEmpty(this.cameraPath)) {
            new File(this.cameraPath);
            int[] iArr3 = new int[2];
            File file = new File(this.cameraPath);
            if (!checkedAndroid_Q) {
                if (this.config.isFallbackVersion3) {
                    new PictureMediaScannerConnection(getContext(), this.cameraPath, $$Lambda$PictureSelectorCameraEmptyActivity$fSzp52pW_3cZ5piuR93I5l7ogI.INSTANCE);
                } else {
                    sendBroadcast(new Intent("android.intent.action.MEDIA_SCANNER_SCAN_FILE", Uri.fromFile(file)));
                }
            }
            LocalMedia localMedia = new LocalMedia();
            if (this.config.chooseMode != PictureMimeType.ofAudio()) {
                if (checkedAndroid_Q) {
                    File file2 = new File(PictureFileUtils.getPath(getApplicationContext(), Uri.parse(this.cameraPath)));
                    j2 = file2.length();
                    str = PictureMimeType.fileToType(file2);
                    if (PictureMimeType.eqImage(str)) {
                        iArr2 = MediaUtils.getLocalImageSizeToAndroidQ(this, this.cameraPath);
                    } else {
                        iArr2 = MediaUtils.getLocalVideoSize(this, Uri.parse(this.cameraPath));
                        j = MediaUtils.extractDuration(getContext(), true, this.cameraPath);
                    }
                    iArr3 = iArr2;
                    int lastIndexOf = this.cameraPath.lastIndexOf("/") + 1;
                    localMedia.setId(lastIndexOf > 0 ? ValueOf.toLong(this.cameraPath.substring(lastIndexOf)) : -1);
                } else {
                    str = PictureMimeType.fileToType(file);
                    j2 = new File(this.cameraPath).length();
                    if (PictureMimeType.eqImage(str)) {
                        PictureFileUtils.rotateImage(PictureFileUtils.readPictureDegree(this, this.cameraPath), this.cameraPath);
                        iArr = MediaUtils.getLocalImageWidthOrHeight(this.cameraPath);
                    } else {
                        iArr = MediaUtils.getLocalVideoSize(this.cameraPath);
                        j = MediaUtils.extractDuration(getContext(), false, this.cameraPath);
                    }
                    iArr3 = iArr;
                    localMedia.setId(System.currentTimeMillis());
                }
            }
            localMedia.setDuration(j);
            localMedia.setWidth(iArr3[0]);
            localMedia.setHeight(iArr3[1]);
            localMedia.setPath(this.cameraPath);
            localMedia.setMimeType(str);
            localMedia.setSize(j2);
            localMedia.setChooseModel(this.config.chooseMode);
            cameraHandleResult(localMedia, str);
        }
    }

    private void cameraHandleResult(LocalMedia localMedia, String str) {
        boolean eqImage = PictureMimeType.eqImage(str);
        if (this.config.enableCrop && eqImage) {
            this.originalPath = this.cameraPath;
            startCrop(this.cameraPath);
        } else if (!this.config.isCompress || !eqImage || this.config.isCheckOriginalImage) {
            ArrayList arrayList = new ArrayList();
            arrayList.add(localMedia);
            onResult(arrayList);
        } else {
            ArrayList arrayList2 = new ArrayList();
            arrayList2.add(localMedia);
            compressImage(arrayList2);
        }
    }

    @Override // androidx.activity.ComponentActivity
    public void onBackPressed() {
        super.onBackPressed();
        closeActivity();
    }

    @Override // androidx.core.app.ActivityCompat.OnRequestPermissionsResultCallback, com.luck.picture.lib.PictureBaseActivity, androidx.fragment.app.FragmentActivity
    public void onRequestPermissionsResult(int i, String[] strArr, int[] iArr) {
        super.onRequestPermissionsResult(i, strArr, iArr);
        if (i != 1) {
            if (i == 2) {
                if (iArr[0] == 0) {
                    onTakePhoto();
                    return;
                }
                closeActivity();
                ToastUtils.s(getContext(), getString(R.string.picture_camera));
            }
        } else if (iArr[0] == 0) {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.CAMERA"}, 2);
        } else {
            ToastUtils.s(getContext(), getString(R.string.picture_jurisdiction));
            closeActivity();
        }
    }
}
