package com.luck.picture.lib.adapter;

import android.content.Context;
import android.graphics.PorterDuff;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.Animation;
import android.widget.ImageView;
import android.widget.TextView;
import androidx.core.content.ContextCompat;
import androidx.recyclerview.widget.RecyclerView;
import com.luck.picture.lib.R;
import com.luck.picture.lib.adapter.PictureImageGridAdapter;
import com.luck.picture.lib.anim.OptAnimationLoader;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.tools.AnimUtils;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.StringUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.luck.picture.lib.tools.VoiceUtils;
import java.io.File;
import java.util.ArrayList;
import java.util.List;

public class PictureImageGridAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {
    private Animation animation;
    private PictureSelectionConfig config;
    private Context context;
    private OnPhotoSelectChangedListener imageSelectChangedListener;
    private List<LocalMedia> images = new ArrayList();
    private boolean isGo;
    private List<LocalMedia> selectImages = new ArrayList();
    private boolean showCamera;

    public interface OnPhotoSelectChangedListener {
        void onChange(List<LocalMedia> list);

        void onPictureClick(LocalMedia localMedia, int i);

        void onTakePhoto();
    }

    public PictureImageGridAdapter(Context context2, PictureSelectionConfig pictureSelectionConfig) {
        this.context = context2;
        this.config = pictureSelectionConfig;
        this.showCamera = pictureSelectionConfig.isCamera;
        this.animation = OptAnimationLoader.loadAnimation(context2, R.anim.picture_anim_modal_in);
    }

    public void setShowCamera(boolean z) {
        this.showCamera = z;
    }

    public void bindImagesData(List<LocalMedia> list) {
        this.images = list;
        notifyDataSetChanged();
    }

    public void bindSelectImages(List<LocalMedia> list) {
        ArrayList arrayList = new ArrayList();
        int size = list.size();
        for (int i = 0; i < size; i++) {
            arrayList.add(list.get(i));
        }
        this.selectImages = arrayList;
        if (!this.config.isSingleDirectReturn) {
            subSelectPosition();
            OnPhotoSelectChangedListener onPhotoSelectChangedListener = this.imageSelectChangedListener;
            if (onPhotoSelectChangedListener != null) {
                onPhotoSelectChangedListener.onChange(this.selectImages);
            }
        }
    }

    public List<LocalMedia> getSelectedImages() {
        List<LocalMedia> list = this.selectImages;
        return list == null ? new ArrayList() : list;
    }

    public List<LocalMedia> getImages() {
        List<LocalMedia> list = this.images;
        return list == null ? new ArrayList() : list;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemViewType(int i) {
        return (!this.showCamera || i != 0) ? 2 : 1;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public RecyclerView.ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i) {
        if (i == 1) {
            return new HeaderViewHolder(LayoutInflater.from(this.context).inflate(R.layout.picture_item_camera, viewGroup, false));
        }
        return new ViewHolder(LayoutInflater.from(this.context).inflate(R.layout.picture_image_grid_item, viewGroup, false));
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onBindViewHolder(RecyclerView.ViewHolder viewHolder, int i) {
        if (getItemViewType(i) == 1) {
            ((HeaderViewHolder) viewHolder).headerView.setOnClickListener(new View.OnClickListener() {
                /* class com.luck.picture.lib.adapter.$$Lambda$PictureImageGridAdapter$qvbHL3G2CY7hZL16_NieLEof5nI */

                public final void onClick(View view) {
                    PictureImageGridAdapter.this.lambda$onBindViewHolder$0$PictureImageGridAdapter(view);
                }
            });
            return;
        }
        ViewHolder viewHolder2 = (ViewHolder) viewHolder;
        LocalMedia localMedia = this.images.get(this.showCamera ? i - 1 : i);
        localMedia.position = viewHolder2.getAdapterPosition();
        String path = localMedia.getPath();
        String mimeType = localMedia.getMimeType();
        if (this.config.checkNumMode) {
            notifyCheckChanged(viewHolder2, localMedia);
        }
        selectImage(viewHolder2, isSelected(localMedia), false);
        boolean isGif = PictureMimeType.isGif(mimeType);
        viewHolder2.tvCheck.setVisibility(this.config.isSingleDirectReturn ? 8 : 0);
        viewHolder2.btnCheck.setVisibility(this.config.isSingleDirectReturn ? 8 : 0);
        viewHolder2.tvIsGif.setVisibility(isGif ? 0 : 8);
        if (PictureMimeType.eqImage(localMedia.getMimeType())) {
            viewHolder2.tvLongChart.setVisibility(MediaUtils.isLongImg(localMedia) ? 0 : 8);
        } else {
            viewHolder2.tvLongChart.setVisibility(8);
        }
        boolean eqVideo = PictureMimeType.eqVideo(mimeType);
        boolean eqAudio = PictureMimeType.eqAudio(mimeType);
        if (eqVideo || eqAudio) {
            viewHolder2.tvDuration.setVisibility(0);
            viewHolder2.tvDuration.setText(DateUtils.formatDurationTime(localMedia.getDuration()));
            if (Build.VERSION.SDK_INT >= 17) {
                viewHolder2.tvDuration.setCompoundDrawablesRelativeWithIntrinsicBounds(eqVideo ? R.drawable.picture_icon_video : R.drawable.picture_icon_audio, 0, 0, 0);
            }
        } else {
            viewHolder2.tvDuration.setVisibility(8);
        }
        if (this.config.chooseMode == PictureMimeType.ofAudio()) {
            viewHolder2.ivPicture.setImageResource(R.drawable.picture_audio_placeholder);
        } else if (this.config.imageEngine != null) {
            this.config.imageEngine.loadGridImage(this.context, path, viewHolder2.ivPicture);
        }
        if (this.config.enablePreview || this.config.enPreviewVideo || this.config.enablePreviewAudio) {
            viewHolder2.btnCheck.setOnClickListener(new View.OnClickListener(path, mimeType, viewHolder2, localMedia) {
                /* class com.luck.picture.lib.adapter.$$Lambda$PictureImageGridAdapter$xvHHE17bAvvvT4Eutof1oFVgdY */
                private final /* synthetic */ String f$1;
                private final /* synthetic */ String f$2;
                private final /* synthetic */ PictureImageGridAdapter.ViewHolder f$3;
                private final /* synthetic */ LocalMedia f$4;

                {
                    this.f$1 = r2;
                    this.f$2 = r3;
                    this.f$3 = r4;
                    this.f$4 = r5;
                }

                public final void onClick(View view) {
                    PictureImageGridAdapter.this.lambda$onBindViewHolder$1$PictureImageGridAdapter(this.f$1, this.f$2, this.f$3, this.f$4, view);
                }
            });
        }
        viewHolder2.contentView.setOnClickListener(new View.OnClickListener(path, mimeType, i, localMedia, viewHolder2) {
            /* class com.luck.picture.lib.adapter.$$Lambda$PictureImageGridAdapter$hcORIUDlg5Ahh1KD1jdQ6RiA5SU */
            private final /* synthetic */ String f$1;
            private final /* synthetic */ String f$2;
            private final /* synthetic */ int f$3;
            private final /* synthetic */ LocalMedia f$4;
            private final /* synthetic */ PictureImageGridAdapter.ViewHolder f$5;

            {
                this.f$1 = r2;
                this.f$2 = r3;
                this.f$3 = r4;
                this.f$4 = r5;
                this.f$5 = r6;
            }

            public final void onClick(View view) {
                PictureImageGridAdapter.this.lambda$onBindViewHolder$2$PictureImageGridAdapter(this.f$1, this.f$2, this.f$3, this.f$4, this.f$5, view);
            }
        });
    }

    public /* synthetic */ void lambda$onBindViewHolder$0$PictureImageGridAdapter(View view) {
        OnPhotoSelectChangedListener onPhotoSelectChangedListener = this.imageSelectChangedListener;
        if (onPhotoSelectChangedListener != null) {
            onPhotoSelectChangedListener.onTakePhoto();
        }
    }

    public /* synthetic */ void lambda$onBindViewHolder$1$PictureImageGridAdapter(String str, String str2, ViewHolder viewHolder, LocalMedia localMedia, View view) {
        if (SdkVersionUtils.checkedAndroid_Q()) {
            str = PictureFileUtils.getPath(this.context, Uri.parse(str));
        }
        if (!new File(str).exists()) {
            Context context2 = this.context;
            ToastUtils.s(context2, PictureMimeType.s(context2, str2));
            return;
        }
        changeCheckboxState(viewHolder, localMedia);
    }

    public /* synthetic */ void lambda$onBindViewHolder$2$PictureImageGridAdapter(String str, String str2, int i, LocalMedia localMedia, ViewHolder viewHolder, View view) {
        if (SdkVersionUtils.checkedAndroid_Q()) {
            str = PictureFileUtils.getPath(this.context, Uri.parse(str));
        }
        if (!new File(str).exists()) {
            Context context2 = this.context;
            ToastUtils.s(context2, PictureMimeType.s(context2, str2));
            return;
        }
        if (this.showCamera) {
            i--;
        }
        if (i != -1) {
            boolean z = true;
            if ((!PictureMimeType.eqImage(str2) || !this.config.enablePreview) && ((!PictureMimeType.eqVideo(str2) || (!this.config.enPreviewVideo && this.config.selectionMode != 1)) && (!PictureMimeType.eqAudio(str2) || (!this.config.enablePreviewAudio && this.config.selectionMode != 1)))) {
                z = false;
            }
            if (z) {
                this.imageSelectChangedListener.onPictureClick(localMedia, i);
            } else {
                changeCheckboxState(viewHolder, localMedia);
            }
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        return this.showCamera ? this.images.size() + 1 : this.images.size();
    }

    public class HeaderViewHolder extends RecyclerView.ViewHolder {
        View headerView;
        TextView tvCamera;

        public HeaderViewHolder(View view) {
            super(view);
            String str;
            this.headerView = view;
            this.tvCamera = (TextView) view.findViewById(R.id.tvCamera);
            if (PictureImageGridAdapter.this.config.chooseMode == PictureMimeType.ofAudio()) {
                str = PictureImageGridAdapter.this.context.getString(R.string.picture_tape);
            } else {
                str = PictureImageGridAdapter.this.context.getString(R.string.picture_take_picture);
            }
            this.tvCamera.setText(str);
        }
    }

    public class ViewHolder extends RecyclerView.ViewHolder {
        View btnCheck;
        View contentView;
        ImageView ivPicture;
        TextView tvCheck;
        TextView tvDuration;
        TextView tvIsGif;
        TextView tvLongChart;

        public ViewHolder(View view) {
            super(view);
            this.contentView = view;
            this.ivPicture = (ImageView) view.findViewById(R.id.ivPicture);
            this.tvCheck = (TextView) view.findViewById(R.id.tvCheck);
            this.btnCheck = view.findViewById(R.id.btnCheck);
            this.tvDuration = (TextView) view.findViewById(R.id.tv_duration);
            this.tvIsGif = (TextView) view.findViewById(R.id.tv_isGif);
            this.tvLongChart = (TextView) view.findViewById(R.id.tv_long_chart);
            if (PictureImageGridAdapter.this.config.style != null && PictureImageGridAdapter.this.config.style.pictureCheckedStyle != 0) {
                this.tvCheck.setBackgroundResource(PictureImageGridAdapter.this.config.style.pictureCheckedStyle);
            }
        }
    }

    public boolean isSelected(LocalMedia localMedia) {
        int size = this.selectImages.size();
        for (int i = 0; i < size; i++) {
            LocalMedia localMedia2 = this.selectImages.get(i);
            if (!(localMedia2 == null || TextUtils.isEmpty(localMedia2.getPath()) || (!localMedia2.getPath().equals(localMedia.getPath()) && localMedia2.getId() != localMedia.getId()))) {
                return true;
            }
        }
        return false;
    }

    private void notifyCheckChanged(ViewHolder viewHolder, LocalMedia localMedia) {
        viewHolder.tvCheck.setText("");
        int size = this.selectImages.size();
        for (int i = 0; i < size; i++) {
            LocalMedia localMedia2 = this.selectImages.get(i);
            if (localMedia2.getPath().equals(localMedia.getPath()) || localMedia2.getId() == localMedia.getId()) {
                localMedia.setNum(localMedia2.getNum());
                localMedia2.setPosition(localMedia.getPosition());
                viewHolder.tvCheck.setText(String.valueOf(localMedia.getNum()));
            }
        }
    }

    private void changeCheckboxState(ViewHolder viewHolder, LocalMedia localMedia) {
        LocalMedia localMedia2;
        boolean isSelected = viewHolder.tvCheck.isSelected();
        int size = this.selectImages.size();
        int i = 0;
        String mimeType = size > 0 ? this.selectImages.get(0).getMimeType() : "";
        if (!TextUtils.isEmpty(mimeType) && !PictureMimeType.isMimeTypeSame(mimeType, localMedia.getMimeType())) {
            Context context2 = this.context;
            ToastUtils.s(context2, context2.getString(R.string.picture_rule));
        } else if (PictureMimeType.eqVideo(mimeType) && this.config.maxVideoSelectNum > 0 && size >= this.config.maxVideoSelectNum && !isSelected) {
            Context context3 = this.context;
            ToastUtils.s(context3, StringUtils.getToastMsg(context3, mimeType, this.config.maxVideoSelectNum));
        } else if (size < this.config.maxSelectNum || isSelected) {
            if (isSelected) {
                while (true) {
                    if (i >= size) {
                        break;
                    }
                    localMedia2 = this.selectImages.get(i);
                    if (localMedia2 == null || TextUtils.isEmpty(localMedia2.getPath()) || (!localMedia2.getPath().equals(localMedia.getPath()) && localMedia2.getId() != localMedia.getId())) {
                        i++;
                    }
                }
                this.selectImages.remove(localMedia2);
                subSelectPosition();
                AnimUtils.disZoom(viewHolder.ivPicture, this.config.zoomAnim);
            } else {
                if (this.config.selectionMode == 1) {
                    singleRadioMediaImage();
                }
                this.selectImages.add(localMedia);
                localMedia.setNum(this.selectImages.size());
                VoiceUtils.playVoice(this.context, this.config.openClickSound);
                AnimUtils.zoom(viewHolder.ivPicture, this.config.zoomAnim);
            }
            notifyItemChanged(viewHolder.getAdapterPosition());
            selectImage(viewHolder, !isSelected, true);
            OnPhotoSelectChangedListener onPhotoSelectChangedListener = this.imageSelectChangedListener;
            if (onPhotoSelectChangedListener != null) {
                onPhotoSelectChangedListener.onChange(this.selectImages);
            }
        } else {
            Context context4 = this.context;
            ToastUtils.s(context4, StringUtils.getToastMsg(context4, mimeType, this.config.maxSelectNum));
        }
    }

    private void singleRadioMediaImage() {
        List<LocalMedia> list = this.selectImages;
        if (list != null && list.size() > 0) {
            this.isGo = true;
            int i = 0;
            LocalMedia localMedia = this.selectImages.get(0);
            if (this.config.isCamera || this.isGo) {
                i = localMedia.position;
            } else if (localMedia.position > 0) {
                i = localMedia.position - 1;
            }
            notifyItemChanged(i);
            this.selectImages.clear();
        }
    }

    private void subSelectPosition() {
        if (this.config.checkNumMode) {
            int size = this.selectImages.size();
            int i = 0;
            while (i < size) {
                LocalMedia localMedia = this.selectImages.get(i);
                i++;
                localMedia.setNum(i);
                notifyItemChanged(localMedia.position);
            }
        }
    }

    public void selectImage(ViewHolder viewHolder, boolean z, boolean z2) {
        viewHolder.tvCheck.setSelected(z);
        if (z) {
            if (z2 && this.animation != null) {
                viewHolder.tvCheck.startAnimation(this.animation);
            }
            viewHolder.ivPicture.setColorFilter(ContextCompat.getColor(this.context, R.color.picture_color_80), PorterDuff.Mode.SRC_ATOP);
            return;
        }
        viewHolder.ivPicture.setColorFilter(ContextCompat.getColor(this.context, R.color.picture_color_20), PorterDuff.Mode.SRC_ATOP);
    }

    public void setOnPhotoSelectChangedListener(OnPhotoSelectChangedListener onPhotoSelectChangedListener) {
        this.imageSelectChangedListener = onPhotoSelectChangedListener;
    }
}
