package com.luck.picture.lib.adapter;

import android.content.Intent;
import android.graphics.PointF;
import android.net.Uri;
import android.os.Bundle;
import android.util.SparseArray;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import androidx.viewpager.widget.PagerAdapter;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.photoview.OnViewTapListener;
import com.luck.picture.lib.photoview.PhotoView;
import com.luck.picture.lib.tools.JumpUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.widget.longimage.ImageSource;
import com.luck.picture.lib.widget.longimage.ImageViewState;
import com.luck.picture.lib.widget.longimage.SubsamplingScaleImageView;
import java.io.File;
import java.util.List;

public class PictureSimpleFragmentAdapter extends PagerAdapter {
    private static final int MAX_CACHE_SIZE = 20;
    private PictureSelectionConfig config;
    private List<LocalMedia> images;
    private SparseArray<View> mCacheView = new SparseArray<>();
    private OnCallBackActivity onBackPressed;

    public interface OnCallBackActivity {
        void onActivityBackPressed();
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public boolean isViewFromObject(View view, Object obj) {
        return view == obj;
    }

    public void clear() {
        SparseArray<View> sparseArray = this.mCacheView;
        if (sparseArray != null) {
            sparseArray.clear();
            this.mCacheView = null;
        }
    }

    public PictureSimpleFragmentAdapter(PictureSelectionConfig pictureSelectionConfig, List<LocalMedia> list, OnCallBackActivity onCallBackActivity) {
        this.config = pictureSelectionConfig;
        this.images = list;
        this.onBackPressed = onCallBackActivity;
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public int getCount() {
        List<LocalMedia> list = this.images;
        if (list != null) {
            return list.size();
        }
        return 0;
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public void destroyItem(ViewGroup viewGroup, int i, Object obj) {
        viewGroup.removeView((View) obj);
        if (this.mCacheView.size() > 20) {
            this.mCacheView.remove(i);
        }
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public Object instantiateItem(ViewGroup viewGroup, int i) {
        String str;
        View view = this.mCacheView.get(i);
        if (view == null) {
            view = LayoutInflater.from(viewGroup.getContext()).inflate(R.layout.picture_image_preview, viewGroup, false);
            PhotoView photoView = (PhotoView) view.findViewById(R.id.preview_image);
            SubsamplingScaleImageView subsamplingScaleImageView = (SubsamplingScaleImageView) view.findViewById(R.id.longImg);
            ImageView imageView = (ImageView) view.findViewById(R.id.iv_play);
            LocalMedia localMedia = this.images.get(i);
            if (localMedia != null) {
                String mimeType = localMedia.getMimeType();
                int i2 = 8;
                imageView.setVisibility(PictureMimeType.eqVideo(mimeType) ? 0 : 8);
                if (localMedia.isCut() && !localMedia.isCompressed()) {
                    str = localMedia.getCutPath();
                } else if (localMedia.isCompressed() || (localMedia.isCut() && localMedia.isCompressed())) {
                    str = localMedia.getCompressPath();
                } else {
                    str = localMedia.getPath();
                }
                boolean isGif = PictureMimeType.isGif(mimeType);
                boolean isLongImg = MediaUtils.isLongImg(localMedia);
                photoView.setVisibility((!isLongImg || isGif) ? 0 : 8);
                if (isLongImg && !isGif) {
                    i2 = 0;
                }
                subsamplingScaleImageView.setVisibility(i2);
                if (!isGif || localMedia.isCompressed()) {
                    PictureSelectionConfig pictureSelectionConfig = this.config;
                    if (!(pictureSelectionConfig == null || pictureSelectionConfig.imageEngine == null)) {
                        if (isLongImg) {
                            displayLongPic(SdkVersionUtils.checkedAndroid_Q() ? Uri.parse(str) : Uri.fromFile(new File(str)), subsamplingScaleImageView);
                        } else {
                            this.config.imageEngine.loadImage(view.getContext(), str, photoView);
                        }
                    }
                } else {
                    PictureSelectionConfig pictureSelectionConfig2 = this.config;
                    if (!(pictureSelectionConfig2 == null || pictureSelectionConfig2.imageEngine == null)) {
                        this.config.imageEngine.loadAsGifImage(view.getContext(), str, photoView);
                    }
                }
                photoView.setOnViewTapListener(new OnViewTapListener() {
                    /* class com.luck.picture.lib.adapter.$$Lambda$PictureSimpleFragmentAdapter$41mAAnVqldPa84yNkzEZDSWNzxU */

                    @Override // com.luck.picture.lib.photoview.OnViewTapListener
                    public final void onViewTap(View view, float f, float f2) {
                        PictureSimpleFragmentAdapter.this.lambda$instantiateItem$0$PictureSimpleFragmentAdapter(view, f, f2);
                    }
                });
                subsamplingScaleImageView.setOnClickListener(new View.OnClickListener() {
                    /* class com.luck.picture.lib.adapter.$$Lambda$PictureSimpleFragmentAdapter$Iiy4ccpygbG1V81nteUiDAf0D3s */

                    public final void onClick(View view) {
                        PictureSimpleFragmentAdapter.this.lambda$instantiateItem$1$PictureSimpleFragmentAdapter(view);
                    }
                });
                imageView.setOnClickListener(new View.OnClickListener(str, viewGroup) {
                    /* class com.luck.picture.lib.adapter.$$Lambda$PictureSimpleFragmentAdapter$HjTKFQnlLb23uxW0hkXsIUJCwd0 */
                    private final /* synthetic */ String f$0;
                    private final /* synthetic */ ViewGroup f$1;

                    {
                        this.f$0 = r1;
                        this.f$1 = r2;
                    }

                    public final void onClick(View view) {
                        PictureSimpleFragmentAdapter.lambda$instantiateItem$2(this.f$0, this.f$1, view);
                    }
                });
            }
            this.mCacheView.put(i, view);
        }
        viewGroup.addView(view, 0);
        return view;
    }

    public /* synthetic */ void lambda$instantiateItem$0$PictureSimpleFragmentAdapter(View view, float f, float f2) {
        OnCallBackActivity onCallBackActivity = this.onBackPressed;
        if (onCallBackActivity != null) {
            onCallBackActivity.onActivityBackPressed();
        }
    }

    public /* synthetic */ void lambda$instantiateItem$1$PictureSimpleFragmentAdapter(View view) {
        OnCallBackActivity onCallBackActivity = this.onBackPressed;
        if (onCallBackActivity != null) {
            onCallBackActivity.onActivityBackPressed();
        }
    }

    static /* synthetic */ void lambda$instantiateItem$2(String str, ViewGroup viewGroup, View view) {
        Intent intent = new Intent();
        Bundle bundle = new Bundle();
        bundle.putString(PictureConfig.EXTRA_VIDEO_PATH, str);
        intent.putExtras(bundle);
        JumpUtils.startPictureVideoPlayActivity(viewGroup.getContext(), bundle);
    }

    private void displayLongPic(Uri uri, SubsamplingScaleImageView subsamplingScaleImageView) {
        subsamplingScaleImageView.setQuickScaleEnabled(true);
        subsamplingScaleImageView.setZoomEnabled(true);
        subsamplingScaleImageView.setPanEnabled(true);
        subsamplingScaleImageView.setDoubleTapZoomDuration(100);
        subsamplingScaleImageView.setMinimumScaleType(2);
        subsamplingScaleImageView.setDoubleTapZoomDpi(2);
        subsamplingScaleImageView.setImage(ImageSource.uri(uri), new ImageViewState(0.0f, new PointF(0.0f, 0.0f), 0));
    }
}
