package com.luck.picture.lib.compress;

import android.content.Context;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Environment;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import android.util.Log;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.tools.AndroidQTransformUtils;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class Luban implements Handler.Callback {
    private static final int MSG_COMPRESS_ERROR = 2;
    private static final int MSG_COMPRESS_START = 1;
    private static final int MSG_COMPRESS_SUCCESS = 0;
    private static final String TAG = "Luban";
    private int compressQuality;
    private boolean focusAlpha;
    private int index;
    private boolean isAndroidQ;
    private OnCompressListener mCompressListener;
    private CompressionPredicate mCompressionPredicate;
    private Handler mHandler;
    private int mLeastCompressSize;
    private List<String> mPaths;
    private OnRenameListener mRenameListener;
    private List<InputStreamProvider> mStreamProviders;
    private String mTargetDir;
    private List<LocalMedia> mediaList;

    private Luban(Builder builder) {
        this.index = -1;
        this.mPaths = builder.mPaths;
        this.mediaList = builder.mediaList;
        this.mTargetDir = builder.mTargetDir;
        this.mRenameListener = builder.mRenameListener;
        this.mStreamProviders = builder.mStreamProviders;
        this.mCompressListener = builder.mCompressListener;
        this.mLeastCompressSize = builder.mLeastCompressSize;
        this.mCompressionPredicate = builder.mCompressionPredicate;
        this.compressQuality = builder.compressQuality;
        this.focusAlpha = builder.focusAlpha;
        this.mHandler = new Handler(Looper.getMainLooper(), this);
        this.isAndroidQ = builder.isAndroidQ;
    }

    public static Builder with(Context context) {
        return new Builder(context);
    }

    private File getImageCacheFile(Context context, String str) {
        if (TextUtils.isEmpty(this.mTargetDir) && getImageCacheDir(context) != null) {
            this.mTargetDir = getImageCacheDir(context).getAbsolutePath();
        }
        StringBuilder sb = new StringBuilder();
        sb.append(this.mTargetDir);
        sb.append("/");
        sb.append(DateUtils.getCreateFileName("IMG_"));
        if (TextUtils.isEmpty(str)) {
            str = ".jpg";
        }
        sb.append(str);
        return new File(sb.toString());
    }

    private File getImageCustomFile(Context context, String str) {
        if (TextUtils.isEmpty(this.mTargetDir)) {
            this.mTargetDir = getImageCacheDir(context).getAbsolutePath();
        }
        return new File(this.mTargetDir + "/" + str);
    }

    private static File getImageCacheDir(Context context) {
        File externalFilesDir = context.getExternalFilesDir(Environment.DIRECTORY_PICTURES);
        if (externalFilesDir == null) {
            if (Log.isLoggable(TAG, 6)) {
                Log.e(TAG, "default disk cache dir is null");
            }
            return null;
        } else if (externalFilesDir.mkdirs() || (externalFilesDir.exists() && externalFilesDir.isDirectory())) {
            return externalFilesDir;
        } else {
            return null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void launch(Context context) {
        List<InputStreamProvider> list = this.mStreamProviders;
        if (list == null || this.mPaths == null || (list.size() == 0 && this.mCompressListener != null)) {
            this.mCompressListener.onError(new NullPointerException("image file cannot be null"));
        }
        Iterator<InputStreamProvider> it = this.mStreamProviders.iterator();
        this.index = -1;
        while (it.hasNext()) {
            AsyncTask.SERIAL_EXECUTOR.execute(new Runnable(it.next(), context) {
                /* class com.luck.picture.lib.compress.$$Lambda$Luban$FIp_nrNo5IFcYhOflpIqR9L2njQ */
                private final /* synthetic */ InputStreamProvider f$1;
                private final /* synthetic */ Context f$2;

                {
                    this.f$1 = r2;
                    this.f$2 = r3;
                }

                public final void run() {
                    Luban.this.lambda$launch$0$Luban(this.f$1, this.f$2);
                }
            });
            it.remove();
        }
    }

    public /* synthetic */ void lambda$launch$0$Luban(InputStreamProvider inputStreamProvider, Context context) {
        File file;
        String str;
        try {
            boolean z = true;
            this.index++;
            this.mHandler.sendMessage(this.mHandler.obtainMessage(1));
            if (!inputStreamProvider.getMedia().isCompressed() || TextUtils.isEmpty(inputStreamProvider.getMedia().getCompressPath())) {
                file = compress(context, inputStreamProvider);
            } else if (new File(inputStreamProvider.getMedia().getCompressPath()).exists()) {
                file = new File(inputStreamProvider.getMedia().getCompressPath());
            } else {
                file = compress(context, inputStreamProvider);
            }
            if (this.mediaList == null || this.mediaList.size() <= 0) {
                this.mHandler.sendMessage(this.mHandler.obtainMessage(2, new IOException()));
                return;
            }
            LocalMedia localMedia = this.mediaList.get(this.index);
            boolean isHttp = PictureMimeType.isHttp(file.getAbsolutePath());
            localMedia.setCompressed(!isHttp);
            if (isHttp) {
                str = "";
            } else {
                str = file.getAbsolutePath();
            }
            localMedia.setCompressPath(str);
            if (this.index != this.mediaList.size() - 1) {
                z = false;
            }
            if (z) {
                this.mHandler.sendMessage(this.mHandler.obtainMessage(0, this.mediaList));
            }
        } catch (IOException e) {
            Handler handler = this.mHandler;
            handler.sendMessage(handler.obtainMessage(2, e));
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private File get(InputStreamProvider inputStreamProvider, Context context) throws IOException {
        try {
            return new Engine(inputStreamProvider, getImageCacheFile(context, Checker.SINGLE.extSuffix(inputStreamProvider)), this.focusAlpha, this.compressQuality).compress();
        } finally {
            inputStreamProvider.close();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private List<File> get(Context context) throws IOException {
        File file;
        ArrayList arrayList = new ArrayList();
        Iterator<InputStreamProvider> it = this.mStreamProviders.iterator();
        while (it.hasNext()) {
            InputStreamProvider next = it.next();
            if (!next.getMedia().isCompressed() || TextUtils.isEmpty(next.getMedia().getCompressPath())) {
                arrayList.add(compress(context, next));
            } else {
                if (new File(next.getMedia().getCompressPath()).exists()) {
                    file = new File(next.getMedia().getCompressPath());
                } else {
                    file = compress(context, next);
                }
                arrayList.add(file);
            }
            it.remove();
        }
        return arrayList;
    }

    private File compress(Context context, InputStreamProvider inputStreamProvider) throws IOException {
        try {
            return compressRealLocalMedia(context, inputStreamProvider);
        } finally {
            inputStreamProvider.close();
        }
    }

    private File compressReal(Context context, InputStreamProvider inputStreamProvider) throws IOException {
        String extSuffix = Checker.SINGLE.extSuffix(inputStreamProvider.getMedia() != null ? inputStreamProvider.getMedia().getMimeType() : "");
        if (TextUtils.isEmpty(extSuffix)) {
            extSuffix = Checker.SINGLE.extSuffix(inputStreamProvider);
        }
        File imageCacheFile = getImageCacheFile(context, extSuffix);
        OnRenameListener onRenameListener = this.mRenameListener;
        if (onRenameListener != null) {
            imageCacheFile = getImageCustomFile(context, onRenameListener.rename(inputStreamProvider.getPath()));
        }
        CompressionPredicate compressionPredicate = this.mCompressionPredicate;
        if (compressionPredicate != null) {
            if (!compressionPredicate.apply(inputStreamProvider.getPath()) || !Checker.SINGLE.needCompress(this.mLeastCompressSize, inputStreamProvider.getPath())) {
                return new File(inputStreamProvider.getPath());
            }
            return new Engine(inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality).compress();
        } else if (Checker.SINGLE.extSuffix(inputStreamProvider).startsWith(".gif")) {
            return new File(inputStreamProvider.getPath());
        } else {
            if (Checker.SINGLE.needCompress(this.mLeastCompressSize, inputStreamProvider.getPath())) {
                return new Engine(inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality).compress();
            }
            return new File(inputStreamProvider.getPath());
        }
    }

    private File compressRealLocalMedia(Context context, InputStreamProvider inputStreamProvider) throws IOException {
        File file;
        String str;
        String str2;
        String str3;
        String str4;
        LocalMedia media = inputStreamProvider.getMedia();
        String path = this.isAndroidQ ? PictureFileUtils.getPath(context, Uri.parse(inputStreamProvider.getPath())) : inputStreamProvider.getPath();
        String str5 = "";
        String extSuffix = Checker.SINGLE.extSuffix(media != null ? inputStreamProvider.getMedia().getMimeType() : str5);
        if (TextUtils.isEmpty(extSuffix)) {
            extSuffix = Checker.SINGLE.extSuffix(inputStreamProvider);
        }
        File imageCacheFile = getImageCacheFile(context, extSuffix);
        OnRenameListener onRenameListener = this.mRenameListener;
        if (onRenameListener != null) {
            str5 = onRenameListener.rename(path);
            if (!TextUtils.isEmpty(str5)) {
                imageCacheFile = getImageCustomFile(context, str5);
            }
        }
        if (this.mCompressionPredicate != null) {
            if (Checker.SINGLE.extSuffix(inputStreamProvider).startsWith(".gif")) {
                if (!this.isAndroidQ) {
                    return new File(path);
                }
                if (media.isCut()) {
                    str4 = media.getCutPath();
                } else {
                    str4 = AndroidQTransformUtils.copyImagePathToDirectoryPictures(context, inputStreamProvider.getPath(), str5, media.getMimeType());
                }
                return new File(str4);
            } else if (this.mCompressionPredicate.apply(path) && Checker.SINGLE.needCompressToLocalMedia(this.mLeastCompressSize, path)) {
                return new Engine(inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality).compress();
            } else {
                if (!this.isAndroidQ) {
                    return new File(path);
                }
                if (media.isCut()) {
                    str3 = media.getCutPath();
                } else {
                    str3 = AndroidQTransformUtils.copyImagePathToDirectoryPictures(context, inputStreamProvider.getPath(), str5, media.getMimeType());
                }
                return new File(str3);
            }
        } else if (!Checker.SINGLE.extSuffix(inputStreamProvider).startsWith(".gif")) {
            if (Checker.SINGLE.needCompressToLocalMedia(this.mLeastCompressSize, path)) {
                file = new Engine(inputStreamProvider, imageCacheFile, this.focusAlpha, this.compressQuality).compress();
            } else if (this.isAndroidQ) {
                if (media.isCut()) {
                    str = media.getCutPath();
                } else {
                    str = AndroidQTransformUtils.copyImagePathToDirectoryPictures(context, inputStreamProvider.getPath(), str5, media.getMimeType());
                }
                return new File(str);
            } else {
                file = new File(path);
            }
            return file;
        } else if (!this.isAndroidQ) {
            return new File(path);
        } else {
            if (media.isCut()) {
                str2 = media.getCutPath();
            } else {
                str2 = AndroidQTransformUtils.copyImagePathToDirectoryPictures(context, inputStreamProvider.getPath(), str5, media.getMimeType());
            }
            return new File(str2);
        }
    }

    public boolean handleMessage(Message message) {
        if (this.mCompressListener == null) {
            return false;
        }
        int i = message.what;
        if (i == 0) {
            this.mCompressListener.onSuccess((List) message.obj);
        } else if (i == 1) {
            this.mCompressListener.onStart();
        } else if (i == 2) {
            this.mCompressListener.onError((Throwable) message.obj);
        }
        return false;
    }

    public static class Builder {
        private int compressQuality;
        private Context context;
        private boolean focusAlpha;
        private boolean isAndroidQ;
        private OnCompressListener mCompressListener;
        private CompressionPredicate mCompressionPredicate;
        private int mLeastCompressSize = 100;
        private List<String> mPaths;
        private OnRenameListener mRenameListener;
        private List<InputStreamProvider> mStreamProviders;
        private String mTargetDir;
        private List<LocalMedia> mediaList;

        public Builder putGear(int i) {
            return this;
        }

        Builder(Context context2) {
            this.context = context2;
            this.mPaths = new ArrayList();
            this.mediaList = new ArrayList();
            this.mStreamProviders = new ArrayList();
            this.isAndroidQ = SdkVersionUtils.checkedAndroid_Q();
        }

        private Luban build() {
            return new Luban(this);
        }

        public Builder load(InputStreamProvider inputStreamProvider) {
            this.mStreamProviders.add(inputStreamProvider);
            return this;
        }

        public <T> Builder loadMediaData(List<LocalMedia> list) {
            this.mediaList = list;
            for (LocalMedia localMedia : list) {
                load(localMedia);
            }
            return this;
        }

        private Builder load(final LocalMedia localMedia) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass1 */

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() throws IOException {
                    if (Builder.this.isAndroidQ && !localMedia.isCut()) {
                        return Builder.this.context.getContentResolver().openInputStream(Uri.parse(localMedia.getPath()));
                    }
                    return new FileInputStream(localMedia.isCut() ? localMedia.getCutPath() : localMedia.getPath());
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return localMedia.isCut() ? localMedia.getCutPath() : localMedia.getPath();
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return localMedia;
                }
            });
            return this;
        }

        public Builder load(final Uri uri) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass2 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() throws IOException {
                    return Builder.this.context.getContentResolver().openInputStream(uri);
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return uri.getPath();
                }
            });
            return this;
        }

        public Builder load(final File file) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass3 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() throws IOException {
                    return new FileInputStream(file);
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return file.getAbsolutePath();
                }
            });
            return this;
        }

        public Builder load(final String str) {
            this.mStreamProviders.add(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass4 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() throws IOException {
                    return new FileInputStream(str);
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return str;
                }
            });
            return this;
        }

        public <T> Builder load(List<T> list) {
            for (T t : list) {
                if (t instanceof String) {
                    load((String) t);
                } else if (t instanceof File) {
                    load((File) t);
                } else if (t instanceof Uri) {
                    load((Uri) t);
                } else {
                    throw new IllegalArgumentException("Incoming data type exception, it must be String, File, Uri or Bitmap");
                }
            }
            return this;
        }

        public Builder setRenameListener(OnRenameListener onRenameListener) {
            this.mRenameListener = onRenameListener;
            return this;
        }

        public Builder setCompressListener(OnCompressListener onCompressListener) {
            this.mCompressListener = onCompressListener;
            return this;
        }

        public Builder setTargetDir(String str) {
            this.mTargetDir = str;
            return this;
        }

        public Builder setFocusAlpha(boolean z) {
            this.focusAlpha = z;
            return this;
        }

        public Builder setCompressQuality(int i) {
            this.compressQuality = i;
            return this;
        }

        public Builder ignoreBy(int i) {
            this.mLeastCompressSize = i;
            return this;
        }

        public Builder filter(CompressionPredicate compressionPredicate) {
            this.mCompressionPredicate = compressionPredicate;
            return this;
        }

        public void launch() {
            build().launch(this.context);
        }

        public File get(final String str) throws IOException {
            return build().get(new InputStreamAdapter() {
                /* class com.luck.picture.lib.compress.Luban.Builder.AnonymousClass5 */

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public LocalMedia getMedia() {
                    return null;
                }

                @Override // com.luck.picture.lib.compress.InputStreamAdapter
                public InputStream openInternal() throws IOException {
                    return new FileInputStream(str);
                }

                @Override // com.luck.picture.lib.compress.InputStreamProvider
                public String getPath() {
                    return str;
                }
            }, this.context);
        }

        public List<File> get() throws IOException {
            return build().get(this.context);
        }
    }
}
