package com.luck.picture.lib.widget;

import android.content.Context;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.os.Handler;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.PopupWindow;
import androidx.core.content.ContextCompat;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import com.luck.picture.lib.R;
import com.luck.picture.lib.adapter.PictureAlbumDirectoryAdapter;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.tools.AnimUtils;
import com.luck.picture.lib.tools.AttrsUtils;
import com.luck.picture.lib.tools.ScreenUtils;
import java.util.List;

public class FolderPopWindow extends PopupWindow {
    private PictureAlbumDirectoryAdapter adapter;
    private int chooseMode;
    private PictureSelectionConfig config;
    private Context context;
    private Drawable drawableDown;
    private Drawable drawableUp;
    private boolean isDismiss = false;
    private ImageView ivArrowView;
    private int maxHeight;
    private RecyclerView recyclerView;
    private View rootViewBg;
    private View window;

    public FolderPopWindow(Context context2, PictureSelectionConfig pictureSelectionConfig) {
        this.context = context2;
        this.config = pictureSelectionConfig;
        this.chooseMode = pictureSelectionConfig.chooseMode;
        this.window = LayoutInflater.from(context2).inflate(R.layout.picture_window_folder, (ViewGroup) null);
        setContentView(this.window);
        setWidth(-1);
        setHeight(-2);
        setAnimationStyle(R.style.PictureThemeWindowStyle);
        setFocusable(true);
        setOutsideTouchable(true);
        update();
        if (pictureSelectionConfig.style != null) {
            if (pictureSelectionConfig.style.pictureTitleUpResId != 0) {
                this.drawableUp = ContextCompat.getDrawable(context2, pictureSelectionConfig.style.pictureTitleUpResId);
            }
            if (pictureSelectionConfig.style.pictureTitleDownResId != 0) {
                this.drawableDown = ContextCompat.getDrawable(context2, pictureSelectionConfig.style.pictureTitleDownResId);
            }
        } else if (pictureSelectionConfig.isWeChatStyle) {
            this.drawableUp = ContextCompat.getDrawable(context2, R.drawable.picture_icon_wechat_up);
            this.drawableDown = ContextCompat.getDrawable(context2, R.drawable.picture_icon_wechat_down);
        } else {
            if (pictureSelectionConfig.upResId != 0) {
                this.drawableUp = ContextCompat.getDrawable(context2, pictureSelectionConfig.upResId);
            } else {
                this.drawableUp = AttrsUtils.getTypeValueDrawable(context2, R.attr.picture_arrow_up_icon);
            }
            if (pictureSelectionConfig.downResId != 0) {
                this.drawableDown = ContextCompat.getDrawable(context2, pictureSelectionConfig.downResId);
            } else {
                this.drawableDown = AttrsUtils.getTypeValueDrawable(context2, R.attr.picture_arrow_down_icon);
            }
        }
        this.maxHeight = (int) (((double) ScreenUtils.getScreenHeight(context2)) * 0.6d);
        initView();
    }

    public void initView() {
        this.rootViewBg = this.window.findViewById(R.id.rootViewBg);
        this.adapter = new PictureAlbumDirectoryAdapter(this.config);
        this.recyclerView = (RecyclerView) this.window.findViewById(R.id.folder_list);
        this.recyclerView.setLayoutManager(new LinearLayoutManager(this.context));
        this.recyclerView.setAdapter(this.adapter);
        this.rootViewBg.setOnClickListener(new View.OnClickListener() {
            /* class com.luck.picture.lib.widget.$$Lambda$FolderPopWindow$fAawcR6IyRSaOKtDL1Gr6XZmPzA */

            public final void onClick(View view) {
                FolderPopWindow.this.lambda$initView$0$FolderPopWindow(view);
            }
        });
    }

    public /* synthetic */ void lambda$initView$0$FolderPopWindow(View view) {
        dismiss();
    }

    public void bindFolder(List<LocalMediaFolder> list) {
        this.adapter.setChooseMode(this.chooseMode);
        this.adapter.bindFolderData(list);
        this.recyclerView.getLayoutParams().height = (list == null || list.size() <= 8) ? -2 : this.maxHeight;
    }

    public void setArrowImageView(ImageView imageView) {
        this.ivArrowView = imageView;
    }

    public void showAsDropDown(View view) {
        try {
            if (Build.VERSION.SDK_INT == 24) {
                int[] iArr = new int[2];
                view.getLocationInWindow(iArr);
                showAtLocation(view, 0, 0, iArr[1] + view.getHeight());
            } else {
                super.showAsDropDown(view);
            }
            this.isDismiss = false;
            this.ivArrowView.setImageDrawable(this.drawableUp);
            AnimUtils.rotateArrow(this.ivArrowView, true);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void setOnItemClickListener(PictureAlbumDirectoryAdapter.OnItemClickListener onItemClickListener) {
        this.adapter.setOnItemClickListener(onItemClickListener);
    }

    public void dismiss() {
        if (!this.isDismiss) {
            this.ivArrowView.setImageDrawable(this.drawableDown);
            AnimUtils.rotateArrow(this.ivArrowView, false);
            this.isDismiss = true;
            if (Build.VERSION.SDK_INT <= 16) {
                dismiss4Pop();
                this.isDismiss = false;
                return;
            }
            super.dismiss();
            this.isDismiss = false;
        }
    }

    private void dismiss4Pop() {
        new Handler().post(new Runnable() {
            /* class com.luck.picture.lib.widget.$$Lambda$FolderPopWindow$GygpubWlHtTXZ_7LuIdq3zlxzQc */

            public final void run() {
                FolderPopWindow.this.lambda$dismiss4Pop$1$FolderPopWindow();
            }
        });
    }

    public /* synthetic */ void lambda$dismiss4Pop$1$FolderPopWindow() {
        super.dismiss();
    }

    public void notifyDataCheckedStatus(List<LocalMedia> list) {
        try {
            List<LocalMediaFolder> folderData = this.adapter.getFolderData();
            for (LocalMediaFolder localMediaFolder : folderData) {
                localMediaFolder.setCheckedNum(0);
            }
            if (list.size() > 0) {
                for (LocalMediaFolder localMediaFolder2 : folderData) {
                    int i = 0;
                    for (LocalMedia localMedia : localMediaFolder2.getImages()) {
                        String path = localMedia.getPath();
                        for (LocalMedia localMedia2 : list) {
                            if (path.equals(localMedia2.getPath())) {
                                i++;
                                localMediaFolder2.setCheckedNum(i);
                            }
                        }
                    }
                }
            }
            this.adapter.bindFolderData(folderData);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
