package com.mcxiaoke.packer.support.walle;

import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.channels.FileChannel;
import java.util.HashMap;
import java.util.Map;

/* access modifiers changed from: package-private */
public final class PayloadWriter {

    /* access modifiers changed from: package-private */
    public interface ApkSigningBlockHandler {
        ApkSigningBlock handle(Map<Integer, ByteBuffer> map);
    }

    private PayloadWriter() {
    }

    public static void writeBlock(File file, int i, byte[] bArr) throws IOException {
        ByteBuffer allocate = ByteBuffer.allocate(bArr.length);
        allocate.order(ByteOrder.LITTLE_ENDIAN);
        allocate.put(bArr, 0, bArr.length);
        allocate.flip();
        writeBlock(file, i, allocate);
    }

    public static void writeBlock(File file, int i, ByteBuffer byteBuffer) throws IOException {
        HashMap hashMap = new HashMap();
        hashMap.put(Integer.valueOf(i), byteBuffer);
        writeValues(file, hashMap);
    }

    private static void writeValues(File file, final Map<Integer, ByteBuffer> map) throws IOException {
        writeApkSigningBlock(file, new ApkSigningBlockHandler() {
            /* class com.mcxiaoke.packer.support.walle.PayloadWriter.AnonymousClass1 */

            @Override // com.mcxiaoke.packer.support.walle.PayloadWriter.ApkSigningBlockHandler
            public ApkSigningBlock handle(Map<Integer, ByteBuffer> map) {
                Map map2 = map;
                if (map2 != null && !map2.isEmpty()) {
                    map.putAll(map);
                }
                ApkSigningBlock apkSigningBlock = new ApkSigningBlock();
                for (Map.Entry<Integer, ByteBuffer> entry : map.entrySet()) {
                    apkSigningBlock.addPayload(new ApkSigningPayload(entry.getKey().intValue(), entry.getValue()));
                }
                return apkSigningBlock;
            }
        });
    }

    static void writeApkSigningBlock(File file, ApkSigningBlockHandler apkSigningBlockHandler) throws IOException {
        Throwable th;
        RandomAccessFile randomAccessFile;
        FileChannel fileChannel = null;
        try {
            randomAccessFile = new RandomAccessFile(file, "rw");
            try {
                fileChannel = randomAccessFile.getChannel();
                long findZipCommentLength = ApkUtil.findZipCommentLength(fileChannel);
                long findCentralDirStartOffset = ApkUtil.findCentralDirStartOffset(fileChannel, findZipCommentLength);
                Pair<ByteBuffer, Long> findApkSigningBlock = ApkUtil.findApkSigningBlock(fileChannel, findCentralDirStartOffset);
                ByteBuffer first = findApkSigningBlock.getFirst();
                long longValue = findApkSigningBlock.getSecond().longValue();
                if (findCentralDirStartOffset == 0 || longValue == 0) {
                    throw new IOException("No APK Signature Scheme v2 block in APK Signing Block");
                }
                Map<Integer, ByteBuffer> findIdValues = ApkUtil.findIdValues(first);
                if (findIdValues.get(Integer.valueOf((int) V2Const.APK_SIGNATURE_SCHEME_V2_BLOCK_ID)) != null) {
                    ApkSigningBlock handle = apkSigningBlockHandler.handle(findIdValues);
                    randomAccessFile.seek(findCentralDirStartOffset);
                    byte[] bArr = new byte[((int) (fileChannel.size() - findCentralDirStartOffset))];
                    randomAccessFile.read(bArr);
                    fileChannel.position(longValue);
                    long writeTo = handle.writeTo(randomAccessFile);
                    randomAccessFile.write(bArr);
                    randomAccessFile.setLength(randomAccessFile.getFilePointer());
                    randomAccessFile.seek((fileChannel.size() - findZipCommentLength) - 6);
                    ByteBuffer allocate = ByteBuffer.allocate(4);
                    allocate.order(ByteOrder.LITTLE_ENDIAN);
                    allocate.putInt((int) (((writeTo + findCentralDirStartOffset) + 8) - (findCentralDirStartOffset - longValue)));
                    allocate.flip();
                    randomAccessFile.write(allocate.array());
                    V2Utils.close(fileChannel);
                    V2Utils.close(randomAccessFile);
                    return;
                }
                throw new IOException("No APK Signature Scheme v2 block in APK Signing Block");
            } catch (Throwable th2) {
                th = th2;
                V2Utils.close(fileChannel);
                V2Utils.close(randomAccessFile);
                throw th;
            }
        } catch (Throwable th3) {
            th = th3;
            randomAccessFile = null;
            V2Utils.close(fileChannel);
            V2Utils.close(randomAccessFile);
            throw th;
        }
    }
}
