package com.rhyme.r_scan.RScanCamera;

import android.app.Activity;
import android.graphics.SurfaceTexture;
import android.hardware.camera2.CameraAccessException;
import android.hardware.camera2.CameraCaptureSession;
import android.hardware.camera2.CameraDevice;
import android.hardware.camera2.CameraManager;
import android.hardware.camera2.CaptureRequest;
import android.media.Image;
import android.media.ImageReader;
import android.os.Build;
import android.os.Handler;
import android.util.Log;
import android.util.Size;
import android.view.Surface;
import com.google.zxing.BinaryBitmap;
import com.google.zxing.MultiFormatReader;
import com.google.zxing.PlanarYUVLuminanceSource;
import com.google.zxing.Result;
import com.google.zxing.common.HybridBinarizer;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.view.TextureRegistry;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.Executor;
import java.util.concurrent.Executors;

/* access modifiers changed from: package-private */
public class RScanCamera {
    private final String TAG = "RScanCamera";
    private CameraCaptureSession cameraCaptureSession;
    private CameraDevice cameraDevice;
    private final CameraManager cameraManager;
    private final String cameraName;
    private CaptureRequest.Builder captureRequestBuilder;
    private Executor executor = Executors.newSingleThreadExecutor();
    private final TextureRegistry.SurfaceTextureEntry flutterTexture;
    private Handler handler = new Handler();
    private ImageReader imageStreamReader;
    private boolean isOpenFlash = false;
    private boolean isPlay = true;
    private long lastCurrentTimestamp = 0;
    private final Size previewSize;
    private RScanMessenger rScanMessenger;
    private MultiFormatReader reader = new MultiFormatReader();

    public enum ResolutionPreset {
        low,
        medium,
        high,
        veryHigh,
        ultraHigh,
        max
    }

    /* access modifiers changed from: package-private */
    public void startScan() {
        this.isPlay = true;
    }

    /* access modifiers changed from: package-private */
    public void stopScan() {
        this.isPlay = false;
    }

    /* access modifiers changed from: package-private */
    public void enableTorch(boolean z) throws CameraAccessException {
        if (z) {
            this.captureRequestBuilder.set(CaptureRequest.FLASH_MODE, 2);
            this.cameraCaptureSession.setRepeatingRequest(this.captureRequestBuilder.build(), null, null);
            return;
        }
        this.captureRequestBuilder.set(CaptureRequest.FLASH_MODE, 0);
        this.cameraCaptureSession.setRepeatingRequest(this.captureRequestBuilder.build(), null, null);
    }

    /* access modifiers changed from: package-private */
    public boolean isTorchOn() {
        try {
            return ((Integer) this.captureRequestBuilder.get(CaptureRequest.FLASH_MODE)).intValue() != 0;
        } catch (NullPointerException unused) {
            return false;
        }
    }

    RScanCamera(Activity activity, TextureRegistry.SurfaceTextureEntry surfaceTextureEntry, RScanMessenger rScanMessenger2, final String str, String str2) {
        if (activity != null) {
            this.cameraName = str;
            this.flutterTexture = surfaceTextureEntry;
            this.rScanMessenger = rScanMessenger2;
            this.cameraManager = (CameraManager) activity.getSystemService("camera");
            this.previewSize = CameraUtils.computeBestPreviewSize(str, ResolutionPreset.valueOf(str2));
            if (Build.VERSION.SDK_INT >= 23) {
                this.cameraManager.registerTorchCallback(new CameraManager.TorchCallback() {
                    /* class com.rhyme.r_scan.RScanCamera.RScanCamera.AnonymousClass1 */

                    public void onTorchModeUnavailable(String str) {
                        super.onTorchModeUnavailable(str);
                    }

                    public void onTorchModeChanged(String str, boolean z) {
                        super.onTorchModeChanged(str, z);
                        if (str.equals(str)) {
                            RScanCamera.this.isOpenFlash = z;
                        }
                    }
                }, (Handler) null);
                return;
            }
            return;
        }
        throw new IllegalStateException("No activity available!");
    }

    /* access modifiers changed from: package-private */
    public void open(final MethodChannel.Result result) throws CameraAccessException {
        this.imageStreamReader = ImageReader.newInstance(this.previewSize.getWidth(), this.previewSize.getHeight(), 35, 2);
        this.cameraManager.openCamera(this.cameraName, new CameraDevice.StateCallback() {
            /* class com.rhyme.r_scan.RScanCamera.RScanCamera.AnonymousClass2 */

            public void onOpened(CameraDevice cameraDevice) {
                RScanCamera.this.cameraDevice = cameraDevice;
                try {
                    RScanCamera.this.startPreview();
                    HashMap hashMap = new HashMap();
                    hashMap.put("textureId", Long.valueOf(RScanCamera.this.flutterTexture.id()));
                    hashMap.put("previewWidth", Integer.valueOf(RScanCamera.this.previewSize.getWidth()));
                    hashMap.put("previewHeight", Integer.valueOf(RScanCamera.this.previewSize.getHeight()));
                    result.success(hashMap);
                } catch (CameraAccessException e) {
                    result.error("CameraAccess", e.getMessage(), null);
                    RScanCamera.this.close();
                }
            }

            public void onClosed(CameraDevice cameraDevice) {
                super.onClosed(cameraDevice);
            }

            public void onDisconnected(CameraDevice cameraDevice) {
                RScanCamera.this.close();
            }

            public void onError(CameraDevice cameraDevice, int i) {
                RScanCamera.this.close();
            }
        }, (Handler) null);
    }

    private void createCaptureSession(Surface... surfaceArr) throws CameraAccessException {
        closeCaptureSession();
        this.captureRequestBuilder = this.cameraDevice.createCaptureRequest(1);
        SurfaceTexture surfaceTexture = this.flutterTexture.surfaceTexture();
        surfaceTexture.setDefaultBufferSize(this.previewSize.getWidth(), this.previewSize.getHeight());
        Surface surface = new Surface(surfaceTexture);
        this.captureRequestBuilder.addTarget(surface);
        List<Surface> asList = Arrays.asList(surfaceArr);
        for (Surface surface2 : asList) {
            this.captureRequestBuilder.addTarget(surface2);
        }
        AnonymousClass3 r0 = new CameraCaptureSession.StateCallback() {
            /* class com.rhyme.r_scan.RScanCamera.RScanCamera.AnonymousClass3 */

            public void onConfigureFailed(CameraCaptureSession cameraCaptureSession) {
            }

            public void onConfigured(CameraCaptureSession cameraCaptureSession) {
                try {
                    if (RScanCamera.this.cameraDevice != null) {
                        RScanCamera.this.cameraCaptureSession = cameraCaptureSession;
                        RScanCamera.this.cameraCaptureSession.setRepeatingRequest(RScanCamera.this.captureRequestBuilder.build(), null, null);
                    }
                } catch (CameraAccessException | IllegalArgumentException | IllegalStateException unused) {
                }
            }
        };
        ArrayList arrayList = new ArrayList();
        arrayList.add(surface);
        arrayList.addAll(asList);
        this.cameraDevice.createCaptureSession(arrayList, r0, null);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startPreview() throws CameraAccessException {
        startPreviewWithImageStream();
    }

    private void startPreviewWithImageStream() throws CameraAccessException {
        createCaptureSession(this.imageStreamReader.getSurface());
        this.imageStreamReader.setOnImageAvailableListener(new ImageReader.OnImageAvailableListener() {
            /* class com.rhyme.r_scan.RScanCamera.RScanCamera.AnonymousClass4 */

            public void onImageAvailable(final ImageReader imageReader) {
                RScanCamera.this.executor.execute(new Runnable() {
                    /* class com.rhyme.r_scan.RScanCamera.RScanCamera.AnonymousClass4.AnonymousClass1 */

                    public void run() {
                        Image acquireLatestImage;
                        long currentTimeMillis = System.currentTimeMillis();
                        if (currentTimeMillis - RScanCamera.this.lastCurrentTimestamp >= 1 && RScanCamera.this.isPlay == Boolean.TRUE.booleanValue() && (acquireLatestImage = imageReader.acquireLatestImage()) != null) {
                            if (35 != acquireLatestImage.getFormat()) {
                                Log.d("RScanCamera", "analyze: " + acquireLatestImage.getFormat());
                                return;
                            }
                            ByteBuffer buffer = acquireLatestImage.getPlanes()[0].getBuffer();
                            byte[] bArr = new byte[buffer.remaining()];
                            buffer.get(bArr);
                            int height = acquireLatestImage.getHeight();
                            int width = acquireLatestImage.getWidth();
                            try {
                                final Result decode = RScanCamera.this.reader.decode(new BinaryBitmap(new HybridBinarizer(new PlanarYUVLuminanceSource(bArr, width, height, 0, 0, width, height, false))));
                                if (decode != null) {
                                    RScanCamera.this.handler.post(new Runnable() {
                                        /* class com.rhyme.r_scan.RScanCamera.RScanCamera.AnonymousClass4.AnonymousClass1.AnonymousClass1 */

                                        public void run() {
                                            RScanCamera.this.rScanMessenger.send(decode);
                                        }
                                    });
                                }
                            } catch (Exception unused) {
                                buffer.clear();
                            }
                            RScanCamera.this.lastCurrentTimestamp = currentTimeMillis;
                            acquireLatestImage.close();
                        }
                    }
                });
            }
        }, this.handler);
    }

    private void closeCaptureSession() {
        CameraCaptureSession cameraCaptureSession2 = this.cameraCaptureSession;
        if (cameraCaptureSession2 != null) {
            cameraCaptureSession2.close();
            this.cameraCaptureSession = null;
        }
    }

    /* access modifiers changed from: package-private */
    public void close() {
        closeCaptureSession();
        CameraDevice cameraDevice2 = this.cameraDevice;
        if (cameraDevice2 != null) {
            cameraDevice2.close();
            this.cameraDevice = null;
        }
        ImageReader imageReader = this.imageStreamReader;
        if (imageReader != null) {
            imageReader.close();
            this.imageStreamReader = null;
        }
    }

    /* access modifiers changed from: package-private */
    public void dispose() {
        close();
        this.flutterTexture.release();
    }
}
