package com.yalantis.ucrop;

import android.content.Context;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Build;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;
import androidx.recyclerview.widget.RecyclerView;
import com.yalantis.ucrop.PicturePhotoGalleryAdapter;
import com.yalantis.ucrop.callback.BitmapLoadShowCallback;
import com.yalantis.ucrop.model.CutInfo;
import com.yalantis.ucrop.util.BitmapLoadUtils;
import com.yalantis.ucrop.util.FileUtils;
import java.io.File;
import java.util.List;

public class PicturePhotoGalleryAdapter extends RecyclerView.Adapter<ViewHolder> {
    private Context context;
    private boolean isAndroidQ;
    private List<CutInfo> list;
    private OnItemClickListener listener;
    private LayoutInflater mInflater;
    private final int maxImageHeight = 220;
    private final int maxImageWidth = 200;

    public interface OnItemClickListener {
        void onItemClick(int i, View view);
    }

    public PicturePhotoGalleryAdapter(Context context2, List<CutInfo> list2) {
        this.mInflater = LayoutInflater.from(context2);
        this.context = context2;
        this.list = list2;
        this.isAndroidQ = Build.VERSION.SDK_INT >= 29;
    }

    public void setData(List<CutInfo> list2) {
        this.list = list2;
        notifyDataSetChanged();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i) {
        return new ViewHolder(this.mInflater.inflate(R.layout.ucrop_picture_gf_adapter_edit_list, viewGroup, false));
    }

    public void onBindViewHolder(final ViewHolder viewHolder, int i) {
        CutInfo cutInfo = this.list.get(i);
        String path = cutInfo != null ? cutInfo.getPath() : "";
        int i2 = 0;
        if (cutInfo.isCut()) {
            viewHolder.iv_dot.setVisibility(0);
            viewHolder.iv_dot.setImageResource(R.drawable.ucrop_oval_true);
        } else {
            viewHolder.iv_dot.setVisibility(4);
        }
        Uri parse = this.isAndroidQ ? Uri.parse(path) : Uri.fromFile(new File(path));
        TextView textView = viewHolder.tvGif;
        if (!FileUtils.isGif(cutInfo.getMimeType())) {
            i2 = 8;
        }
        textView.setVisibility(i2);
        BitmapLoadUtils.decodeBitmapInBackground(this.context, parse, 200, 220, new BitmapLoadShowCallback() {
            /* class com.yalantis.ucrop.PicturePhotoGalleryAdapter.AnonymousClass1 */

            @Override // com.yalantis.ucrop.callback.BitmapLoadShowCallback
            public void onBitmapLoaded(Bitmap bitmap) {
                if (viewHolder.mIvPhoto != null) {
                    viewHolder.mIvPhoto.setImageBitmap(bitmap);
                }
            }

            @Override // com.yalantis.ucrop.callback.BitmapLoadShowCallback
            public void onFailure(Exception exc) {
                if (viewHolder.mIvPhoto != null) {
                    viewHolder.mIvPhoto.setImageResource(R.color.ucrop_color_ba3);
                }
            }
        });
        viewHolder.itemView.setOnClickListener(new View.OnClickListener(viewHolder) {
            /* class com.yalantis.ucrop.$$Lambda$PicturePhotoGalleryAdapter$X3WmoW3FOwRuXM9N_R0uc7o73MA */
            private final /* synthetic */ PicturePhotoGalleryAdapter.ViewHolder f$1;

            {
                this.f$1 = r2;
            }

            public final void onClick(View view) {
                PicturePhotoGalleryAdapter.this.lambda$onBindViewHolder$0$PicturePhotoGalleryAdapter(this.f$1, view);
            }
        });
    }

    public /* synthetic */ void lambda$onBindViewHolder$0$PicturePhotoGalleryAdapter(ViewHolder viewHolder, View view) {
        OnItemClickListener onItemClickListener = this.listener;
        if (onItemClickListener != null) {
            onItemClickListener.onItemClick(viewHolder.getAdapterPosition(), view);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        List<CutInfo> list2 = this.list;
        if (list2 != null) {
            return list2.size();
        }
        return 0;
    }

    public static class ViewHolder extends RecyclerView.ViewHolder {
        ImageView iv_dot;
        ImageView mIvPhoto;
        TextView tvGif;

        public ViewHolder(View view) {
            super(view);
            this.mIvPhoto = (ImageView) view.findViewById(R.id.iv_photo);
            this.iv_dot = (ImageView) view.findViewById(R.id.iv_dot);
            this.tvGif = (TextView) view.findViewById(R.id.tv_gif);
        }
    }

    public void setOnItemClickListener(OnItemClickListener onItemClickListener) {
        this.listener = onItemClickListener;
    }
}
