package io.flutter.embedding.engine.systemchannels;

import android.os.Build;
import android.view.InputDevice;
import android.view.KeyEvent;
import io.flutter.Log;
import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.JSONMessageCodec;
import java.util.HashMap;
import java.util.Map;
import org.json.JSONException;
import org.json.JSONObject;
import tv.danmaku.ijk.media.player.IjkMediaMeta;

public class KeyEventChannel {
    private static final String TAG = "KeyEventChannel";
    public final BasicMessageChannel<Object> channel;
    private EventResponseHandler eventResponseHandler;

    public interface EventResponseHandler {
        void onKeyEventHandled(long j);

        void onKeyEventNotHandled(long j);
    }

    public void setEventResponseHandler(EventResponseHandler eventResponseHandler2) {
        this.eventResponseHandler = eventResponseHandler2;
    }

    public KeyEventChannel(BinaryMessenger binaryMessenger) {
        this.channel = new BasicMessageChannel<>(binaryMessenger, "flutter/keyevent", JSONMessageCodec.INSTANCE);
    }

    /* access modifiers changed from: package-private */
    public BasicMessageChannel.Reply<Object> createReplyHandler(long j) {
        return new BasicMessageChannel.Reply(j) {
            /* class io.flutter.embedding.engine.systemchannels.$$Lambda$KeyEventChannel$noIAfhEsnbVSFihKYSNN7XvL4E */
            private final /* synthetic */ long f$1;

            {
                this.f$1 = r2;
            }

            @Override // io.flutter.plugin.common.BasicMessageChannel.Reply
            public final void reply(Object obj) {
                KeyEventChannel.this.lambda$createReplyHandler$0$KeyEventChannel(this.f$1, obj);
            }
        };
    }

    public /* synthetic */ void lambda$createReplyHandler$0$KeyEventChannel(long j, Object obj) {
        EventResponseHandler eventResponseHandler2 = this.eventResponseHandler;
        if (eventResponseHandler2 != null) {
            if (obj == null) {
                try {
                    eventResponseHandler2.onKeyEventNotHandled(j);
                } catch (JSONException e) {
                    Log.e(TAG, "Unable to unpack JSON message: " + e);
                    this.eventResponseHandler.onKeyEventNotHandled(j);
                }
            } else if (((JSONObject) obj).getBoolean("handled")) {
                this.eventResponseHandler.onKeyEventHandled(j);
            } else {
                this.eventResponseHandler.onKeyEventNotHandled(j);
            }
        }
    }

    public void keyUp(FlutterKeyEvent flutterKeyEvent) {
        HashMap hashMap = new HashMap();
        hashMap.put(IjkMediaMeta.IJKM_KEY_TYPE, "keyup");
        hashMap.put("keymap", "android");
        encodeKeyEvent(flutterKeyEvent, hashMap);
        this.channel.send(hashMap, createReplyHandler(flutterKeyEvent.eventId));
    }

    public void keyDown(FlutterKeyEvent flutterKeyEvent) {
        HashMap hashMap = new HashMap();
        hashMap.put(IjkMediaMeta.IJKM_KEY_TYPE, "keydown");
        hashMap.put("keymap", "android");
        encodeKeyEvent(flutterKeyEvent, hashMap);
        this.channel.send(hashMap, createReplyHandler(flutterKeyEvent.eventId));
    }

    private void encodeKeyEvent(FlutterKeyEvent flutterKeyEvent, Map<String, Object> map) {
        map.put("flags", Integer.valueOf(flutterKeyEvent.flags));
        map.put("plainCodePoint", Integer.valueOf(flutterKeyEvent.plainCodePoint));
        map.put("codePoint", Integer.valueOf(flutterKeyEvent.codePoint));
        map.put("keyCode", Integer.valueOf(flutterKeyEvent.keyCode));
        map.put("scanCode", Integer.valueOf(flutterKeyEvent.scanCode));
        map.put("metaState", Integer.valueOf(flutterKeyEvent.metaState));
        if (flutterKeyEvent.complexCharacter != null) {
            map.put("character", flutterKeyEvent.complexCharacter.toString());
        }
        map.put("source", Integer.valueOf(flutterKeyEvent.source));
        map.put("vendorId", Integer.valueOf(flutterKeyEvent.vendorId));
        map.put("productId", Integer.valueOf(flutterKeyEvent.productId));
        map.put("deviceId", Integer.valueOf(flutterKeyEvent.deviceId));
        map.put("repeatCount", Integer.valueOf(flutterKeyEvent.repeatCount));
    }

    public static class FlutterKeyEvent {
        public final int codePoint;
        public final Character complexCharacter;
        public final int deviceId;
        public final long eventId;
        public final int flags;
        public final int keyCode;
        public final int metaState;
        public final int plainCodePoint;
        public final int productId;
        public final int repeatCount;
        public final int scanCode;
        public final int source;
        public final int vendorId;

        public FlutterKeyEvent(KeyEvent keyEvent, long j) {
            this(keyEvent, null, j);
        }

        public FlutterKeyEvent(KeyEvent keyEvent, Character ch, long j) {
            this(keyEvent.getDeviceId(), keyEvent.getFlags(), keyEvent.getUnicodeChar(0), keyEvent.getUnicodeChar(), keyEvent.getKeyCode(), ch, keyEvent.getScanCode(), keyEvent.getMetaState(), keyEvent.getSource(), keyEvent.getRepeatCount(), j);
        }

        public FlutterKeyEvent(int i, int i2, int i3, int i4, int i5, Character ch, int i6, int i7, int i8, int i9, long j) {
            this.deviceId = i;
            this.flags = i2;
            this.plainCodePoint = i3;
            this.codePoint = i4;
            this.keyCode = i5;
            this.complexCharacter = ch;
            this.scanCode = i6;
            this.metaState = i7;
            this.source = i8;
            this.repeatCount = i9;
            this.eventId = j;
            InputDevice device = InputDevice.getDevice(i);
            if (device == null) {
                this.vendorId = 0;
                this.productId = 0;
            } else if (Build.VERSION.SDK_INT >= 19) {
                this.vendorId = device.getVendorId();
                this.productId = device.getProductId();
            } else {
                this.vendorId = 0;
                this.productId = 0;
            }
        }
    }
}
