package tv.danmaku.ijk.media.player.misc;

import android.graphics.SurfaceTexture;
import android.view.Surface;
import tv.danmaku.ijk.media.player.pragma.DebugLog;

public class MediaCodecSurface {
    public boolean mAttached = false;
    public boolean mReleased = false;
    public Surface mSurface = new Surface(this.mSurfaceTexture);
    public SurfaceTexture mSurfaceTexture = new SurfaceTexture(0);

    public MediaCodecSurface() {
        this.mSurfaceTexture.detachFromGLContext();
    }

    public void attachToGLContext(int i, int i2, int i3) {
        if (!this.mReleased && !this.mAttached) {
            this.mAttached = true;
            this.mSurfaceTexture.attachToGLContext(i);
        }
    }

    public void detachFromGLContext() {
        if (this.mAttached) {
            this.mSurfaceTexture.detachFromGLContext();
            this.mAttached = false;
        }
    }

    public Surface getSurface() {
        if (this.mReleased) {
            return null;
        }
        return this.mSurface;
    }

    public SurfaceTexture getSurfaceTexture() {
        if (this.mReleased) {
            return null;
        }
        return this.mSurfaceTexture;
    }

    public void release() {
        DebugLog.d("MediaCodecSurface", "release()," + this.mReleased);
        this.mReleased = true;
        SurfaceTexture surfaceTexture = this.mSurfaceTexture;
        if (surfaceTexture != null) {
            surfaceTexture.release();
            this.mSurfaceTexture = null;
        }
        Surface surface = this.mSurface;
        if (surface != null) {
            surface.release();
            this.mSurface = null;
        }
    }

    public void updateTexImage(float[] fArr) {
        if (!this.mReleased && this.mAttached) {
            this.mSurfaceTexture.updateTexImage();
            this.mSurfaceTexture.getTransformMatrix(fArr);
        }
    }
}
