package androidx.camera.core.impl;

import androidx.camera.core.Camera;
import androidx.camera.core.CameraControl;
import androidx.camera.core.CameraInfo;
import androidx.camera.core.UseCase;
import androidx.camera.core.internal.CameraUseCaseAdapter;
import com.google.common.util.concurrent.ListenableFuture;
import java.util.Collection;
import java.util.Collections;
import java.util.LinkedHashSet;

public interface CameraInternal extends Camera, UseCase.StateChangeCallback {
    void attachUseCases(Collection<UseCase> collection);

    void close();

    void detachUseCases(Collection<UseCase> collection);

    @Override // androidx.camera.core.Camera
    CameraControl getCameraControl();

    CameraControlInternal getCameraControlInternal();

    @Override // androidx.camera.core.Camera
    CameraInfo getCameraInfo();

    CameraInfoInternal getCameraInfoInternal();

    @Override // androidx.camera.core.Camera
    LinkedHashSet<CameraInternal> getCameraInternals();

    Quirks getCameraQuirks();

    Observable<State> getCameraState();

    @Override // androidx.camera.core.Camera
    CameraConfig getExtendedConfig();

    void open();

    ListenableFuture<Void> release();

    @Override // androidx.camera.core.Camera
    void setExtendedConfig(CameraConfig cameraConfig) throws CameraUseCaseAdapter.CameraException;

    public enum State {
        PENDING_OPEN(false),
        OPENING(true),
        OPEN(true),
        CLOSING(true),
        CLOSED(false),
        RELEASING(true),
        RELEASED(false);
        
        private final boolean mHoldsCameraSlot;

        private State(boolean z) {
            this.mHoldsCameraSlot = z;
        }

        /* access modifiers changed from: package-private */
        public boolean holdsCameraSlot() {
            return this.mHoldsCameraSlot;
        }
    }

    /* renamed from: androidx.camera.core.impl.CameraInternal$-CC  reason: invalid class name */
    public final /* synthetic */ class CC {
        public static void $default$setExtendedConfig(CameraInternal cameraInternal, CameraConfig cameraConfig) throws CameraUseCaseAdapter.CameraException {
        }

        public static CameraControl $default$getCameraControl(CameraInternal _this) {
            return _this.getCameraControlInternal();
        }

        public static CameraInfo $default$getCameraInfo(CameraInternal _this) {
            return _this.getCameraInfoInternal();
        }

        /* JADX WARN: Incorrect args count in method signature: ()Ljava/util/LinkedHashSet<Landroidx/camera/core/impl/CameraInternal;>; */
        public static LinkedHashSet $default$getCameraInternals(CameraInternal _this) {
            return new LinkedHashSet(Collections.singleton(_this));
        }

        public static CameraConfig $default$getExtendedConfig(CameraInternal _this) {
            return CameraConfigs.emptyConfig();
        }
    }
}
