package androidx.camera.extensions.internal;

import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.locks.Condition;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

/* access modifiers changed from: package-private */
public final class BlockingCloseAccessCounter {
    private static final int COUNTER_DESTROYED_FLAG = -1;
    private AtomicInteger mAccessCount = new AtomicInteger(0);
    private final Condition mDoneCondition = this.mLock.newCondition();
    private final Lock mLock = new ReentrantLock();

    BlockingCloseAccessCounter() {
    }

    /* access modifiers changed from: package-private */
    public boolean tryIncrement() {
        this.mLock.lock();
        try {
            if (this.mAccessCount.get() == -1) {
                return false;
            }
            this.mAccessCount.getAndIncrement();
            this.mLock.unlock();
            return true;
        } finally {
            this.mLock.unlock();
        }
    }

    /* access modifiers changed from: package-private */
    public void decrement() {
        this.mLock.lock();
        try {
            int andDecrement = this.mAccessCount.getAndDecrement();
            if (andDecrement == -1) {
                throw new IllegalStateException("Unable to decrement. Counter already destroyed");
            } else if (andDecrement != 0) {
                this.mDoneCondition.signal();
            } else {
                throw new IllegalStateException("Unable to decrement. No corresponding counter increment");
            }
        } finally {
            this.mLock.unlock();
        }
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:1:0x0005 */
    /* JADX WARNING: Removed duplicated region for block: B:4:0x000f A[SYNTHETIC, Splitter:B:4:0x000f] */
    public void destroyAndWaitForZeroAccess() {
        this.mLock.lock();
        while (!this.mAccessCount.compareAndSet(0, -1)) {
            try {
                this.mDoneCondition.await();
            } finally {
                this.mLock.unlock();
            }
        }
    }
}
