package com.dooboolab.fluttersound;

import android.media.MediaPlayer;
import android.media.MediaRecorder;
import android.os.Build;
import android.os.Handler;
import android.os.SystemClock;
import android.util.Log;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;
import java.io.File;
import java.io.FileOutputStream;
import java.util.Timer;
import java.util.TimerTask;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import org.json.JSONException;
import org.json.JSONObject;

public class FlutterSoundPlugin implements MethodChannel.MethodCallHandler, PluginRegistry.RequestPermissionsResultListener, AudioInterface {
    static final int CODEC_OPUS = 2;
    static final int CODEC_VORBIS = 5;
    private static final String ERR_PLAYER_IS_NULL = "ERR_PLAYER_IS_NULL";
    private static final String ERR_PLAYER_IS_PLAYING = "ERR_PLAYER_IS_PLAYING";
    private static final String ERR_RECORDER_IS_NULL = "ERR_RECORDER_IS_NULL";
    private static final String ERR_RECORDER_IS_RECORDING = "ERR_RECORDER_IS_RECORDING";
    private static final String ERR_UNKNOWN = "ERR_UNKNOWN";
    static final String PLAY_STREAM = "com.dooboolab.fluttersound/play";
    static final String RECORD_STREAM = "com.dooboolab.fluttersound/record";
    static final String TAG = "FlutterSoundPlugin";
    static boolean[] _isAndroidDecoderSupported = {true, true, true, false, true, true, true};
    static boolean[] _isAndroidEncoderSupported = {true, true, false, false, false, false, false};
    private static MethodChannel channel;
    static int[] codecArray = {0, 3, 7, 0, 0, 6, 0};
    static int[] formatsArray = {6, 6, 11, 0, 0, 11, 0};
    static String[] pathArray = {"sound.acc", "sound.acc", "sound.opus", "sound.caf", "sound.mp3", "sound.ogg", "sound.wav"};
    private static PluginRegistry.Registrar reg;
    private final Handler dbPeakLevelHandler = new Handler();
    String[] extentionArray = {"acc", "acc", "opus", "caf", "mp3", "ogg", "wav"};
    String finalPath;
    private Timer mTimer = new Timer();
    private final Handler mainHandler = new Handler();
    private final AudioModel model = new AudioModel();
    private final Handler recordHandler = new Handler();
    private final ExecutorService taskScheduler = Executors.newSingleThreadExecutor();

    private FlutterSoundPlugin(PluginRegistry.Registrar registrar) {
        channel = new MethodChannel(registrar.messenger(), "flutter_sound");
        channel.setMethodCallHandler(this);
        reg = registrar;
    }

    public static void registerWith(PluginRegistry.Registrar registrar) {
        new FlutterSoundPlugin(registrar);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    @Override // io.flutter.plugin.common.MethodChannel.MethodCallHandler
    public void onMethodCall(MethodCall methodCall, MethodChannel.Result result) {
        char c;
        String str = (String) methodCall.argument("path");
        String str2 = methodCall.method;
        int i = 0;
        switch (str2.hashCode()) {
            case -1978808627:
                if (str2.equals("startPlayerFromBuffer")) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case -1972505888:
                if (str2.equals("stopRecorder")) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case -1959921181:
                if (str2.equals("startPlayer")) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case -1899438985:
                if (str2.equals("pausePlayer")) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            case -1548073362:
                if (str2.equals("setDbPeakLevelUpdate")) {
                    c = 11;
                    break;
                }
                c = 65535;
                break;
            case -1444181677:
                if (str2.equals("setSubscriptionDuration")) {
                    c = '\r';
                    break;
                }
                c = 65535;
                break;
            case -1442839165:
                if (str2.equals("stopPlayer")) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case -672116928:
                if (str2.equals("startRecorder")) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case -56585708:
                if (str2.equals("isDecoderSupported")) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case 115944508:
                if (str2.equals("isEncoderSupported")) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 552978388:
                if (str2.equals("seekToPlayer")) {
                    c = '\t';
                    break;
                }
                c = 65535;
                break;
            case 670514716:
                if (str2.equals("setVolume")) {
                    c = '\n';
                    break;
                }
                c = 65535;
                break;
            case 896668605:
                if (str2.equals("setDbLevelEnabled")) {
                    c = '\f';
                    break;
                }
                c = 65535;
                break;
            case 1408481646:
                if (str2.equals("resumePlayer")) {
                    c = '\b';
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                int intValue = ((Integer) methodCall.argument("codec")).intValue();
                boolean z = _isAndroidDecoderSupported[intValue];
                if (Build.VERSION.SDK_INT < 23 && (intValue == 2 || intValue == 5)) {
                    z = false;
                }
                result.success(Boolean.valueOf(z));
                return;
            case 1:
                int intValue2 = ((Integer) methodCall.argument("codec")).intValue();
                boolean z2 = _isAndroidEncoderSupported[intValue2];
                if (Build.VERSION.SDK_INT < 29 && (intValue2 == 2 || intValue2 == 5)) {
                    z2 = false;
                }
                result.success(Boolean.valueOf(z2));
                return;
            case 2:
                this.taskScheduler.submit(new Runnable(methodCall, str, result) {
                    /* class com.dooboolab.fluttersound.$$Lambda$FlutterSoundPlugin$Uw7hmMVnMhHSlTmtp8I_WAUlmZE */
                    private final /* synthetic */ MethodCall f$1;
                    private final /* synthetic */ String f$2;
                    private final /* synthetic */ MethodChannel.Result f$3;

                    {
                        this.f$1 = r2;
                        this.f$2 = r3;
                        this.f$3 = r4;
                    }

                    public final void run() {
                        FlutterSoundPlugin.this.lambda$onMethodCall$0$FlutterSoundPlugin(this.f$1, this.f$2, this.f$3);
                    }
                });
                return;
            case 3:
                this.taskScheduler.submit(new Runnable(result) {
                    /* class com.dooboolab.fluttersound.$$Lambda$FlutterSoundPlugin$N_oLCG8XbbFsDuyjpzm5ucCAKqw */
                    private final /* synthetic */ MethodChannel.Result f$1;

                    {
                        this.f$1 = r2;
                    }

                    public final void run() {
                        FlutterSoundPlugin.this.lambda$onMethodCall$1$FlutterSoundPlugin(this.f$1);
                    }
                });
                return;
            case 4:
                startPlayer(str, result);
                return;
            case 5:
                Integer num = (Integer) methodCall.argument("codec");
                t_CODEC[] values = t_CODEC.values();
                if (num != null) {
                    i = num.intValue();
                }
                startPlayerFromBuffer((byte[]) methodCall.argument("dataBuffer"), values[i], result);
                return;
            case 6:
                stopPlayer(result);
                return;
            case 7:
                pausePlayer(result);
                return;
            case '\b':
                resumePlayer(result);
                return;
            case '\t':
                seekToPlayer(((Integer) methodCall.argument("sec")).intValue(), result);
                return;
            case '\n':
                setVolume(((Double) methodCall.argument("volume")).doubleValue(), result);
                return;
            case 11:
                setDbPeakLevelUpdate(((Double) methodCall.argument("intervalInSecs")).doubleValue(), result);
                return;
            case '\f':
                setDbLevelEnabled(((Boolean) methodCall.argument("enabled")).booleanValue(), result);
                return;
            case '\r':
                if (methodCall.argument("sec") != null) {
                    setSubscriptionDuration(((Double) methodCall.argument("sec")).doubleValue(), result);
                    return;
                }
                return;
            default:
                result.notImplemented();
                return;
        }
    }

    public /* synthetic */ void lambda$onMethodCall$0$FlutterSoundPlugin(MethodCall methodCall, String str, MethodChannel.Result result) {
        Integer num = (Integer) methodCall.argument("sampleRate");
        startRecorder((Integer) methodCall.argument("numChannels"), num, (Integer) methodCall.argument("bitRate"), t_CODEC.values()[((Integer) methodCall.argument("codec")).intValue()], ((Integer) methodCall.argument("androidEncoder")).intValue(), ((Integer) methodCall.argument("androidAudioSource")).intValue(), ((Integer) methodCall.argument("androidOutputFormat")).intValue(), str, result);
    }

    @Override // io.flutter.plugin.common.PluginRegistry.RequestPermissionsResultListener
    public boolean onRequestPermissionsResult(int i, String[] strArr, int[] iArr) {
        return i == 200 && iArr[0] == 0;
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    public void startRecorder(Integer num, Integer num2, Integer num3, t_CODEC t_codec, int i, int i2, int i3, String str, final MethodChannel.Result result) {
        int i4 = Build.VERSION.SDK_INT;
        if (sdkCompat.checkRecordPermission(reg) != 0) {
            result.error(TAG, "NO PERMISSION GRANTED", "android.permission.RECORD_AUDIO or android.permission.WRITE_EXTERNAL_STORAGE");
            return;
        }
        MediaRecorder mediaRecorder = this.model.getMediaRecorder();
        if (mediaRecorder == null) {
            this.model.setMediaRecorder(new MediaRecorder());
            mediaRecorder = this.model.getMediaRecorder();
        } else {
            mediaRecorder.reset();
        }
        mediaRecorder.setAudioSource(i2);
        if (codecArray[t_codec.ordinal()] == 0) {
            result.error(TAG, "UNSUPPORTED", "Unsupported encoder");
            return;
        }
        int i5 = codecArray[t_codec.ordinal()];
        mediaRecorder.setOutputFormat(formatsArray[t_codec.ordinal()]);
        if (str == null) {
            str = pathArray[t_codec.ordinal()];
        }
        mediaRecorder.setOutputFile(str);
        mediaRecorder.setAudioEncoder(i5);
        if (num != null) {
            mediaRecorder.setAudioChannels(num.intValue());
        }
        if (num2 != null) {
            mediaRecorder.setAudioSamplingRate(num2.intValue());
        }
        if (num3 != null) {
            mediaRecorder.setAudioEncodingBitRate(num3.intValue());
        }
        try {
            mediaRecorder.prepare();
            mediaRecorder.start();
            this.recordHandler.removeCallbacksAndMessages(null);
            this.model.setRecorderTicker(new Runnable(SystemClock.elapsedRealtime()) {
                /* class com.dooboolab.fluttersound.$$Lambda$FlutterSoundPlugin$uooajoJpLjjX_wTruemSTuewMhs */
                private final /* synthetic */ long f$1;

                {
                    this.f$1 = r2;
                }

                public final void run() {
                    FlutterSoundPlugin.this.lambda$startRecorder$2$FlutterSoundPlugin(this.f$1);
                }
            });
            this.recordHandler.post(this.model.getRecorderTicker());
            if (this.model.shouldProcessDbLevel) {
                this.dbPeakLevelHandler.removeCallbacksAndMessages(null);
                this.model.setDbLevelTicker(new Runnable() {
                    /* class com.dooboolab.fluttersound.$$Lambda$FlutterSoundPlugin$K_bb_FIX6tSbJZZ5ESRwkfqU8Y */

                    public final void run() {
                        FlutterSoundPlugin.this.lambda$startRecorder$3$FlutterSoundPlugin();
                    }
                });
                this.dbPeakLevelHandler.post(this.model.getDbLevelTicker());
            }
            this.finalPath = str;
            this.mainHandler.post(new Runnable() {
                /* class com.dooboolab.fluttersound.FlutterSoundPlugin.AnonymousClass1 */

                public void run() {
                    result.success(FlutterSoundPlugin.this.finalPath);
                }
            });
        } catch (Exception e) {
            Log.e(TAG, "Exception: ", e);
        }
    }

    public /* synthetic */ void lambda$startRecorder$2$FlutterSoundPlugin(long j) {
        long elapsedRealtime = SystemClock.elapsedRealtime() - j;
        try {
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("current_position", String.valueOf(elapsedRealtime));
            channel.invokeMethod("updateRecorderProgress", jSONObject.toString());
            this.recordHandler.postDelayed(this.model.getRecorderTicker(), (long) this.model.subsDurationMillis);
        } catch (JSONException e) {
            Log.d(TAG, "Json Exception: " + e.toString());
        }
    }

    public /* synthetic */ void lambda$startRecorder$3$FlutterSoundPlugin() {
        MediaRecorder mediaRecorder = this.model.getMediaRecorder();
        if (mediaRecorder != null) {
            double maxAmplitude = (double) mediaRecorder.getMaxAmplitude();
            double log10 = Math.log10((maxAmplitude / 51805.5336d) / 2.0E-4d) * 20.0d;
            if (Double.isInfinite(log10)) {
                log10 = 0.0d;
            }
            Log.d(TAG, "rawAmplitude: " + maxAmplitude + " Base DB: " + log10);
            channel.invokeMethod("updateDbPeakProgress", Double.valueOf(log10));
            this.dbPeakLevelHandler.postDelayed(this.model.getDbLevelTicker(), this.model.peakLevelUpdateMillis);
        }
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    /* renamed from: stopRecorder */
    public void lambda$onMethodCall$1$FlutterSoundPlugin(final MethodChannel.Result result) {
        this.recordHandler.removeCallbacksAndMessages(null);
        this.dbPeakLevelHandler.removeCallbacksAndMessages(null);
        if (this.model.getMediaRecorder() == null) {
            Log.d(TAG, "mediaRecorder is null");
            result.error(ERR_RECORDER_IS_NULL, ERR_RECORDER_IS_NULL, ERR_RECORDER_IS_NULL);
            return;
        }
        this.model.getMediaRecorder().stop();
        this.model.getMediaRecorder().reset();
        this.model.getMediaRecorder().release();
        this.model.setMediaRecorder(null);
        this.mainHandler.post(new Runnable() {
            /* class com.dooboolab.fluttersound.FlutterSoundPlugin.AnonymousClass2 */

            public void run() {
                result.success(FlutterSoundPlugin.this.finalPath);
            }
        });
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    public void startPlayer(String str, MethodChannel.Result result) {
        if (this.model.getMediaPlayer() != null) {
            boolean z = true;
            if (this.model.getMediaPlayer().isPlaying() || this.model.getMediaPlayer().getCurrentPosition() <= 1) {
                z = false;
            }
            if (Boolean.valueOf(z).booleanValue()) {
                this.model.getMediaPlayer().start();
                result.success("player resumed.");
                return;
            }
            Log.e(TAG, "Player is already running. Stop it first.");
            result.success("player is already running.");
            return;
        }
        this.model.setMediaPlayer(new MediaPlayer());
        this.mTimer = new Timer();
        if (str == null) {
            try {
                this.model.getMediaPlayer().setDataSource(AudioModel.DEFAULT_FILE_LOCATION);
            } catch (Exception e) {
                Log.e(TAG, "startPlayer() exception");
                result.error(ERR_UNKNOWN, ERR_UNKNOWN, e.getMessage());
                return;
            }
        } else {
            this.model.getMediaPlayer().setDataSource(str);
        }
        this.model.getMediaPlayer().setOnPreparedListener(new MediaPlayer.OnPreparedListener(str, result) {
            /* class com.dooboolab.fluttersound.$$Lambda$FlutterSoundPlugin$WKoBFlD2SGEZtteHMH13N_R4Ao */
            private final /* synthetic */ String f$1;
            private final /* synthetic */ MethodChannel.Result f$2;

            {
                this.f$1 = r2;
                this.f$2 = r3;
            }

            public final void onPrepared(MediaPlayer mediaPlayer) {
                FlutterSoundPlugin.this.lambda$startPlayer$4$FlutterSoundPlugin(this.f$1, this.f$2, mediaPlayer);
            }
        });
        this.model.getMediaPlayer().setOnCompletionListener(new MediaPlayer.OnCompletionListener() {
            /* class com.dooboolab.fluttersound.$$Lambda$FlutterSoundPlugin$hvKAmEkZ5ZM9XCFi8tPrkqtCkww */

            public final void onCompletion(MediaPlayer mediaPlayer) {
                FlutterSoundPlugin.this.lambda$startPlayer$5$FlutterSoundPlugin(mediaPlayer);
            }
        });
        this.model.getMediaPlayer().prepare();
    }

    public /* synthetic */ void lambda$startPlayer$4$FlutterSoundPlugin(String str, MethodChannel.Result result, final MediaPlayer mediaPlayer) {
        Log.d(TAG, "mediaPlayer prepared and start");
        mediaPlayer.start();
        this.mTimer.schedule(new TimerTask() {
            /* class com.dooboolab.fluttersound.FlutterSoundPlugin.AnonymousClass3 */

            public void run() {
                try {
                    final JSONObject jSONObject = new JSONObject();
                    jSONObject.put("duration", String.valueOf(mediaPlayer.getDuration()));
                    jSONObject.put("current_position", String.valueOf(mediaPlayer.getCurrentPosition()));
                    FlutterSoundPlugin.this.mainHandler.post(new Runnable() {
                        /* class com.dooboolab.fluttersound.FlutterSoundPlugin.AnonymousClass3.AnonymousClass1 */

                        public void run() {
                            FlutterSoundPlugin.channel.invokeMethod("updateProgress", jSONObject.toString());
                        }
                    });
                } catch (JSONException e) {
                    Log.d(FlutterSoundPlugin.TAG, "Json Exception: " + e.toString());
                }
            }
        }, 0, (long) this.model.subsDurationMillis);
        if (str == null) {
            str = AudioModel.DEFAULT_FILE_LOCATION;
        }
        result.success(str);
    }

    public /* synthetic */ void lambda$startPlayer$5$FlutterSoundPlugin(MediaPlayer mediaPlayer) {
        Log.d(TAG, "Plays completed.");
        try {
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("duration", String.valueOf(mediaPlayer.getDuration()));
            jSONObject.put("current_position", String.valueOf(mediaPlayer.getCurrentPosition()));
            channel.invokeMethod("audioPlayerDidFinishPlaying", jSONObject.toString());
        } catch (JSONException e) {
            Log.d(TAG, "Json Exception: " + e.toString());
        }
        this.mTimer.cancel();
        if (mediaPlayer.isPlaying()) {
            mediaPlayer.stop();
        }
        mediaPlayer.reset();
        mediaPlayer.release();
        this.model.setMediaPlayer(null);
    }

    public void startPlayerFromBuffer(byte[] bArr, t_CODEC t_codec, MethodChannel.Result result) {
        try {
            File createTempFile = File.createTempFile("flutter_sound", this.extentionArray[t_codec.ordinal()]);
            new FileOutputStream(createTempFile).write(bArr);
            startPlayer(createTempFile.getAbsolutePath(), result);
        } catch (Exception e) {
            result.error(ERR_UNKNOWN, ERR_UNKNOWN, e.getMessage());
        }
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    public void stopPlayer(MethodChannel.Result result) {
        this.mTimer.cancel();
        if (this.model.getMediaPlayer() == null) {
            result.error(ERR_PLAYER_IS_NULL, ERR_PLAYER_IS_NULL, ERR_PLAYER_IS_NULL);
            return;
        }
        try {
            this.model.getMediaPlayer().stop();
            this.model.getMediaPlayer().reset();
            this.model.getMediaPlayer().release();
            this.model.setMediaPlayer(null);
            result.success("stopped player.");
        } catch (Exception e) {
            Log.e(TAG, "stopPlay exception: " + e.getMessage());
            result.error(ERR_UNKNOWN, ERR_UNKNOWN, e.getMessage());
        }
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    public void pausePlayer(MethodChannel.Result result) {
        if (this.model.getMediaPlayer() == null) {
            result.error(ERR_PLAYER_IS_NULL, ERR_PLAYER_IS_NULL, ERR_PLAYER_IS_NULL);
            return;
        }
        try {
            this.model.getMediaPlayer().pause();
            result.success("paused player.");
        } catch (Exception e) {
            Log.e(TAG, "pausePlay exception: " + e.getMessage());
            result.error(ERR_UNKNOWN, ERR_UNKNOWN, e.getMessage());
        }
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    public void resumePlayer(MethodChannel.Result result) {
        if (this.model.getMediaPlayer() == null) {
            result.error(ERR_PLAYER_IS_NULL, ERR_PLAYER_IS_NULL, ERR_PLAYER_IS_NULL);
        } else if (this.model.getMediaPlayer().isPlaying()) {
            result.error(ERR_PLAYER_IS_PLAYING, ERR_PLAYER_IS_PLAYING, ERR_PLAYER_IS_PLAYING);
        } else {
            try {
                this.model.getMediaPlayer().seekTo(this.model.getMediaPlayer().getCurrentPosition());
                this.model.getMediaPlayer().start();
                result.success("resumed player.");
            } catch (Exception e) {
                Log.e(TAG, "mediaPlayer resume: " + e.getMessage());
                result.error(ERR_UNKNOWN, ERR_UNKNOWN, e.getMessage());
            }
        }
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    public void seekToPlayer(int i, MethodChannel.Result result) {
        if (this.model.getMediaPlayer() == null) {
            result.error(ERR_PLAYER_IS_NULL, ERR_PLAYER_IS_NULL, ERR_PLAYER_IS_NULL);
            return;
        }
        int currentPosition = this.model.getMediaPlayer().getCurrentPosition();
        Log.d(TAG, "currentMillis: " + currentPosition);
        Log.d(TAG, "seekTo: " + i);
        this.model.getMediaPlayer().seekTo(i);
        result.success(String.valueOf(i));
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    public void setVolume(double d, MethodChannel.Result result) {
        if (this.model.getMediaPlayer() == null) {
            result.error(ERR_PLAYER_IS_NULL, ERR_PLAYER_IS_NULL, ERR_PLAYER_IS_NULL);
            return;
        }
        float f = (float) d;
        this.model.getMediaPlayer().setVolume(f, f);
        result.success("Set volume");
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    public void setDbPeakLevelUpdate(double d, MethodChannel.Result result) {
        this.model.peakLevelUpdateMillis = (long) (d * 1000.0d);
        result.success("setDbPeakLevelUpdate: " + this.model.peakLevelUpdateMillis);
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    public void setDbLevelEnabled(boolean z, MethodChannel.Result result) {
        this.model.shouldProcessDbLevel = z;
        result.success("setDbLevelEnabled: " + this.model.shouldProcessDbLevel);
    }

    @Override // com.dooboolab.fluttersound.AudioInterface
    public void setSubscriptionDuration(double d, MethodChannel.Result result) {
        this.model.subsDurationMillis = (int) (d * 1000.0d);
        result.success("setSubscriptionDuration: " + this.model.subsDurationMillis);
    }
}
