package com.flutter_webview_plugin;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.net.http.SslError;
import android.os.Build;
import android.os.Handler;
import android.view.KeyEvent;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.CookieManager;
import android.webkit.GeolocationPermissions;
import android.webkit.SslErrorHandler;
import android.webkit.ValueCallback;
import android.webkit.WebChromeClient;
import android.webkit.WebView;
import android.widget.FrameLayout;
import androidx.core.app.NotificationCompat;
import androidx.core.content.FileProvider;
import com.flutter_webview_plugin.ObservableWebView;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.tekartik.sqflite.Constant;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/* access modifiers changed from: package-private */
public class WebviewManager {
    private static final int FILECHOOSER_RESULTCODE = 1;
    Activity activity;
    boolean closed = false;
    Context context;
    private Uri fileUri;
    private boolean ignoreSSLErrors = false;
    private ValueCallback<Uri> mUploadMessage;
    private ValueCallback<Uri[]> mUploadMessageArray;
    private final Handler platformThreadHandler;
    ResultHandler resultHandler;
    private Uri videoUri;
    WebView webView;
    BrowserClient webViewClient;

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private long getFileSize(Uri uri) {
        Cursor query = this.context.getContentResolver().query(uri, null, null, null, null);
        query.moveToFirst();
        return query.getLong(query.getColumnIndex("_size"));
    }

    class ResultHandler {
        ResultHandler() {
        }

        /* JADX WARNING: Removed duplicated region for block: B:19:0x0064  */
        /* JADX WARNING: Removed duplicated region for block: B:29:? A[RETURN, SYNTHETIC] */
        public boolean handleResult(int i, int i2, Intent intent) {
            Uri[] uriArr;
            if (Build.VERSION.SDK_INT >= 21) {
                if (i == 1) {
                    if (i2 == -1) {
                        if (WebviewManager.this.fileUri != null) {
                            WebviewManager webviewManager = WebviewManager.this;
                            if (webviewManager.getFileSize(webviewManager.fileUri) > 0) {
                                uriArr = new Uri[]{WebviewManager.this.fileUri};
                                if (WebviewManager.this.mUploadMessageArray != null) {
                                    return true;
                                }
                                WebviewManager.this.mUploadMessageArray.onReceiveValue(uriArr);
                                WebviewManager.this.mUploadMessageArray = null;
                                return true;
                            }
                        }
                        if (WebviewManager.this.videoUri != null) {
                            WebviewManager webviewManager2 = WebviewManager.this;
                            if (webviewManager2.getFileSize(webviewManager2.videoUri) > 0) {
                                uriArr = new Uri[]{WebviewManager.this.videoUri};
                                if (WebviewManager.this.mUploadMessageArray != null) {
                                }
                            }
                        }
                        if (intent != null) {
                            uriArr = WebviewManager.this.getSelectedFiles(intent);
                            if (WebviewManager.this.mUploadMessageArray != null) {
                            }
                        }
                    }
                    uriArr = null;
                    if (WebviewManager.this.mUploadMessageArray != null) {
                    }
                }
            } else if (i == 1) {
                Uri data = (i2 != -1 || intent == null) ? null : intent.getData();
                if (WebviewManager.this.mUploadMessage == null) {
                    return true;
                }
                WebviewManager.this.mUploadMessage.onReceiveValue(data);
                WebviewManager.this.mUploadMessage = null;
                return true;
            }
            return false;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Uri[] getSelectedFiles(Intent intent) {
        String dataString;
        if (!(intent.getData() == null || (dataString = intent.getDataString()) == null)) {
            return new Uri[]{Uri.parse(dataString)};
        }
        if (intent.getClipData() == null) {
            return null;
        }
        int itemCount = intent.getClipData().getItemCount();
        Uri[] uriArr = new Uri[itemCount];
        for (int i = 0; i < itemCount; i++) {
            uriArr[i] = intent.getClipData().getItemAt(i).getUri();
        }
        return uriArr;
    }

    WebviewManager(final Activity activity2, Context context2, List<String> list) {
        this.webView = new ObservableWebView(activity2);
        this.activity = activity2;
        this.context = context2;
        this.resultHandler = new ResultHandler();
        this.platformThreadHandler = new Handler(context2.getMainLooper());
        this.webViewClient = new BrowserClient() {
            /* class com.flutter_webview_plugin.WebviewManager.AnonymousClass1 */

            public void onReceivedSslError(WebView webView, SslErrorHandler sslErrorHandler, SslError sslError) {
                if (WebviewManager.this.ignoreSSLErrors) {
                    sslErrorHandler.proceed();
                } else {
                    super.onReceivedSslError(webView, sslErrorHandler, sslError);
                }
            }
        };
        this.webView.setOnKeyListener(new View.OnKeyListener() {
            /* class com.flutter_webview_plugin.WebviewManager.AnonymousClass2 */

            public boolean onKey(View view, int i, KeyEvent keyEvent) {
                if (keyEvent.getAction() != 0 || i != 4) {
                    return false;
                }
                if (WebviewManager.this.webView.canGoBack()) {
                    WebviewManager.this.webView.goBack();
                    return true;
                }
                FlutterWebviewPlugin.channel.invokeMethod("onBack", null);
                return true;
            }
        });
        ((ObservableWebView) this.webView).setOnScrollChangedCallback(new ObservableWebView.OnScrollChangedCallback() {
            /* class com.flutter_webview_plugin.WebviewManager.AnonymousClass3 */

            @Override // com.flutter_webview_plugin.ObservableWebView.OnScrollChangedCallback
            public void onScroll(int i, int i2, int i3, int i4) {
                HashMap hashMap = new HashMap();
                hashMap.put("yDirection", Double.valueOf((double) i2));
                FlutterWebviewPlugin.channel.invokeMethod("onScrollYChanged", hashMap);
                HashMap hashMap2 = new HashMap();
                hashMap2.put("xDirection", Double.valueOf((double) i));
                FlutterWebviewPlugin.channel.invokeMethod("onScrollXChanged", hashMap2);
            }
        });
        this.webView.setWebViewClient(this.webViewClient);
        this.webView.setWebChromeClient(new WebChromeClient() {
            /* class com.flutter_webview_plugin.WebviewManager.AnonymousClass4 */

            public void openFileChooser(ValueCallback<Uri> valueCallback) {
                WebviewManager.this.mUploadMessage = valueCallback;
                Intent intent = new Intent("android.intent.action.GET_CONTENT");
                intent.addCategory("android.intent.category.OPENABLE");
                intent.setType("image/*");
                activity2.startActivityForResult(Intent.createChooser(intent, "File Chooser"), 1);
            }

            public void openFileChooser(ValueCallback valueCallback, String str) {
                WebviewManager.this.mUploadMessage = valueCallback;
                Intent intent = new Intent("android.intent.action.GET_CONTENT");
                intent.addCategory("android.intent.category.OPENABLE");
                intent.setType("*/*");
                activity2.startActivityForResult(Intent.createChooser(intent, "File Browser"), 1);
            }

            public void openFileChooser(ValueCallback<Uri> valueCallback, String str, String str2) {
                WebviewManager.this.mUploadMessage = valueCallback;
                Intent intent = new Intent("android.intent.action.GET_CONTENT");
                intent.addCategory("android.intent.category.OPENABLE");
                intent.setType("image/*");
                activity2.startActivityForResult(Intent.createChooser(intent, "File Chooser"), 1);
            }

            @Override // android.webkit.WebChromeClient
            public boolean onShowFileChooser(WebView webView, ValueCallback<Uri[]> valueCallback, WebChromeClient.FileChooserParams fileChooserParams) {
                Intent intent;
                if (WebviewManager.this.mUploadMessageArray != null) {
                    WebviewManager.this.mUploadMessageArray.onReceiveValue(null);
                }
                WebviewManager.this.mUploadMessageArray = valueCallback;
                String[] safeAcceptedTypes = WebviewManager.this.getSafeAcceptedTypes(fileChooserParams);
                ArrayList arrayList = new ArrayList();
                WebviewManager.this.fileUri = null;
                WebviewManager.this.videoUri = null;
                if (WebviewManager.this.acceptsImages(safeAcceptedTypes).booleanValue()) {
                    Intent intent2 = new Intent("android.media.action.IMAGE_CAPTURE");
                    WebviewManager webviewManager = WebviewManager.this;
                    webviewManager.fileUri = webviewManager.getOutputFilename("android.media.action.IMAGE_CAPTURE");
                    intent2.putExtra("output", WebviewManager.this.fileUri);
                    arrayList.add(intent2);
                }
                if (WebviewManager.this.acceptsVideo(safeAcceptedTypes).booleanValue()) {
                    Intent intent3 = new Intent("android.media.action.VIDEO_CAPTURE");
                    WebviewManager webviewManager2 = WebviewManager.this;
                    webviewManager2.videoUri = webviewManager2.getOutputFilename("android.media.action.VIDEO_CAPTURE");
                    intent3.putExtra("output", WebviewManager.this.videoUri);
                    arrayList.add(intent3);
                }
                if (Build.VERSION.SDK_INT >= 21) {
                    boolean z = fileChooserParams.getMode() == 1;
                    intent = fileChooserParams.createIntent();
                    intent.putExtra("android.intent.extra.ALLOW_MULTIPLE", z);
                } else {
                    intent = new Intent("android.intent.action.GET_CONTENT");
                    intent.addCategory("android.intent.category.OPENABLE");
                    intent.setType("*/*");
                }
                Intent intent4 = new Intent("android.intent.action.CHOOSER");
                intent4.putExtra("android.intent.extra.INTENT", intent);
                intent4.putExtra("android.intent.extra.INITIAL_INTENTS", (Intent[]) arrayList.toArray(new Intent[arrayList.size()]));
                activity2.startActivityForResult(intent4, 1);
                return true;
            }

            public void onProgressChanged(WebView webView, int i) {
                HashMap hashMap = new HashMap();
                hashMap.put(NotificationCompat.CATEGORY_PROGRESS, Double.valueOf(((double) i) / 100.0d));
                FlutterWebviewPlugin.channel.invokeMethod("onProgressChanged", hashMap);
            }

            public void onGeolocationPermissionsShowPrompt(String str, GeolocationPermissions.Callback callback) {
                callback.invoke(str, true, false);
            }
        });
        registerJavaScriptChannelNames(list);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Uri getOutputFilename(String str) {
        String str2;
        String str3 = "";
        if (str == "android.media.action.IMAGE_CAPTURE") {
            str3 = "image-";
            str2 = ".jpg";
        } else if (str == "android.media.action.VIDEO_CAPTURE") {
            str3 = "video-";
            str2 = PictureFileUtils.POST_VIDEO;
        } else {
            str2 = str3;
        }
        String packageName = this.context.getPackageName();
        File file = null;
        try {
            file = createCapturedFile(str3, str2);
        } catch (IOException e) {
            e.printStackTrace();
        }
        Context context2 = this.context;
        return FileProvider.getUriForFile(context2, packageName + ".fileprovider", file);
    }

    private File createCapturedFile(String str, String str2) throws IOException {
        String format = new SimpleDateFormat("yyyyMMdd_HHmmss").format(new Date());
        return File.createTempFile(str + "_" + format, str2, this.context.getExternalFilesDir(null));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Boolean acceptsImages(String[] strArr) {
        return Boolean.valueOf(isArrayEmpty(strArr).booleanValue() || arrayContainsString(strArr, "image").booleanValue());
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Boolean acceptsVideo(String[] strArr) {
        return Boolean.valueOf(isArrayEmpty(strArr).booleanValue() || arrayContainsString(strArr, "video").booleanValue());
    }

    private Boolean arrayContainsString(String[] strArr, String str) {
        for (String str2 : strArr) {
            if (str2.contains(str)) {
                return true;
            }
        }
        return false;
    }

    private Boolean isArrayEmpty(String[] strArr) {
        boolean z = false;
        if (strArr.length == 0 || (strArr.length == 1 && strArr[0].length() == 0)) {
            z = true;
        }
        return Boolean.valueOf(z);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String[] getSafeAcceptedTypes(WebChromeClient.FileChooserParams fileChooserParams) {
        return Build.VERSION.SDK_INT >= 21 ? fileChooserParams.getAcceptTypes() : new String[0];
    }

    private void clearCookies() {
        if (Build.VERSION.SDK_INT >= 21) {
            CookieManager.getInstance().removeAllCookies(new ValueCallback<Boolean>() {
                /* class com.flutter_webview_plugin.WebviewManager.AnonymousClass5 */

                public void onReceiveValue(Boolean bool) {
                }
            });
        } else {
            CookieManager.getInstance().removeAllCookie();
        }
    }

    private void clearCache() {
        this.webView.clearCache(true);
        this.webView.clearFormData();
    }

    private void registerJavaScriptChannelNames(List<String> list) {
        for (String str : list) {
            this.webView.addJavascriptInterface(new JavaScriptChannel(FlutterWebviewPlugin.channel, str, this.platformThreadHandler), str);
        }
    }

    /* access modifiers changed from: package-private */
    public void openUrl(boolean z, boolean z2, boolean z3, boolean z4, boolean z5, String str, String str2, Map<String, String> map, boolean z6, boolean z7, boolean z8, boolean z9, boolean z10, boolean z11, boolean z12, boolean z13, boolean z14, String str3, boolean z15, boolean z16, boolean z17) {
        this.webView.getSettings().setJavaScriptEnabled(z);
        this.webView.getSettings().setBuiltInZoomControls(z6);
        this.webView.getSettings().setSupportZoom(z6);
        this.webView.getSettings().setDisplayZoomControls(z7);
        this.webView.getSettings().setDomStorageEnabled(z8);
        this.webView.getSettings().setLoadWithOverviewMode(z9);
        this.webView.getSettings().setJavaScriptCanOpenWindowsAutomatically(z11);
        this.webView.getSettings().setSupportMultipleWindows(z11);
        this.webView.getSettings().setAppCacheEnabled(z12);
        this.webView.getSettings().setAllowFileAccessFromFileURLs(z13);
        this.webView.getSettings().setAllowUniversalAccessFromFileURLs(z13);
        this.webView.getSettings().setUseWideViewPort(z14);
        if (Build.VERSION.SDK_INT >= 17) {
            this.webView.getSettings().setMediaPlaybackRequiresUserGesture(z5);
        }
        if (Build.VERSION.SDK_INT >= 19) {
            WebView webView2 = this.webView;
            WebView.setWebContentsDebuggingEnabled(z16);
        }
        this.ignoreSSLErrors = z17;
        this.webViewClient.updateInvalidUrlRegex(str3);
        if (z15) {
            this.webView.getSettings().setGeolocationEnabled(true);
        }
        if (Build.VERSION.SDK_INT >= 21) {
            this.webView.getSettings().setMixedContentMode(2);
        }
        if (z2) {
            clearCache();
        }
        if (z3) {
            this.webView.setVisibility(8);
        }
        if (z4) {
            clearCookies();
        }
        if (str != null) {
            this.webView.getSettings().setUserAgentString(str);
        }
        if (!z10) {
            this.webView.setVerticalScrollBarEnabled(false);
        }
        if (map != null) {
            this.webView.loadUrl(str2, map);
        } else {
            this.webView.loadUrl(str2);
        }
    }

    /* access modifiers changed from: package-private */
    public void reloadUrl(String str) {
        this.webView.loadUrl(str);
    }

    /* access modifiers changed from: package-private */
    public void reloadUrl(String str, Map<String, String> map) {
        this.webView.loadUrl(str, map);
    }

    /* access modifiers changed from: package-private */
    public void close(MethodCall methodCall, MethodChannel.Result result) {
        WebView webView2 = this.webView;
        if (webView2 != null) {
            ((ViewGroup) webView2.getParent()).removeView(this.webView);
        }
        this.webView = null;
        if (result != null) {
            result.success(null);
        }
        this.closed = true;
        FlutterWebviewPlugin.channel.invokeMethod("onDestroy", null);
    }

    /* access modifiers changed from: package-private */
    public void close() {
        close(null, null);
    }

    /* access modifiers changed from: package-private */
    public void eval(MethodCall methodCall, final MethodChannel.Result result) {
        this.webView.evaluateJavascript((String) methodCall.argument(Constant.PARAM_ERROR_CODE), new ValueCallback<String>() {
            /* class com.flutter_webview_plugin.WebviewManager.AnonymousClass6 */

            public void onReceiveValue(String str) {
                result.success(str);
            }
        });
    }

    /* access modifiers changed from: package-private */
    public void reload(MethodCall methodCall, MethodChannel.Result result) {
        WebView webView2 = this.webView;
        if (webView2 != null) {
            webView2.reload();
        }
    }

    /* access modifiers changed from: package-private */
    public void back(MethodCall methodCall, MethodChannel.Result result) {
        WebView webView2 = this.webView;
        if (webView2 != null && webView2.canGoBack()) {
            this.webView.goBack();
        }
    }

    /* access modifiers changed from: package-private */
    public void forward(MethodCall methodCall, MethodChannel.Result result) {
        WebView webView2 = this.webView;
        if (webView2 != null && webView2.canGoForward()) {
            this.webView.goForward();
        }
    }

    /* access modifiers changed from: package-private */
    public void resize(FrameLayout.LayoutParams layoutParams) {
        this.webView.setLayoutParams(layoutParams);
    }

    /* access modifiers changed from: package-private */
    public boolean canGoBack() {
        return this.webView.canGoBack();
    }

    /* access modifiers changed from: package-private */
    public boolean canGoForward() {
        return this.webView.canGoForward();
    }

    /* access modifiers changed from: package-private */
    public void cleanCache() {
        this.webView.clearCache(true);
    }

    /* access modifiers changed from: package-private */
    public void hide(MethodCall methodCall, MethodChannel.Result result) {
        WebView webView2 = this.webView;
        if (webView2 != null) {
            webView2.setVisibility(8);
        }
    }

    /* access modifiers changed from: package-private */
    public void show(MethodCall methodCall, MethodChannel.Result result) {
        WebView webView2 = this.webView;
        if (webView2 != null) {
            webView2.setVisibility(0);
        }
    }

    /* access modifiers changed from: package-private */
    public void stopLoading(MethodCall methodCall, MethodChannel.Result result) {
        WebView webView2 = this.webView;
        if (webView2 != null) {
            webView2.stopLoading();
        }
    }
}
