package com.luck.picture.lib.model;

import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.provider.MediaStore;
import android.text.TextUtils;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.ValueOf;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Locale;

public class LocalMediaLoader implements Handler.Callback {
    private static final int AUDIO_DURATION = 500;
    private static final long FILE_SIZE_UNIT = 1048576;
    private static final int MSG_QUERY_MEDIA_ERROR = -1;
    private static final int MSG_QUERY_MEDIA_SUCCESS = 0;
    private static final String NOT_GIF = "!='image/gif'";
    private static final String ORDER_BY = "_id DESC";
    private static final String[] PROJECTION = {"_id", "_data", "mime_type", "width", "height", "duration", "_size", "bucket_display_name", "_display_name"};
    private static final Uri QUERY_URI = MediaStore.Files.getContentUri("external");
    private static final String SELECTION = "media_type=? AND _size>0";
    private static final String[] SELECTION_ALL_ARGS = {String.valueOf(1), String.valueOf(3)};
    private static final String SELECTION_NOT_GIF = "media_type=? AND _size>0 AND mime_type!='image/gif'";
    private static final String SELECTION_SPECIFIED_FORMAT = "media_type=? AND _size>0 AND mime_type";
    private PictureSelectionConfig config;
    private boolean isAndroidQ = SdkVersionUtils.checkedAndroid_Q();
    private LocalMediaLoadListener mCompleteListener;
    private Context mContext;
    private Handler mHandler;

    public interface LocalMediaLoadListener {
        void loadComplete(List<LocalMediaFolder> list);

        void loadMediaDataError();
    }

    private static String getSelectionArgsForSingleMediaCondition() {
        return SELECTION;
    }

    private static String getSelectionArgsForSingleMediaCondition(String str) {
        return "media_type=? AND _size>0 AND " + str;
    }

    private static String getSelectionArgsForAllMediaCondition(String str, boolean z) {
        StringBuilder sb = new StringBuilder();
        sb.append("(media_type=?");
        sb.append(z ? "" : " AND mime_type!='image/gif'");
        sb.append(" OR ");
        sb.append("media_type=? AND ");
        sb.append(str);
        sb.append(") AND ");
        sb.append("_size");
        sb.append(">0");
        return sb.toString();
    }

    private static String[] getSelectionArgsForSingleMediaType(int i) {
        return new String[]{String.valueOf(i)};
    }

    public LocalMediaLoader(Context context, PictureSelectionConfig pictureSelectionConfig) {
        this.mContext = context.getApplicationContext();
        this.config = pictureSelectionConfig;
        this.mHandler = new Handler(Looper.getMainLooper(), this);
    }

    public void loadAllMedia() {
        AsyncTask.SERIAL_EXECUTOR.execute(new Runnable() {
            /* class com.luck.picture.lib.model.$$Lambda$LocalMediaLoader$wKKGWhZdSHFCaFZbZMaAWHLU9H8 */

            public final void run() {
                LocalMediaLoader.this.lambda$loadAllMedia$0$LocalMediaLoader();
            }
        });
    }

    /* JADX WARNING: Removed duplicated region for block: B:43:0x017d A[Catch:{ Exception -> 0x019c }, LOOP:0: B:6:0x0035->B:43:0x017d, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x0137 A[EDGE_INSN: B:51:0x0137->B:36:0x0137 ?: BREAK  , SYNTHETIC] */
    public /* synthetic */ void lambda$loadAllMedia$0$LocalMediaLoader() {
        String str;
        Cursor cursor;
        boolean z;
        String str2;
        Cursor query = this.mContext.getContentResolver().query(QUERY_URI, PROJECTION, getSelection(), getSelectionArgs(), ORDER_BY);
        if (query != null) {
            try {
                ArrayList arrayList = new ArrayList();
                LocalMediaFolder localMediaFolder = new LocalMediaFolder();
                ArrayList arrayList2 = new ArrayList();
                char c = 0;
                if (query.getCount() > 0) {
                    query.moveToFirst();
                    while (true) {
                        long j = query.getLong(query.getColumnIndexOrThrow(PROJECTION[c]));
                        if (this.isAndroidQ) {
                            str = getRealPathAndroid_Q(j);
                        } else {
                            str = query.getString(query.getColumnIndexOrThrow(PROJECTION[1]));
                        }
                        String string = query.getString(query.getColumnIndexOrThrow(PROJECTION[2]));
                        int i = query.getInt(query.getColumnIndexOrThrow(PROJECTION[3]));
                        int i2 = query.getInt(query.getColumnIndexOrThrow(PROJECTION[4]));
                        long j2 = query.getLong(query.getColumnIndexOrThrow(PROJECTION[5]));
                        long j3 = query.getLong(query.getColumnIndexOrThrow(PROJECTION[6]));
                        String string2 = query.getString(query.getColumnIndexOrThrow(PROJECTION[7]));
                        String string3 = query.getString(query.getColumnIndexOrThrow(PROJECTION[8]));
                        if (this.config.filterFileSize <= 0 || j3 <= ((long) this.config.filterFileSize) * 1048576) {
                            if (PictureMimeType.eqVideo(string)) {
                                if (this.config.videoMinSecond <= 0 || j2 >= ((long) this.config.videoMinSecond)) {
                                    if (this.config.videoMaxSecond <= 0 || j2 <= ((long) this.config.videoMaxSecond)) {
                                        if (j2 != 0) {
                                            if (j3 <= 0) {
                                            }
                                        }
                                    }
                                }
                            }
                            cursor = query;
                            z = true;
                            LocalMedia localMedia = new LocalMedia(j, str, string3, j2, this.config.chooseMode, string, i, i2, j3);
                            LocalMediaFolder imageFolder = getImageFolder(str, string2, arrayList);
                            imageFolder.getImages().add(localMedia);
                            imageFolder.setImageNum(imageFolder.getImageNum() + 1);
                            arrayList2.add(localMedia);
                            localMediaFolder.setImageNum(localMediaFolder.getImageNum() + 1);
                            if (cursor.moveToNext()) {
                                break;
                            }
                            query = cursor;
                            c = 0;
                        }
                        cursor = query;
                        z = true;
                        if (cursor.moveToNext()) {
                        }
                    }
                    if (arrayList2.size() > 0) {
                        sortFolder(arrayList);
                        arrayList.add(0, localMediaFolder);
                        localMediaFolder.setFirstImagePath(arrayList2.get(0).getPath());
                        if (this.config.chooseMode == PictureMimeType.ofAudio()) {
                            str2 = this.mContext.getString(R.string.picture_all_audio);
                        } else {
                            str2 = this.mContext.getString(R.string.picture_camera_roll);
                        }
                        localMediaFolder.setName(str2);
                        localMediaFolder.setOfAllType(this.config.chooseMode);
                        localMediaFolder.setCameraFolder(z);
                        localMediaFolder.setImages(arrayList2);
                    }
                }
                this.mHandler.sendMessage(this.mHandler.obtainMessage(0, arrayList));
            } catch (Exception e) {
                Handler handler = this.mHandler;
                if (handler != null) {
                    handler.sendMessage(handler.obtainMessage(-1));
                }
                e.printStackTrace();
            }
        } else {
            this.mHandler.sendMessage(this.mHandler.obtainMessage(-1));
        }
    }

    private String getSelection() {
        int i = this.config.chooseMode;
        if (i == 0) {
            return getSelectionArgsForAllMediaCondition(getDurationCondition(0, 0), this.config.isGif);
        }
        if (i != 1) {
            if (i != 2) {
                if (i != 3) {
                    return null;
                }
                if (TextUtils.isEmpty(this.config.specifiedFormat)) {
                    return getSelectionArgsForSingleMediaCondition(getDurationCondition(0, 500));
                }
                return "media_type=? AND _size>0 AND mime_type='" + this.config.specifiedFormat + "'";
            } else if (TextUtils.isEmpty(this.config.specifiedFormat)) {
                return getSelectionArgsForSingleMediaCondition();
            } else {
                return "media_type=? AND _size>0 AND mime_type='" + this.config.specifiedFormat + "'";
            }
        } else if (TextUtils.isEmpty(this.config.specifiedFormat)) {
            return this.config.isGif ? SELECTION : SELECTION_NOT_GIF;
        } else {
            return "media_type=? AND _size>0 AND mime_type='" + this.config.specifiedFormat + "'";
        }
    }

    private String[] getSelectionArgs() {
        int i = this.config.chooseMode;
        if (i == 0) {
            return SELECTION_ALL_ARGS;
        }
        if (i == 1) {
            return getSelectionArgsForSingleMediaType(1);
        }
        if (i == 2) {
            return getSelectionArgsForSingleMediaType(3);
        }
        if (i != 3) {
            return null;
        }
        return getSelectionArgsForSingleMediaType(2);
    }

    private void sortFolder(List<LocalMediaFolder> list) {
        Collections.sort(list, $$Lambda$LocalMediaLoader$9Yy89jTG_fIMWYKawqX9kvVOkg.INSTANCE);
    }

    static /* synthetic */ int lambda$sortFolder$1(LocalMediaFolder localMediaFolder, LocalMediaFolder localMediaFolder2) {
        int imageNum;
        int imageNum2;
        if (localMediaFolder.getImages() == null || localMediaFolder2.getImages() == null || (imageNum = localMediaFolder.getImageNum()) == (imageNum2 = localMediaFolder2.getImageNum())) {
            return 0;
        }
        return imageNum < imageNum2 ? 1 : -1;
    }

    private String getRealPathAndroid_Q(long j) {
        return QUERY_URI.buildUpon().appendPath(ValueOf.toString(Long.valueOf(j))).build().toString();
    }

    private LocalMediaFolder getImageFolder(String str, String str2, List<LocalMediaFolder> list) {
        if (!this.config.isFallbackVersion) {
            for (LocalMediaFolder localMediaFolder : list) {
                String name = localMediaFolder.getName();
                if (!TextUtils.isEmpty(name) && name.equals(str2)) {
                    return localMediaFolder;
                }
            }
            LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
            localMediaFolder2.setName(str2);
            localMediaFolder2.setFirstImagePath(str);
            list.add(localMediaFolder2);
            return localMediaFolder2;
        }
        File parentFile = new File(str).getParentFile();
        for (LocalMediaFolder localMediaFolder3 : list) {
            String name2 = localMediaFolder3.getName();
            if (!TextUtils.isEmpty(name2) && name2.equals(parentFile.getName())) {
                return localMediaFolder3;
            }
        }
        LocalMediaFolder localMediaFolder4 = new LocalMediaFolder();
        localMediaFolder4.setName(parentFile.getName());
        localMediaFolder4.setFirstImagePath(str);
        list.add(localMediaFolder4);
        return localMediaFolder4;
    }

    private String getDurationCondition(long j, long j2) {
        long j3 = this.config.videoMaxSecond == 0 ? Long.MAX_VALUE : (long) this.config.videoMaxSecond;
        if (j != 0) {
            j3 = Math.min(j3, j);
        }
        Locale locale = Locale.CHINA;
        Object[] objArr = new Object[3];
        objArr[0] = Long.valueOf(Math.max(j2, (long) this.config.videoMinSecond));
        objArr[1] = Math.max(j2, (long) this.config.videoMinSecond) == 0 ? "" : "=";
        objArr[2] = Long.valueOf(j3);
        return String.format(locale, "%d <%s duration and duration <= %d", objArr);
    }

    public boolean handleMessage(Message message) {
        if (this.mCompleteListener == null) {
            return false;
        }
        int i = message.what;
        if (i == -1) {
            this.mCompleteListener.loadMediaDataError();
        } else if (i == 0) {
            this.mCompleteListener.loadComplete((List) message.obj);
        }
        return false;
    }

    public void setCompleteListener(LocalMediaLoadListener localMediaLoadListener) {
        this.mCompleteListener = localMediaLoadListener;
    }
}
