package com.rhyme.r_scan.RScanCamera;

import android.app.Activity;
import android.hardware.camera2.CameraAccessException;
import android.hardware.camera2.CameraCharacteristics;
import android.hardware.camera2.CameraManager;
import android.media.CamcorderProfile;
import android.util.Size;
import com.rhyme.r_scan.RScanCamera.RScanCamera;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class CameraUtils {
    public static List<Map<String, Object>> getAvailableCameras(Activity activity) throws CameraAccessException {
        CameraManager cameraManager = (CameraManager) activity.getSystemService("camera");
        String[] cameraIdList = cameraManager.getCameraIdList();
        ArrayList arrayList = new ArrayList();
        for (String str : cameraIdList) {
            HashMap hashMap = new HashMap();
            CameraCharacteristics cameraCharacteristics = cameraManager.getCameraCharacteristics(str);
            hashMap.put("name", str);
            int intValue = ((Integer) cameraCharacteristics.get(CameraCharacteristics.LENS_FACING)).intValue();
            if (intValue == 0) {
                hashMap.put("lensFacing", "front");
            } else if (intValue == 1) {
                hashMap.put("lensFacing", "back");
            } else if (intValue == 2) {
                hashMap.put("lensFacing", "external");
            }
            arrayList.add(hashMap);
        }
        return arrayList;
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x0030  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x003c  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x0048  */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x0054  */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x0060  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0065  */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0024  */
    static CamcorderProfile getBestAvailableCamcorderProfileForResolutionPreset(String str, RScanCamera.ResolutionPreset resolutionPreset) {
        int parseInt = Integer.parseInt(str);
        switch (resolutionPreset) {
            case max:
                if (CamcorderProfile.hasProfile(parseInt, 1)) {
                    return CamcorderProfile.get(parseInt, 1);
                }
                if (CamcorderProfile.hasProfile(parseInt, 8)) {
                    return CamcorderProfile.get(parseInt, 8);
                }
                if (CamcorderProfile.hasProfile(parseInt, 6)) {
                    return CamcorderProfile.get(parseInt, 6);
                }
                if (CamcorderProfile.hasProfile(parseInt, 5)) {
                    return CamcorderProfile.get(parseInt, 5);
                }
                if (CamcorderProfile.hasProfile(parseInt, 4)) {
                    return CamcorderProfile.get(parseInt, 4);
                }
                if (CamcorderProfile.hasProfile(parseInt, 7)) {
                    return CamcorderProfile.get(parseInt, 7);
                }
                if (CamcorderProfile.hasProfile(parseInt, 0)) {
                    return CamcorderProfile.get(parseInt, 0);
                }
                throw new IllegalArgumentException("No capture session available for current capture session.");
            case ultraHigh:
                if (CamcorderProfile.hasProfile(parseInt, 8)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 6)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 5)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 4)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 7)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 0)) {
                }
                break;
            case veryHigh:
                if (CamcorderProfile.hasProfile(parseInt, 6)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 5)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 4)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 7)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 0)) {
                }
                break;
            case high:
                if (CamcorderProfile.hasProfile(parseInt, 5)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 4)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 7)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 0)) {
                }
                break;
            case medium:
                if (CamcorderProfile.hasProfile(parseInt, 4)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 7)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 0)) {
                }
                break;
            case low:
                if (CamcorderProfile.hasProfile(parseInt, 7)) {
                }
                if (CamcorderProfile.hasProfile(parseInt, 0)) {
                }
                break;
            default:
                if (CamcorderProfile.hasProfile(parseInt, 0)) {
                }
                break;
        }
    }

    static Size computeBestPreviewSize(String str, RScanCamera.ResolutionPreset resolutionPreset) {
        if (resolutionPreset.ordinal() > RScanCamera.ResolutionPreset.high.ordinal()) {
            resolutionPreset = RScanCamera.ResolutionPreset.high;
        }
        CamcorderProfile bestAvailableCamcorderProfileForResolutionPreset = getBestAvailableCamcorderProfileForResolutionPreset(str, resolutionPreset);
        return new Size(bestAvailableCamcorderProfileForResolutionPreset.videoFrameWidth, bestAvailableCamcorderProfileForResolutionPreset.videoFrameHeight);
    }
}
