package io.flutter.embedding.android;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.ColorSpace;
import android.graphics.Paint;
import android.hardware.HardwareBuffer;
import android.media.Image;
import android.media.ImageReader;
import android.os.Build;
import android.util.AttributeSet;
import android.view.Surface;
import android.view.View;
import io.flutter.embedding.engine.renderer.FlutterRenderer;
import io.flutter.embedding.engine.renderer.RenderSurface;
import java.util.LinkedList;
import java.util.Queue;

public class FlutterImageView extends View implements RenderSurface {
    private Bitmap currentBitmap;
    private Image currentImage;
    private FlutterRenderer flutterRenderer;
    private Queue<Image> imageQueue;
    private ImageReader imageReader;
    private boolean isAttachedToFlutterRenderer;
    private SurfaceKind kind;
    private int pendingImages;

    public enum SurfaceKind {
        background,
        overlay
    }

    @Override // io.flutter.embedding.engine.renderer.RenderSurface
    public void pause() {
    }

    public FlutterImageView(Context context, int i, int i2, SurfaceKind surfaceKind) {
        this(context, createImageReader(i, i2), surfaceKind);
    }

    public FlutterImageView(Context context) {
        this(context, 1, 1, SurfaceKind.background);
    }

    public FlutterImageView(Context context, AttributeSet attributeSet) {
        this(context, 1, 1, SurfaceKind.background);
    }

    FlutterImageView(Context context, ImageReader imageReader2, SurfaceKind surfaceKind) {
        super(context, null);
        this.pendingImages = 0;
        this.isAttachedToFlutterRenderer = false;
        this.imageReader = imageReader2;
        this.kind = surfaceKind;
        this.imageQueue = new LinkedList();
        init();
    }

    private void init() {
        setAlpha(0.0f);
    }

    private static ImageReader createImageReader(int i, int i2) {
        if (Build.VERSION.SDK_INT >= 29) {
            return ImageReader.newInstance(i, i2, 1, 3, 768);
        }
        return ImageReader.newInstance(i, i2, 1, 3);
    }

    public Surface getSurface() {
        return this.imageReader.getSurface();
    }

    @Override // io.flutter.embedding.engine.renderer.RenderSurface
    public FlutterRenderer getAttachedRenderer() {
        return this.flutterRenderer;
    }

    @Override // io.flutter.embedding.engine.renderer.RenderSurface
    public void attachToRenderer(FlutterRenderer flutterRenderer2) {
        if (!this.isAttachedToFlutterRenderer) {
            if (AnonymousClass1.$SwitchMap$io$flutter$embedding$android$FlutterImageView$SurfaceKind[this.kind.ordinal()] == 1) {
                flutterRenderer2.swapSurface(this.imageReader.getSurface());
            }
            setAlpha(1.0f);
            this.flutterRenderer = flutterRenderer2;
            this.isAttachedToFlutterRenderer = true;
        }
    }

    /* renamed from: io.flutter.embedding.android.FlutterImageView$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$io$flutter$embedding$android$FlutterImageView$SurfaceKind = new int[SurfaceKind.values().length];

        /* JADX WARNING: Can't wrap try/catch for region: R(6:0|1|2|3|4|6) */
        /* JADX WARNING: Code restructure failed: missing block: B:7:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0014 */
        static {
            $SwitchMap$io$flutter$embedding$android$FlutterImageView$SurfaceKind[SurfaceKind.background.ordinal()] = 1;
            $SwitchMap$io$flutter$embedding$android$FlutterImageView$SurfaceKind[SurfaceKind.overlay.ordinal()] = 2;
        }
    }

    @Override // io.flutter.embedding.engine.renderer.RenderSurface
    public void detachFromRenderer() {
        if (this.isAttachedToFlutterRenderer) {
            setAlpha(0.0f);
            acquireLatestImage();
            this.currentBitmap = null;
            for (Image image : this.imageQueue) {
                image.close();
            }
            this.imageQueue.clear();
            Image image2 = this.currentImage;
            if (image2 != null) {
                image2.close();
                this.currentImage = null;
            }
            invalidate();
            this.isAttachedToFlutterRenderer = false;
        }
    }

    public boolean acquireLatestImage() {
        Image acquireLatestImage;
        if (!this.isAttachedToFlutterRenderer) {
            return false;
        }
        int size = this.imageQueue.size();
        if (this.currentImage != null) {
            size++;
        }
        if (size < this.imageReader.getMaxImages() && (acquireLatestImage = this.imageReader.acquireLatestImage()) != null) {
            this.imageQueue.add(acquireLatestImage);
        }
        invalidate();
        return !this.imageQueue.isEmpty();
    }

    public void resizeIfNeeded(int i, int i2) {
        if (this.flutterRenderer != null) {
            if (i != this.imageReader.getWidth() || i2 != this.imageReader.getHeight()) {
                this.imageQueue.clear();
                this.currentImage = null;
                this.imageReader.close();
                this.imageReader = createImageReader(i, i2);
                this.pendingImages = 0;
            }
        }
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        if (!this.imageQueue.isEmpty()) {
            Image image = this.currentImage;
            if (image != null) {
                image.close();
            }
            this.currentImage = this.imageQueue.poll();
            updateCurrentBitmap();
        }
        Bitmap bitmap = this.currentBitmap;
        if (bitmap != null) {
            canvas.drawBitmap(bitmap, 0.0f, 0.0f, (Paint) null);
        }
    }

    private void updateCurrentBitmap() {
        if (Build.VERSION.SDK_INT >= 29) {
            HardwareBuffer hardwareBuffer = this.currentImage.getHardwareBuffer();
            this.currentBitmap = Bitmap.wrapHardwareBuffer(hardwareBuffer, ColorSpace.get(ColorSpace.Named.SRGB));
            hardwareBuffer.close();
            return;
        }
        Image.Plane[] planes = this.currentImage.getPlanes();
        if (planes.length == 1) {
            Image.Plane plane = planes[0];
            int rowStride = plane.getRowStride() / plane.getPixelStride();
            int height = this.currentImage.getHeight();
            Bitmap bitmap = this.currentBitmap;
            if (!(bitmap != null && bitmap.getWidth() == rowStride && this.currentBitmap.getHeight() == height)) {
                this.currentBitmap = Bitmap.createBitmap(rowStride, height, Bitmap.Config.ARGB_8888);
            }
            this.currentBitmap.copyPixelsFromBuffer(plane.getBuffer());
        }
    }

    /* access modifiers changed from: protected */
    public void onSizeChanged(int i, int i2, int i3, int i4) {
        if (!(i == this.imageReader.getWidth() && i2 == this.imageReader.getHeight()) && this.kind == SurfaceKind.background && this.isAttachedToFlutterRenderer) {
            resizeIfNeeded(i, i2);
            this.flutterRenderer.swapSurface(this.imageReader.getSurface());
        }
    }
}
