package io.flutter.plugins;

import android.graphics.Bitmap;
import android.media.MediaMetadataRetriever;
import android.os.Environment;
import android.text.TextUtils;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

public class FileUtils {
    public static String getMimeType(String str) {
        MediaMetadataRetriever mediaMetadataRetriever = new MediaMetadataRetriever();
        if (str == null) {
            return "text/plain";
        }
        try {
            mediaMetadataRetriever.setDataSource(str);
            return mediaMetadataRetriever.extractMetadata(12);
        } catch (IllegalArgumentException | IllegalStateException | RuntimeException unused) {
            return "text/plain";
        }
    }

    public static int getVideoDuration(String str) {
        MediaMetadataRetriever mediaMetadataRetriever = new MediaMetadataRetriever();
        if (str != null) {
            try {
                mediaMetadataRetriever.setDataSource(new FileInputStream(new File(str).getAbsolutePath()).getFD());
                String extractMetadata = mediaMetadataRetriever.extractMetadata(9);
                if (TextUtils.isDigitsOnly(extractMetadata)) {
                    return Integer.parseInt(extractMetadata) / 1000;
                }
            } catch (Exception unused) {
            }
        }
        return 0;
    }

    public static String getVideoResolution(String str) {
        StringBuffer stringBuffer = new StringBuffer();
        MediaMetadataRetriever mediaMetadataRetriever = new MediaMetadataRetriever();
        if (str != null) {
            try {
                mediaMetadataRetriever.setDataSource(new FileInputStream(new File(str).getAbsolutePath()).getFD());
                stringBuffer.append(mediaMetadataRetriever.extractMetadata(18));
                stringBuffer.append("*");
                stringBuffer.append(mediaMetadataRetriever.extractMetadata(19));
            } catch (Exception unused) {
                return stringBuffer.toString();
            }
        }
        return stringBuffer.toString();
    }

    public static String getVideoRatio(String str) {
        MediaMetadataRetriever mediaMetadataRetriever = new MediaMetadataRetriever();
        if (str != null) {
            try {
                mediaMetadataRetriever.setDataSource(str);
                int parseInt = Integer.parseInt(mediaMetadataRetriever.extractMetadata(18));
                int parseInt2 = Integer.parseInt(mediaMetadataRetriever.extractMetadata(19));
                if (parseInt > 0 && parseInt2 > 0) {
                    return String.valueOf(Float.valueOf((float) parseInt).floatValue() / ((float) parseInt2));
                }
            } catch (Exception unused) {
            }
        }
        return "0";
    }

    public static String getVideoBitrate(String str) {
        MediaMetadataRetriever mediaMetadataRetriever = new MediaMetadataRetriever();
        try {
            mediaMetadataRetriever.setDataSource(str);
            return mediaMetadataRetriever.extractMetadata(20);
        } catch (Exception unused) {
            return "0";
        }
    }

    public static int getVideoSize(String str) {
        File file = new File(str);
        if (file.exists()) {
            try {
                return new FileInputStream(file).available();
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            } catch (IOException e2) {
                e2.printStackTrace();
            }
        }
        return 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x008c A[SYNTHETIC, Splitter:B:14:0x008c] */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x00b5  */
    /* JADX WARNING: Removed duplicated region for block: B:34:? A[RETURN, SYNTHETIC] */
    public static String saveCoverInLocal(String str) {
        FileOutputStream fileOutputStream;
        FileNotFoundException e;
        String str2 = Environment.getExternalStorageDirectory().getAbsolutePath() + File.separator + "lkyDemo" + File.separator + "image";
        File file = new File(str2);
        if (!file.exists()) {
            file.mkdirs();
        }
        File file2 = new File(str2, System.currentTimeMillis() + ".jpg");
        Bitmap videoThumb = getVideoThumb(str);
        try {
            fileOutputStream = new FileOutputStream(file2);
            try {
                videoThumb.compress(Bitmap.CompressFormat.JPEG, 100, fileOutputStream);
                System.out.println("保存已经至" + Environment.getExternalStorageDirectory() + "下");
            } catch (FileNotFoundException e2) {
                e = e2;
            }
        } catch (FileNotFoundException e3) {
            e = e3;
            fileOutputStream = null;
            e.printStackTrace();
            if (fileOutputStream != null) {
            }
            if (!file2.exists()) {
            }
        }
        if (fileOutputStream != null) {
            try {
                fileOutputStream.flush();
                fileOutputStream.close();
            } catch (IOException e4) {
                e4.printStackTrace();
                if (file2.exists()) {
                    return file2.getAbsolutePath();
                }
                return "";
            } catch (Throwable unused) {
                if (file2.exists()) {
                    return file2.getAbsolutePath();
                }
                return "";
            }
        }
        if (!file2.exists()) {
            return file2.getAbsolutePath();
        }
        return "";
    }

    public static Bitmap getVideoThumb(String str) {
        MediaMetadataRetriever mediaMetadataRetriever = new MediaMetadataRetriever();
        mediaMetadataRetriever.setDataSource(str);
        return mediaMetadataRetriever.getFrameAtTime();
    }
}
